(function(){const $=document.createElement("link").relList;if($&&$.supports&&$.supports("modulepreload"))return;for(const G of document.querySelectorAll('link[rel="modulepreload"]'))m(G);new MutationObserver(G=>{for(const B of G)if(B.type==="childList")for(const F of B.addedNodes)F.tagName==="LINK"&&F.rel==="modulepreload"&&m(F)}).observe(document,{childList:!0,subtree:!0});function V(G){const B={};return G.integrity&&(B.integrity=G.integrity),G.referrerPolicy&&(B.referrerPolicy=G.referrerPolicy),G.crossOrigin==="use-credentials"?B.credentials="include":G.crossOrigin==="anonymous"?B.credentials="omit":B.credentials="same-origin",B}function m(G){if(G.ep)return;G.ep=!0;const B=V(G);fetch(G.href,B)}})();var Ff={exports:{}},me={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var F1;function H4(){if(F1)return me;F1=1;var z=Symbol.for("react.transitional.element"),$=Symbol.for("react.fragment");function V(m,G,B){var F=null;if(B!==void 0&&(F=""+B),G.key!==void 0&&(F=""+G.key),"key"in G){B={};for(var rl in G)rl!=="key"&&(B[rl]=G[rl])}else B=G;return G=B.ref,{$$typeof:z,type:m,key:F,ref:G!==void 0?G:null,props:B}}return me.Fragment=$,me.jsx=V,me.jsxs=V,me}var P1;function C4(){return P1||(P1=1,Ff.exports=H4()),Ff.exports}var M=C4(),Pf={exports:{}},Q={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var I1;function x4(){if(I1)return Q;I1=1;var z=Symbol.for("react.transitional.element"),$=Symbol.for("react.portal"),V=Symbol.for("react.fragment"),m=Symbol.for("react.strict_mode"),G=Symbol.for("react.profiler"),B=Symbol.for("react.consumer"),F=Symbol.for("react.context"),rl=Symbol.for("react.forward_ref"),p=Symbol.for("react.suspense"),E=Symbol.for("react.memo"),R=Symbol.for("react.lazy"),K=Symbol.iterator;function N(s){return s===null||typeof s!="object"?null:(s=K&&s[K]||s["@@iterator"],typeof s=="function"?s:null)}var il={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},Ol=Object.assign,jl={};function ql(s,A,D){this.props=s,this.context=A,this.refs=jl,this.updater=D||il}ql.prototype.isReactComponent={},ql.prototype.setState=function(s,A){if(typeof s!="object"&&typeof s!="function"&&s!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,s,A,"setState")},ql.prototype.forceUpdate=function(s){this.updater.enqueueForceUpdate(this,s,"forceUpdate")};function Mt(){}Mt.prototype=ql.prototype;function ht(s,A,D){this.props=s,this.context=A,this.refs=jl,this.updater=D||il}var ul=ht.prototype=new Mt;ul.constructor=ht,Ol(ul,ql.prototype),ul.isPureReactComponent=!0;var sl=Array.isArray,Z={H:null,A:null,T:null,S:null,V:null},P=Object.prototype.hasOwnProperty;function zl(s,A,D,_,C,I){return D=I.ref,{$$typeof:z,type:s,key:A,ref:D!==void 0?D:null,props:I}}function Wl(s,A){return zl(s.type,A,void 0,void 0,void 0,s.props)}function St(s){return typeof s=="object"&&s!==null&&s.$$typeof===z}function Cu(s){var A={"=":"=0",":":"=2"};return"$"+s.replace(/[=:]/g,function(D){return A[D]})}var Ot=/\/+/g;function Yl(s,A){return typeof s=="object"&&s!==null&&s.key!=null?Cu(""+s.key):A.toString(36)}function vu(){}function hu(s){switch(s.status){case"fulfilled":return s.value;case"rejected":throw s.reason;default:switch(typeof s.status=="string"?s.then(vu,vu):(s.status="pending",s.then(function(A){s.status==="pending"&&(s.status="fulfilled",s.value=A)},function(A){s.status==="pending"&&(s.status="rejected",s.reason=A)})),s.status){case"fulfilled":return s.value;case"rejected":throw s.reason}}throw s}function Bl(s,A,D,_,C){var I=typeof s;(I==="undefined"||I==="boolean")&&(s=null);var X=!1;if(s===null)X=!0;else switch(I){case"bigint":case"string":case"number":X=!0;break;case"object":switch(s.$$typeof){case z:case $:X=!0;break;case R:return X=s._init,Bl(X(s._payload),A,D,_,C)}}if(X)return C=C(s),X=_===""?"."+Yl(s,0):_,sl(C)?(D="",X!=null&&(D=X.replace(Ot,"$&/")+"/"),Bl(C,A,D,"",function(Qt){return Qt})):C!=null&&(St(C)&&(C=Wl(C,D+(C.key==null||s&&s.key===C.key?"":(""+C.key).replace(Ot,"$&/")+"/")+X)),A.push(C)),1;X=0;var $l=_===""?".":_+":";if(sl(s))for(var hl=0;hl<s.length;hl++)_=s[hl],I=$l+Yl(_,hl),X+=Bl(_,A,D,I,C);else if(hl=N(s),typeof hl=="function")for(s=hl.call(s),hl=0;!(_=s.next()).done;)_=_.value,I=$l+Yl(_,hl++),X+=Bl(_,A,D,I,C);else if(I==="object"){if(typeof s.then=="function")return Bl(hu(s),A,D,_,C);throw A=String(s),Error("Objects are not valid as a React child (found: "+(A==="[object Object]"?"object with keys {"+Object.keys(s).join(", ")+"}":A)+"). If you meant to render a collection of children, use an array instead.")}return X}function S(s,A,D){if(s==null)return s;var _=[],C=0;return Bl(s,_,"","",function(I){return A.call(D,I,C++)}),_}function O(s){if(s._status===-1){var A=s._result;A=A(),A.then(function(D){(s._status===0||s._status===-1)&&(s._status=1,s._result=D)},function(D){(s._status===0||s._status===-1)&&(s._status=2,s._result=D)}),s._status===-1&&(s._status=0,s._result=A)}if(s._status===1)return s._result.default;throw s._result}var q=typeof reportError=="function"?reportError:function(s){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var A=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof s=="object"&&s!==null&&typeof s.message=="string"?String(s.message):String(s),error:s});if(!window.dispatchEvent(A))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",s);return}console.error(s)};function ol(){}return Q.Children={map:S,forEach:function(s,A,D){S(s,function(){A.apply(this,arguments)},D)},count:function(s){var A=0;return S(s,function(){A++}),A},toArray:function(s){return S(s,function(A){return A})||[]},only:function(s){if(!St(s))throw Error("React.Children.only expected to receive a single React element child.");return s}},Q.Component=ql,Q.Fragment=V,Q.Profiler=G,Q.PureComponent=ht,Q.StrictMode=m,Q.Suspense=p,Q.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=Z,Q.__COMPILER_RUNTIME={__proto__:null,c:function(s){return Z.H.useMemoCache(s)}},Q.cache=function(s){return function(){return s.apply(null,arguments)}},Q.cloneElement=function(s,A,D){if(s==null)throw Error("The argument must be a React element, but you passed "+s+".");var _=Ol({},s.props),C=s.key,I=void 0;if(A!=null)for(X in A.ref!==void 0&&(I=void 0),A.key!==void 0&&(C=""+A.key),A)!P.call(A,X)||X==="key"||X==="__self"||X==="__source"||X==="ref"&&A.ref===void 0||(_[X]=A[X]);var X=arguments.length-2;if(X===1)_.children=D;else if(1<X){for(var $l=Array(X),hl=0;hl<X;hl++)$l[hl]=arguments[hl+2];_.children=$l}return zl(s.type,C,void 0,void 0,I,_)},Q.createContext=function(s){return s={$$typeof:F,_currentValue:s,_currentValue2:s,_threadCount:0,Provider:null,Consumer:null},s.Provider=s,s.Consumer={$$typeof:B,_context:s},s},Q.createElement=function(s,A,D){var _,C={},I=null;if(A!=null)for(_ in A.key!==void 0&&(I=""+A.key),A)P.call(A,_)&&_!=="key"&&_!=="__self"&&_!=="__source"&&(C[_]=A[_]);var X=arguments.length-2;if(X===1)C.children=D;else if(1<X){for(var $l=Array(X),hl=0;hl<X;hl++)$l[hl]=arguments[hl+2];C.children=$l}if(s&&s.defaultProps)for(_ in X=s.defaultProps,X)C[_]===void 0&&(C[_]=X[_]);return zl(s,I,void 0,void 0,null,C)},Q.createRef=function(){return{current:null}},Q.forwardRef=function(s){return{$$typeof:rl,render:s}},Q.isValidElement=St,Q.lazy=function(s){return{$$typeof:R,_payload:{_status:-1,_result:s},_init:O}},Q.memo=function(s,A){return{$$typeof:E,type:s,compare:A===void 0?null:A}},Q.startTransition=function(s){var A=Z.T,D={};Z.T=D;try{var _=s(),C=Z.S;C!==null&&C(D,_),typeof _=="object"&&_!==null&&typeof _.then=="function"&&_.then(ol,q)}catch(I){q(I)}finally{Z.T=A}},Q.unstable_useCacheRefresh=function(){return Z.H.useCacheRefresh()},Q.use=function(s){return Z.H.use(s)},Q.useActionState=function(s,A,D){return Z.H.useActionState(s,A,D)},Q.useCallback=function(s,A){return Z.H.useCallback(s,A)},Q.useContext=function(s){return Z.H.useContext(s)},Q.useDebugValue=function(){},Q.useDeferredValue=function(s,A){return Z.H.useDeferredValue(s,A)},Q.useEffect=function(s,A,D){var _=Z.H;if(typeof D=="function")throw Error("useEffect CRUD overload is not enabled in this build of React.");return _.useEffect(s,A)},Q.useId=function(){return Z.H.useId()},Q.useImperativeHandle=function(s,A,D){return Z.H.useImperativeHandle(s,A,D)},Q.useInsertionEffect=function(s,A){return Z.H.useInsertionEffect(s,A)},Q.useLayoutEffect=function(s,A){return Z.H.useLayoutEffect(s,A)},Q.useMemo=function(s,A){return Z.H.useMemo(s,A)},Q.useOptimistic=function(s,A){return Z.H.useOptimistic(s,A)},Q.useReducer=function(s,A,D){return Z.H.useReducer(s,A,D)},Q.useRef=function(s){return Z.H.useRef(s)},Q.useState=function(s){return Z.H.useState(s)},Q.useSyncExternalStore=function(s,A,D){return Z.H.useSyncExternalStore(s,A,D)},Q.useTransition=function(){return Z.H.useTransition()},Q.version="19.1.1",Q}var ls;function ei(){return ls||(ls=1,Pf.exports=x4()),Pf.exports}var xl=ei(),If={exports:{}},ge={},li={exports:{}},ti={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ts;function j4(){return ts||(ts=1,(function(z){function $(S,O){var q=S.length;S.push(O);l:for(;0<q;){var ol=q-1>>>1,s=S[ol];if(0<G(s,O))S[ol]=O,S[q]=s,q=ol;else break l}}function V(S){return S.length===0?null:S[0]}function m(S){if(S.length===0)return null;var O=S[0],q=S.pop();if(q!==O){S[0]=q;l:for(var ol=0,s=S.length,A=s>>>1;ol<A;){var D=2*(ol+1)-1,_=S[D],C=D+1,I=S[C];if(0>G(_,q))C<s&&0>G(I,_)?(S[ol]=I,S[C]=q,ol=C):(S[ol]=_,S[D]=q,ol=D);else if(C<s&&0>G(I,q))S[ol]=I,S[C]=q,ol=C;else break l}}return O}function G(S,O){var q=S.sortIndex-O.sortIndex;return q!==0?q:S.id-O.id}if(z.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var B=performance;z.unstable_now=function(){return B.now()}}else{var F=Date,rl=F.now();z.unstable_now=function(){return F.now()-rl}}var p=[],E=[],R=1,K=null,N=3,il=!1,Ol=!1,jl=!1,ql=!1,Mt=typeof setTimeout=="function"?setTimeout:null,ht=typeof clearTimeout=="function"?clearTimeout:null,ul=typeof setImmediate<"u"?setImmediate:null;function sl(S){for(var O=V(E);O!==null;){if(O.callback===null)m(E);else if(O.startTime<=S)m(E),O.sortIndex=O.expirationTime,$(p,O);else break;O=V(E)}}function Z(S){if(jl=!1,sl(S),!Ol)if(V(p)!==null)Ol=!0,P||(P=!0,Yl());else{var O=V(E);O!==null&&Bl(Z,O.startTime-S)}}var P=!1,zl=-1,Wl=5,St=-1;function Cu(){return ql?!0:!(z.unstable_now()-St<Wl)}function Ot(){if(ql=!1,P){var S=z.unstable_now();St=S;var O=!0;try{l:{Ol=!1,jl&&(jl=!1,ht(zl),zl=-1),il=!0;var q=N;try{t:{for(sl(S),K=V(p);K!==null&&!(K.expirationTime>S&&Cu());){var ol=K.callback;if(typeof ol=="function"){K.callback=null,N=K.priorityLevel;var s=ol(K.expirationTime<=S);if(S=z.unstable_now(),typeof s=="function"){K.callback=s,sl(S),O=!0;break t}K===V(p)&&m(p),sl(S)}else m(p);K=V(p)}if(K!==null)O=!0;else{var A=V(E);A!==null&&Bl(Z,A.startTime-S),O=!1}}break l}finally{K=null,N=q,il=!1}O=void 0}}finally{O?Yl():P=!1}}}var Yl;if(typeof ul=="function")Yl=function(){ul(Ot)};else if(typeof MessageChannel<"u"){var vu=new MessageChannel,hu=vu.port2;vu.port1.onmessage=Ot,Yl=function(){hu.postMessage(null)}}else Yl=function(){Mt(Ot,0)};function Bl(S,O){zl=Mt(function(){S(z.unstable_now())},O)}z.unstable_IdlePriority=5,z.unstable_ImmediatePriority=1,z.unstable_LowPriority=4,z.unstable_NormalPriority=3,z.unstable_Profiling=null,z.unstable_UserBlockingPriority=2,z.unstable_cancelCallback=function(S){S.callback=null},z.unstable_forceFrameRate=function(S){0>S||125<S?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):Wl=0<S?Math.floor(1e3/S):5},z.unstable_getCurrentPriorityLevel=function(){return N},z.unstable_next=function(S){switch(N){case 1:case 2:case 3:var O=3;break;default:O=N}var q=N;N=O;try{return S()}finally{N=q}},z.unstable_requestPaint=function(){ql=!0},z.unstable_runWithPriority=function(S,O){switch(S){case 1:case 2:case 3:case 4:case 5:break;default:S=3}var q=N;N=S;try{return O()}finally{N=q}},z.unstable_scheduleCallback=function(S,O,q){var ol=z.unstable_now();switch(typeof q=="object"&&q!==null?(q=q.delay,q=typeof q=="number"&&0<q?ol+q:ol):q=ol,S){case 1:var s=-1;break;case 2:s=250;break;case 5:s=1073741823;break;case 4:s=1e4;break;default:s=5e3}return s=q+s,S={id:R++,callback:O,priorityLevel:S,startTime:q,expirationTime:s,sortIndex:-1},q>ol?(S.sortIndex=q,$(E,S),V(p)===null&&S===V(E)&&(jl?(ht(zl),zl=-1):jl=!0,Bl(Z,q-ol))):(S.sortIndex=s,$(p,S),Ol||il||(Ol=!0,P||(P=!0,Yl()))),S},z.unstable_shouldYield=Cu,z.unstable_wrapCallback=function(S){var O=N;return function(){var q=N;N=O;try{return S.apply(this,arguments)}finally{N=q}}}})(ti)),ti}var us;function q4(){return us||(us=1,li.exports=j4()),li.exports}var ui={exports:{}},Zl={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var as;function Y4(){if(as)return Zl;as=1;var z=ei();function $(p){var E="https://react.dev/errors/"+p;if(1<arguments.length){E+="?args[]="+encodeURIComponent(arguments[1]);for(var R=2;R<arguments.length;R++)E+="&args[]="+encodeURIComponent(arguments[R])}return"Minified React error #"+p+"; visit "+E+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function V(){}var m={d:{f:V,r:function(){throw Error($(522))},D:V,C:V,L:V,m:V,X:V,S:V,M:V},p:0,findDOMNode:null},G=Symbol.for("react.portal");function B(p,E,R){var K=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:G,key:K==null?null:""+K,children:p,containerInfo:E,implementation:R}}var F=z.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function rl(p,E){if(p==="font")return"";if(typeof E=="string")return E==="use-credentials"?E:""}return Zl.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=m,Zl.createPortal=function(p,E){var R=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!E||E.nodeType!==1&&E.nodeType!==9&&E.nodeType!==11)throw Error($(299));return B(p,E,null,R)},Zl.flushSync=function(p){var E=F.T,R=m.p;try{if(F.T=null,m.p=2,p)return p()}finally{F.T=E,m.p=R,m.d.f()}},Zl.preconnect=function(p,E){typeof p=="string"&&(E?(E=E.crossOrigin,E=typeof E=="string"?E==="use-credentials"?E:"":void 0):E=null,m.d.C(p,E))},Zl.prefetchDNS=function(p){typeof p=="string"&&m.d.D(p)},Zl.preinit=function(p,E){if(typeof p=="string"&&E&&typeof E.as=="string"){var R=E.as,K=rl(R,E.crossOrigin),N=typeof E.integrity=="string"?E.integrity:void 0,il=typeof E.fetchPriority=="string"?E.fetchPriority:void 0;R==="style"?m.d.S(p,typeof E.precedence=="string"?E.precedence:void 0,{crossOrigin:K,integrity:N,fetchPriority:il}):R==="script"&&m.d.X(p,{crossOrigin:K,integrity:N,fetchPriority:il,nonce:typeof E.nonce=="string"?E.nonce:void 0})}},Zl.preinitModule=function(p,E){if(typeof p=="string")if(typeof E=="object"&&E!==null){if(E.as==null||E.as==="script"){var R=rl(E.as,E.crossOrigin);m.d.M(p,{crossOrigin:R,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0})}}else E==null&&m.d.M(p)},Zl.preload=function(p,E){if(typeof p=="string"&&typeof E=="object"&&E!==null&&typeof E.as=="string"){var R=E.as,K=rl(R,E.crossOrigin);m.d.L(p,R,{crossOrigin:K,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0,type:typeof E.type=="string"?E.type:void 0,fetchPriority:typeof E.fetchPriority=="string"?E.fetchPriority:void 0,referrerPolicy:typeof E.referrerPolicy=="string"?E.referrerPolicy:void 0,imageSrcSet:typeof E.imageSrcSet=="string"?E.imageSrcSet:void 0,imageSizes:typeof E.imageSizes=="string"?E.imageSizes:void 0,media:typeof E.media=="string"?E.media:void 0})}},Zl.preloadModule=function(p,E){if(typeof p=="string")if(E){var R=rl(E.as,E.crossOrigin);m.d.m(p,{as:typeof E.as=="string"&&E.as!=="script"?E.as:void 0,crossOrigin:R,integrity:typeof E.integrity=="string"?E.integrity:void 0})}else m.d.m(p)},Zl.requestFormReset=function(p){m.d.r(p)},Zl.unstable_batchedUpdates=function(p,E){return p(E)},Zl.useFormState=function(p,E,R){return F.H.useFormState(p,E,R)},Zl.useFormStatus=function(){return F.H.useHostTransitionStatus()},Zl.version="19.1.1",Zl}var es;function B4(){if(es)return ui.exports;es=1;function z(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(z)}catch($){console.error($)}}return z(),ui.exports=Y4(),ui.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ns;function G4(){if(ns)return ge;ns=1;var z=q4(),$=ei(),V=B4();function m(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var u=2;u<arguments.length;u++)t+="&args[]="+encodeURIComponent(arguments[u])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function G(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function B(l){var t=l,u=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(u=t.return),l=t.return;while(l)}return t.tag===3?u:null}function F(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function rl(l){if(B(l)!==l)throw Error(m(188))}function p(l){var t=l.alternate;if(!t){if(t=B(l),t===null)throw Error(m(188));return t!==l?null:l}for(var u=l,a=t;;){var e=u.return;if(e===null)break;var n=e.alternate;if(n===null){if(a=e.return,a!==null){u=a;continue}break}if(e.child===n.child){for(n=e.child;n;){if(n===u)return rl(e),l;if(n===a)return rl(e),t;n=n.sibling}throw Error(m(188))}if(u.return!==a.return)u=e,a=n;else{for(var c=!1,f=e.child;f;){if(f===u){c=!0,u=e,a=n;break}if(f===a){c=!0,a=e,u=n;break}f=f.sibling}if(!c){for(f=n.child;f;){if(f===u){c=!0,u=n,a=e;break}if(f===a){c=!0,a=n,u=e;break}f=f.sibling}if(!c)throw Error(m(189))}}if(u.alternate!==a)throw Error(m(190))}if(u.tag!==3)throw Error(m(188));return u.stateNode.current===u?l:t}function E(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=E(l),t!==null)return t;l=l.sibling}return null}var R=Object.assign,K=Symbol.for("react.element"),N=Symbol.for("react.transitional.element"),il=Symbol.for("react.portal"),Ol=Symbol.for("react.fragment"),jl=Symbol.for("react.strict_mode"),ql=Symbol.for("react.profiler"),Mt=Symbol.for("react.provider"),ht=Symbol.for("react.consumer"),ul=Symbol.for("react.context"),sl=Symbol.for("react.forward_ref"),Z=Symbol.for("react.suspense"),P=Symbol.for("react.suspense_list"),zl=Symbol.for("react.memo"),Wl=Symbol.for("react.lazy"),St=Symbol.for("react.activity"),Cu=Symbol.for("react.memo_cache_sentinel"),Ot=Symbol.iterator;function Yl(l){return l===null||typeof l!="object"?null:(l=Ot&&l[Ot]||l["@@iterator"],typeof l=="function"?l:null)}var vu=Symbol.for("react.client.reference");function hu(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===vu?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case Ol:return"Fragment";case ql:return"Profiler";case jl:return"StrictMode";case Z:return"Suspense";case P:return"SuspenseList";case St:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case il:return"Portal";case ul:return(l.displayName||"Context")+".Provider";case ht:return(l._context.displayName||"Context")+".Consumer";case sl:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case zl:return t=l.displayName||null,t!==null?t:hu(l.type)||"Memo";case Wl:t=l._payload,l=l._init;try{return hu(l(t))}catch{}}return null}var Bl=Array.isArray,S=$.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,O=V.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,q={pending:!1,data:null,method:null,action:null},ol=[],s=-1;function A(l){return{current:l}}function D(l){0>s||(l.current=ol[s],ol[s]=null,s--)}function _(l,t){s++,ol[s]=l.current,l.current=t}var C=A(null),I=A(null),X=A(null),$l=A(null);function hl(l,t){switch(_(X,t),_(I,l),_(C,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?M1(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=M1(t),l=O1(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}D(C),_(C,l)}function Qt(){D(C),D(I),D(X)}function jn(l){l.memoizedState!==null&&_($l,l);var t=C.current,u=O1(t,l.type);t!==u&&(_(I,l),_(C,u))}function Se(l){I.current===l&&(D(C),D(I)),$l.current===l&&(D($l),de._currentValue=q)}var qn=Object.prototype.hasOwnProperty,Yn=z.unstable_scheduleCallback,Bn=z.unstable_cancelCallback,ss=z.unstable_shouldYield,os=z.unstable_requestPaint,bt=z.unstable_now,ds=z.unstable_getCurrentPriorityLevel,ni=z.unstable_ImmediatePriority,ci=z.unstable_UserBlockingPriority,be=z.unstable_NormalPriority,rs=z.unstable_LowPriority,fi=z.unstable_IdlePriority,vs=z.log,hs=z.unstable_setDisableYieldValue,ba=null,kl=null;function Vt(l){if(typeof vs=="function"&&hs(l),kl&&typeof kl.setStrictMode=="function")try{kl.setStrictMode(ba,l)}catch{}}var Fl=Math.clz32?Math.clz32:gs,ys=Math.log,ms=Math.LN2;function gs(l){return l>>>=0,l===0?32:31-(ys(l)/ms|0)|0}var Ee=256,Te=4194304;function yu(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return l&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Ae(l,t,u){var a=l.pendingLanes;if(a===0)return 0;var e=0,n=l.suspendedLanes,c=l.pingedLanes;l=l.warmLanes;var f=a&134217727;return f!==0?(a=f&~n,a!==0?e=yu(a):(c&=f,c!==0?e=yu(c):u||(u=f&~l,u!==0&&(e=yu(u))))):(f=a&~n,f!==0?e=yu(f):c!==0?e=yu(c):u||(u=a&~l,u!==0&&(e=yu(u)))),e===0?0:t!==0&&t!==e&&(t&n)===0&&(n=e&-e,u=t&-t,n>=u||n===32&&(u&4194048)!==0)?t:e}function Ea(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function Ss(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function ii(){var l=Ee;return Ee<<=1,(Ee&4194048)===0&&(Ee=256),l}function si(){var l=Te;return Te<<=1,(Te&62914560)===0&&(Te=4194304),l}function Gn(l){for(var t=[],u=0;31>u;u++)t.push(l);return t}function Ta(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function bs(l,t,u,a,e,n){var c=l.pendingLanes;l.pendingLanes=u,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=u,l.entangledLanes&=u,l.errorRecoveryDisabledLanes&=u,l.shellSuspendCounter=0;var f=l.entanglements,i=l.expirationTimes,v=l.hiddenUpdates;for(u=c&~u;0<u;){var g=31-Fl(u),T=1<<g;f[g]=0,i[g]=-1;var h=v[g];if(h!==null)for(v[g]=null,g=0;g<h.length;g++){var y=h[g];y!==null&&(y.lane&=-536870913)}u&=~T}a!==0&&oi(l,a,0),n!==0&&e===0&&l.tag!==0&&(l.suspendedLanes|=n&~(c&~t))}function oi(l,t,u){l.pendingLanes|=t,l.suspendedLanes&=~t;var a=31-Fl(t);l.entangledLanes|=t,l.entanglements[a]=l.entanglements[a]|1073741824|u&4194090}function di(l,t){var u=l.entangledLanes|=t;for(l=l.entanglements;u;){var a=31-Fl(u),e=1<<a;e&t|l[a]&t&&(l[a]|=t),u&=~e}}function Xn(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function Zn(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function ri(){var l=O.p;return l!==0?l:(l=window.event,l===void 0?32:K1(l.type))}function Es(l,t){var u=O.p;try{return O.p=l,t()}finally{O.p=u}}var Lt=Math.random().toString(36).slice(2),Gl="__reactFiber$"+Lt,Vl="__reactProps$"+Lt,xu="__reactContainer$"+Lt,Qn="__reactEvents$"+Lt,Ts="__reactListeners$"+Lt,As="__reactHandles$"+Lt,vi="__reactResources$"+Lt,Aa="__reactMarker$"+Lt;function Vn(l){delete l[Gl],delete l[Vl],delete l[Qn],delete l[Ts],delete l[As]}function ju(l){var t=l[Gl];if(t)return t;for(var u=l.parentNode;u;){if(t=u[xu]||u[Gl]){if(u=t.alternate,t.child!==null||u!==null&&u.child!==null)for(l=R1(l);l!==null;){if(u=l[Gl])return u;l=R1(l)}return t}l=u,u=l.parentNode}return null}function qu(l){if(l=l[Gl]||l[xu]){var t=l.tag;if(t===5||t===6||t===13||t===26||t===27||t===3)return l}return null}function za(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(m(33))}function Yu(l){var t=l[vi];return t||(t=l[vi]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Dl(l){l[Aa]=!0}var hi=new Set,yi={};function mu(l,t){Bu(l,t),Bu(l+"Capture",t)}function Bu(l,t){for(yi[l]=t,l=0;l<t.length;l++)hi.add(t[l])}var zs=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),mi={},gi={};function _s(l){return qn.call(gi,l)?!0:qn.call(mi,l)?!1:zs.test(l)?gi[l]=!0:(mi[l]=!0,!1)}function ze(l,t,u){if(_s(t))if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+u)}}function _e(l,t,u){if(u===null)l.removeAttribute(t);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+u)}}function Dt(l,t,u,a){if(a===null)l.removeAttribute(u);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(u);return}l.setAttributeNS(t,u,""+a)}}var Ln,Si;function Gu(l){if(Ln===void 0)try{throw Error()}catch(u){var t=u.stack.trim().match(/\n( *(at )?)/);Ln=t&&t[1]||"",Si=-1<u.stack.indexOf(`
    at`)?" (<anonymous>)":-1<u.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Ln+l+Si}var Kn=!1;function Jn(l,t){if(!l||Kn)return"";Kn=!0;var u=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var T=function(){throw Error()};if(Object.defineProperty(T.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(T,[])}catch(y){var h=y}Reflect.construct(l,[],T)}else{try{T.call()}catch(y){h=y}l.call(T.prototype)}}else{try{throw Error()}catch(y){h=y}(T=l())&&typeof T.catch=="function"&&T.catch(function(){})}}catch(y){if(y&&h&&typeof y.stack=="string")return[y.stack,h.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var e=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");e&&e.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var n=a.DetermineComponentFrameRoot(),c=n[0],f=n[1];if(c&&f){var i=c.split(`
`),v=f.split(`
`);for(e=a=0;a<i.length&&!i[a].includes("DetermineComponentFrameRoot");)a++;for(;e<v.length&&!v[e].includes("DetermineComponentFrameRoot");)e++;if(a===i.length||e===v.length)for(a=i.length-1,e=v.length-1;1<=a&&0<=e&&i[a]!==v[e];)e--;for(;1<=a&&0<=e;a--,e--)if(i[a]!==v[e]){if(a!==1||e!==1)do if(a--,e--,0>e||i[a]!==v[e]){var g=`
`+i[a].replace(" at new "," at ");return l.displayName&&g.includes("<anonymous>")&&(g=g.replace("<anonymous>",l.displayName)),g}while(1<=a&&0<=e);break}}}finally{Kn=!1,Error.prepareStackTrace=u}return(u=l?l.displayName||l.name:"")?Gu(u):""}function Ms(l){switch(l.tag){case 26:case 27:case 5:return Gu(l.type);case 16:return Gu("Lazy");case 13:return Gu("Suspense");case 19:return Gu("SuspenseList");case 0:case 15:return Jn(l.type,!1);case 11:return Jn(l.type.render,!1);case 1:return Jn(l.type,!0);case 31:return Gu("Activity");default:return""}}function bi(l){try{var t="";do t+=Ms(l),l=l.return;while(l);return t}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}function nt(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function Ei(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function Os(l){var t=Ei(l)?"checked":"value",u=Object.getOwnPropertyDescriptor(l.constructor.prototype,t),a=""+l[t];if(!l.hasOwnProperty(t)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var e=u.get,n=u.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return e.call(this)},set:function(c){a=""+c,n.call(this,c)}}),Object.defineProperty(l,t,{enumerable:u.enumerable}),{getValue:function(){return a},setValue:function(c){a=""+c},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function Me(l){l._valueTracker||(l._valueTracker=Os(l))}function Ti(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var u=t.getValue(),a="";return l&&(a=Ei(l)?l.checked?"true":"false":l.value),l=a,l!==u?(t.setValue(l),!0):!1}function Oe(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var Ds=/[\n"\\]/g;function ct(l){return l.replace(Ds,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function wn(l,t,u,a,e,n,c,f){l.name="",c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.type=c:l.removeAttribute("type"),t!=null?c==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+nt(t)):l.value!==""+nt(t)&&(l.value=""+nt(t)):c!=="submit"&&c!=="reset"||l.removeAttribute("value"),t!=null?Wn(l,c,nt(t)):u!=null?Wn(l,c,nt(u)):a!=null&&l.removeAttribute("value"),e==null&&n!=null&&(l.defaultChecked=!!n),e!=null&&(l.checked=e&&typeof e!="function"&&typeof e!="symbol"),f!=null&&typeof f!="function"&&typeof f!="symbol"&&typeof f!="boolean"?l.name=""+nt(f):l.removeAttribute("name")}function Ai(l,t,u,a,e,n,c,f){if(n!=null&&typeof n!="function"&&typeof n!="symbol"&&typeof n!="boolean"&&(l.type=n),t!=null||u!=null){if(!(n!=="submit"&&n!=="reset"||t!=null))return;u=u!=null?""+nt(u):"",t=t!=null?""+nt(t):u,f||t===l.value||(l.value=t),l.defaultValue=t}a=a??e,a=typeof a!="function"&&typeof a!="symbol"&&!!a,l.checked=f?l.checked:!!a,l.defaultChecked=!!a,c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(l.name=c)}function Wn(l,t,u){t==="number"&&Oe(l.ownerDocument)===l||l.defaultValue===""+u||(l.defaultValue=""+u)}function Xu(l,t,u,a){if(l=l.options,t){t={};for(var e=0;e<u.length;e++)t["$"+u[e]]=!0;for(u=0;u<l.length;u++)e=t.hasOwnProperty("$"+l[u].value),l[u].selected!==e&&(l[u].selected=e),e&&a&&(l[u].defaultSelected=!0)}else{for(u=""+nt(u),t=null,e=0;e<l.length;e++){if(l[e].value===u){l[e].selected=!0,a&&(l[e].defaultSelected=!0);return}t!==null||l[e].disabled||(t=l[e])}t!==null&&(t.selected=!0)}}function zi(l,t,u){if(t!=null&&(t=""+nt(t),t!==l.value&&(l.value=t),u==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=u!=null?""+nt(u):""}function _i(l,t,u,a){if(t==null){if(a!=null){if(u!=null)throw Error(m(92));if(Bl(a)){if(1<a.length)throw Error(m(93));a=a[0]}u=a}u==null&&(u=""),t=u}u=nt(t),l.defaultValue=u,a=l.textContent,a===u&&a!==""&&a!==null&&(l.value=a)}function Zu(l,t){if(t){var u=l.firstChild;if(u&&u===l.lastChild&&u.nodeType===3){u.nodeValue=t;return}}l.textContent=t}var ps=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Mi(l,t,u){var a=t.indexOf("--")===0;u==null||typeof u=="boolean"||u===""?a?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":a?l.setProperty(t,u):typeof u!="number"||u===0||ps.has(t)?t==="float"?l.cssFloat=u:l[t]=(""+u).trim():l[t]=u+"px"}function Oi(l,t,u){if(t!=null&&typeof t!="object")throw Error(m(62));if(l=l.style,u!=null){for(var a in u)!u.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?l.setProperty(a,""):a==="float"?l.cssFloat="":l[a]="");for(var e in t)a=t[e],t.hasOwnProperty(e)&&u[e]!==a&&Mi(l,e,a)}else for(var n in t)t.hasOwnProperty(n)&&Mi(l,n,t[n])}function $n(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Us=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),Rs=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function De(l){return Rs.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}var kn=null;function Fn(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Qu=null,Vu=null;function Di(l){var t=qu(l);if(t&&(l=t.stateNode)){var u=l[Vl]||null;l:switch(l=t.stateNode,t.type){case"input":if(wn(l,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name),t=u.name,u.type==="radio"&&t!=null){for(u=l;u.parentNode;)u=u.parentNode;for(u=u.querySelectorAll('input[name="'+ct(""+t)+'"][type="radio"]'),t=0;t<u.length;t++){var a=u[t];if(a!==l&&a.form===l.form){var e=a[Vl]||null;if(!e)throw Error(m(90));wn(a,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name)}}for(t=0;t<u.length;t++)a=u[t],a.form===l.form&&Ti(a)}break l;case"textarea":zi(l,u.value,u.defaultValue);break l;case"select":t=u.value,t!=null&&Xu(l,!!u.multiple,t,!1)}}}var Pn=!1;function pi(l,t,u){if(Pn)return l(t,u);Pn=!0;try{var a=l(t);return a}finally{if(Pn=!1,(Qu!==null||Vu!==null)&&(vn(),Qu&&(t=Qu,l=Vu,Vu=Qu=null,Di(t),l)))for(t=0;t<l.length;t++)Di(l[t])}}function _a(l,t){var u=l.stateNode;if(u===null)return null;var a=u[Vl]||null;if(a===null)return null;u=a[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(l=l.type,a=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!a;break l;default:l=!1}if(l)return null;if(u&&typeof u!="function")throw Error(m(231,t,typeof u));return u}var pt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),In=!1;if(pt)try{var Ma={};Object.defineProperty(Ma,"passive",{get:function(){In=!0}}),window.addEventListener("test",Ma,Ma),window.removeEventListener("test",Ma,Ma)}catch{In=!1}var Kt=null,lc=null,pe=null;function Ui(){if(pe)return pe;var l,t=lc,u=t.length,a,e="value"in Kt?Kt.value:Kt.textContent,n=e.length;for(l=0;l<u&&t[l]===e[l];l++);var c=u-l;for(a=1;a<=c&&t[u-a]===e[n-a];a++);return pe=e.slice(l,1<a?1-a:void 0)}function Ue(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function Re(){return!0}function Ri(){return!1}function Ll(l){function t(u,a,e,n,c){this._reactName=u,this._targetInst=e,this.type=a,this.nativeEvent=n,this.target=c,this.currentTarget=null;for(var f in l)l.hasOwnProperty(f)&&(u=l[f],this[f]=u?u(n):n[f]);return this.isDefaultPrevented=(n.defaultPrevented!=null?n.defaultPrevented:n.returnValue===!1)?Re:Ri,this.isPropagationStopped=Ri,this}return R(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var u=this.nativeEvent;u&&(u.preventDefault?u.preventDefault():typeof u.returnValue!="unknown"&&(u.returnValue=!1),this.isDefaultPrevented=Re)},stopPropagation:function(){var u=this.nativeEvent;u&&(u.stopPropagation?u.stopPropagation():typeof u.cancelBubble!="unknown"&&(u.cancelBubble=!0),this.isPropagationStopped=Re)},persist:function(){},isPersistent:Re}),t}var gu={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Ne=Ll(gu),Oa=R({},gu,{view:0,detail:0}),Ns=Ll(Oa),tc,uc,Da,He=R({},Oa,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:ec,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Da&&(Da&&l.type==="mousemove"?(tc=l.screenX-Da.screenX,uc=l.screenY-Da.screenY):uc=tc=0,Da=l),tc)},movementY:function(l){return"movementY"in l?l.movementY:uc}}),Ni=Ll(He),Hs=R({},He,{dataTransfer:0}),Cs=Ll(Hs),xs=R({},Oa,{relatedTarget:0}),ac=Ll(xs),js=R({},gu,{animationName:0,elapsedTime:0,pseudoElement:0}),qs=Ll(js),Ys=R({},gu,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),Bs=Ll(Ys),Gs=R({},gu,{data:0}),Hi=Ll(Gs),Xs={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Zs={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Qs={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Vs(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=Qs[l])?!!t[l]:!1}function ec(){return Vs}var Ls=R({},Oa,{key:function(l){if(l.key){var t=Xs[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=Ue(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?Zs[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:ec,charCode:function(l){return l.type==="keypress"?Ue(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?Ue(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),Ks=Ll(Ls),Js=R({},He,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Ci=Ll(Js),ws=R({},Oa,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:ec}),Ws=Ll(ws),$s=R({},gu,{propertyName:0,elapsedTime:0,pseudoElement:0}),ks=Ll($s),Fs=R({},He,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),Ps=Ll(Fs),Is=R({},gu,{newState:0,oldState:0}),lo=Ll(Is),to=[9,13,27,32],nc=pt&&"CompositionEvent"in window,pa=null;pt&&"documentMode"in document&&(pa=document.documentMode);var uo=pt&&"TextEvent"in window&&!pa,xi=pt&&(!nc||pa&&8<pa&&11>=pa),ji=" ",qi=!1;function Yi(l,t){switch(l){case"keyup":return to.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Bi(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var Lu=!1;function ao(l,t){switch(l){case"compositionend":return Bi(t);case"keypress":return t.which!==32?null:(qi=!0,ji);case"textInput":return l=t.data,l===ji&&qi?null:l;default:return null}}function eo(l,t){if(Lu)return l==="compositionend"||!nc&&Yi(l,t)?(l=Ui(),pe=lc=Kt=null,Lu=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return xi&&t.locale!=="ko"?null:t.data;default:return null}}var no={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Gi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!no[l.type]:t==="textarea"}function Xi(l,t,u,a){Qu?Vu?Vu.push(a):Vu=[a]:Qu=a,t=bn(t,"onChange"),0<t.length&&(u=new Ne("onChange","change",null,u,a),l.push({event:u,listeners:t}))}var Ua=null,Ra=null;function co(l){E1(l,0)}function Ce(l){var t=za(l);if(Ti(t))return l}function Zi(l,t){if(l==="change")return t}var Qi=!1;if(pt){var cc;if(pt){var fc="oninput"in document;if(!fc){var Vi=document.createElement("div");Vi.setAttribute("oninput","return;"),fc=typeof Vi.oninput=="function"}cc=fc}else cc=!1;Qi=cc&&(!document.documentMode||9<document.documentMode)}function Li(){Ua&&(Ua.detachEvent("onpropertychange",Ki),Ra=Ua=null)}function Ki(l){if(l.propertyName==="value"&&Ce(Ra)){var t=[];Xi(t,Ra,l,Fn(l)),pi(co,t)}}function fo(l,t,u){l==="focusin"?(Li(),Ua=t,Ra=u,Ua.attachEvent("onpropertychange",Ki)):l==="focusout"&&Li()}function io(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return Ce(Ra)}function so(l,t){if(l==="click")return Ce(t)}function oo(l,t){if(l==="input"||l==="change")return Ce(t)}function ro(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var Pl=typeof Object.is=="function"?Object.is:ro;function Na(l,t){if(Pl(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var u=Object.keys(l),a=Object.keys(t);if(u.length!==a.length)return!1;for(a=0;a<u.length;a++){var e=u[a];if(!qn.call(t,e)||!Pl(l[e],t[e]))return!1}return!0}function Ji(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function wi(l,t){var u=Ji(l);l=0;for(var a;u;){if(u.nodeType===3){if(a=l+u.textContent.length,l<=t&&a>=t)return{node:u,offset:t-l};l=a}l:{for(;u;){if(u.nextSibling){u=u.nextSibling;break l}u=u.parentNode}u=void 0}u=Ji(u)}}function Wi(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?Wi(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function $i(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Oe(l.document);t instanceof l.HTMLIFrameElement;){try{var u=typeof t.contentWindow.location.href=="string"}catch{u=!1}if(u)l=t.contentWindow;else break;t=Oe(l.document)}return t}function ic(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var vo=pt&&"documentMode"in document&&11>=document.documentMode,Ku=null,sc=null,Ha=null,oc=!1;function ki(l,t,u){var a=u.window===u?u.document:u.nodeType===9?u:u.ownerDocument;oc||Ku==null||Ku!==Oe(a)||(a=Ku,"selectionStart"in a&&ic(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Ha&&Na(Ha,a)||(Ha=a,a=bn(sc,"onSelect"),0<a.length&&(t=new Ne("onSelect","select",null,t,u),l.push({event:t,listeners:a}),t.target=Ku)))}function Su(l,t){var u={};return u[l.toLowerCase()]=t.toLowerCase(),u["Webkit"+l]="webkit"+t,u["Moz"+l]="moz"+t,u}var Ju={animationend:Su("Animation","AnimationEnd"),animationiteration:Su("Animation","AnimationIteration"),animationstart:Su("Animation","AnimationStart"),transitionrun:Su("Transition","TransitionRun"),transitionstart:Su("Transition","TransitionStart"),transitioncancel:Su("Transition","TransitionCancel"),transitionend:Su("Transition","TransitionEnd")},dc={},Fi={};pt&&(Fi=document.createElement("div").style,"AnimationEvent"in window||(delete Ju.animationend.animation,delete Ju.animationiteration.animation,delete Ju.animationstart.animation),"TransitionEvent"in window||delete Ju.transitionend.transition);function bu(l){if(dc[l])return dc[l];if(!Ju[l])return l;var t=Ju[l],u;for(u in t)if(t.hasOwnProperty(u)&&u in Fi)return dc[l]=t[u];return l}var Pi=bu("animationend"),Ii=bu("animationiteration"),l0=bu("animationstart"),ho=bu("transitionrun"),yo=bu("transitionstart"),mo=bu("transitioncancel"),t0=bu("transitionend"),u0=new Map,rc="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");rc.push("scrollEnd");function yt(l,t){u0.set(l,t),mu(t,[l])}var a0=new WeakMap;function ft(l,t){if(typeof l=="object"&&l!==null){var u=a0.get(l);return u!==void 0?u:(t={value:l,source:t,stack:bi(t)},a0.set(l,t),t)}return{value:l,source:t,stack:bi(t)}}var it=[],wu=0,vc=0;function xe(){for(var l=wu,t=vc=wu=0;t<l;){var u=it[t];it[t++]=null;var a=it[t];it[t++]=null;var e=it[t];it[t++]=null;var n=it[t];if(it[t++]=null,a!==null&&e!==null){var c=a.pending;c===null?e.next=e:(e.next=c.next,c.next=e),a.pending=e}n!==0&&e0(u,e,n)}}function je(l,t,u,a){it[wu++]=l,it[wu++]=t,it[wu++]=u,it[wu++]=a,vc|=a,l.lanes|=a,l=l.alternate,l!==null&&(l.lanes|=a)}function hc(l,t,u,a){return je(l,t,u,a),qe(l)}function Wu(l,t){return je(l,null,null,t),qe(l)}function e0(l,t,u){l.lanes|=u;var a=l.alternate;a!==null&&(a.lanes|=u);for(var e=!1,n=l.return;n!==null;)n.childLanes|=u,a=n.alternate,a!==null&&(a.childLanes|=u),n.tag===22&&(l=n.stateNode,l===null||l._visibility&1||(e=!0)),l=n,n=n.return;return l.tag===3?(n=l.stateNode,e&&t!==null&&(e=31-Fl(u),l=n.hiddenUpdates,a=l[e],a===null?l[e]=[t]:a.push(t),t.lane=u|536870912),n):null}function qe(l){if(50<ae)throw ae=0,Tf=null,Error(m(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var $u={};function go(l,t,u,a){this.tag=l,this.key=u,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Il(l,t,u,a){return new go(l,t,u,a)}function yc(l){return l=l.prototype,!(!l||!l.isReactComponent)}function Ut(l,t){var u=l.alternate;return u===null?(u=Il(l.tag,t,l.key,l.mode),u.elementType=l.elementType,u.type=l.type,u.stateNode=l.stateNode,u.alternate=l,l.alternate=u):(u.pendingProps=t,u.type=l.type,u.flags=0,u.subtreeFlags=0,u.deletions=null),u.flags=l.flags&65011712,u.childLanes=l.childLanes,u.lanes=l.lanes,u.child=l.child,u.memoizedProps=l.memoizedProps,u.memoizedState=l.memoizedState,u.updateQueue=l.updateQueue,t=l.dependencies,u.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},u.sibling=l.sibling,u.index=l.index,u.ref=l.ref,u.refCleanup=l.refCleanup,u}function n0(l,t){l.flags&=65011714;var u=l.alternate;return u===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=u.childLanes,l.lanes=u.lanes,l.child=u.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=u.memoizedProps,l.memoizedState=u.memoizedState,l.updateQueue=u.updateQueue,l.type=u.type,t=u.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function Ye(l,t,u,a,e,n){var c=0;if(a=l,typeof l=="function")yc(l)&&(c=1);else if(typeof l=="string")c=b4(l,u,C.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case St:return l=Il(31,u,t,e),l.elementType=St,l.lanes=n,l;case Ol:return Eu(u.children,e,n,t);case jl:c=8,e|=24;break;case ql:return l=Il(12,u,t,e|2),l.elementType=ql,l.lanes=n,l;case Z:return l=Il(13,u,t,e),l.elementType=Z,l.lanes=n,l;case P:return l=Il(19,u,t,e),l.elementType=P,l.lanes=n,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case Mt:case ul:c=10;break l;case ht:c=9;break l;case sl:c=11;break l;case zl:c=14;break l;case Wl:c=16,a=null;break l}c=29,u=Error(m(130,l===null?"null":typeof l,"")),a=null}return t=Il(c,u,t,e),t.elementType=l,t.type=a,t.lanes=n,t}function Eu(l,t,u,a){return l=Il(7,l,a,t),l.lanes=u,l}function mc(l,t,u){return l=Il(6,l,null,t),l.lanes=u,l}function gc(l,t,u){return t=Il(4,l.children!==null?l.children:[],l.key,t),t.lanes=u,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var ku=[],Fu=0,Be=null,Ge=0,st=[],ot=0,Tu=null,Rt=1,Nt="";function Au(l,t){ku[Fu++]=Ge,ku[Fu++]=Be,Be=l,Ge=t}function c0(l,t,u){st[ot++]=Rt,st[ot++]=Nt,st[ot++]=Tu,Tu=l;var a=Rt;l=Nt;var e=32-Fl(a)-1;a&=~(1<<e),u+=1;var n=32-Fl(t)+e;if(30<n){var c=e-e%5;n=(a&(1<<c)-1).toString(32),a>>=c,e-=c,Rt=1<<32-Fl(t)+e|u<<e|a,Nt=n+l}else Rt=1<<n|u<<e|a,Nt=l}function Sc(l){l.return!==null&&(Au(l,1),c0(l,1,0))}function bc(l){for(;l===Be;)Be=ku[--Fu],ku[Fu]=null,Ge=ku[--Fu],ku[Fu]=null;for(;l===Tu;)Tu=st[--ot],st[ot]=null,Nt=st[--ot],st[ot]=null,Rt=st[--ot],st[ot]=null}var Ql=null,gl=null,tl=!1,zu=null,Et=!1,Ec=Error(m(519));function _u(l){var t=Error(m(418,""));throw ja(ft(t,l)),Ec}function f0(l){var t=l.stateNode,u=l.type,a=l.memoizedProps;switch(t[Gl]=l,t[Vl]=a,u){case"dialog":W("cancel",t),W("close",t);break;case"iframe":case"object":case"embed":W("load",t);break;case"video":case"audio":for(u=0;u<ne.length;u++)W(ne[u],t);break;case"source":W("error",t);break;case"img":case"image":case"link":W("error",t),W("load",t);break;case"details":W("toggle",t);break;case"input":W("invalid",t),Ai(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0),Me(t);break;case"select":W("invalid",t);break;case"textarea":W("invalid",t),_i(t,a.value,a.defaultValue,a.children),Me(t)}u=a.children,typeof u!="string"&&typeof u!="number"&&typeof u!="bigint"||t.textContent===""+u||a.suppressHydrationWarning===!0||_1(t.textContent,u)?(a.popover!=null&&(W("beforetoggle",t),W("toggle",t)),a.onScroll!=null&&W("scroll",t),a.onScrollEnd!=null&&W("scrollend",t),a.onClick!=null&&(t.onclick=En),t=!0):t=!1,t||_u(l)}function i0(l){for(Ql=l.return;Ql;)switch(Ql.tag){case 5:case 13:Et=!1;return;case 27:case 3:Et=!0;return;default:Ql=Ql.return}}function Ca(l){if(l!==Ql)return!1;if(!tl)return i0(l),tl=!0,!1;var t=l.tag,u;if((u=t!==3&&t!==27)&&((u=t===5)&&(u=l.type,u=!(u!=="form"&&u!=="button")||Yf(l.type,l.memoizedProps)),u=!u),u&&gl&&_u(l),i0(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(m(317));l:{for(l=l.nextSibling,t=0;l;){if(l.nodeType===8)if(u=l.data,u==="/$"){if(t===0){gl=gt(l.nextSibling);break l}t--}else u!=="$"&&u!=="$!"&&u!=="$?"||t++;l=l.nextSibling}gl=null}}else t===27?(t=gl,fu(l.type)?(l=Zf,Zf=null,gl=l):gl=t):gl=Ql?gt(l.stateNode.nextSibling):null;return!0}function xa(){gl=Ql=null,tl=!1}function s0(){var l=zu;return l!==null&&(wl===null?wl=l:wl.push.apply(wl,l),zu=null),l}function ja(l){zu===null?zu=[l]:zu.push(l)}var Tc=A(null),Mu=null,Ht=null;function Jt(l,t,u){_(Tc,t._currentValue),t._currentValue=u}function Ct(l){l._currentValue=Tc.current,D(Tc)}function Ac(l,t,u){for(;l!==null;){var a=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),l===u)break;l=l.return}}function zc(l,t,u,a){var e=l.child;for(e!==null&&(e.return=l);e!==null;){var n=e.dependencies;if(n!==null){var c=e.child;n=n.firstContext;l:for(;n!==null;){var f=n;n=e;for(var i=0;i<t.length;i++)if(f.context===t[i]){n.lanes|=u,f=n.alternate,f!==null&&(f.lanes|=u),Ac(n.return,u,l),a||(c=null);break l}n=f.next}}else if(e.tag===18){if(c=e.return,c===null)throw Error(m(341));c.lanes|=u,n=c.alternate,n!==null&&(n.lanes|=u),Ac(c,u,l),c=null}else c=e.child;if(c!==null)c.return=e;else for(c=e;c!==null;){if(c===l){c=null;break}if(e=c.sibling,e!==null){e.return=c.return,c=e;break}c=c.return}e=c}}function qa(l,t,u,a){l=null;for(var e=t,n=!1;e!==null;){if(!n){if((e.flags&524288)!==0)n=!0;else if((e.flags&262144)!==0)break}if(e.tag===10){var c=e.alternate;if(c===null)throw Error(m(387));if(c=c.memoizedProps,c!==null){var f=e.type;Pl(e.pendingProps.value,c.value)||(l!==null?l.push(f):l=[f])}}else if(e===$l.current){if(c=e.alternate,c===null)throw Error(m(387));c.memoizedState.memoizedState!==e.memoizedState.memoizedState&&(l!==null?l.push(de):l=[de])}e=e.return}l!==null&&zc(t,l,u,a),t.flags|=262144}function Xe(l){for(l=l.firstContext;l!==null;){if(!Pl(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ou(l){Mu=l,Ht=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function Xl(l){return o0(Mu,l)}function Ze(l,t){return Mu===null&&Ou(l),o0(l,t)}function o0(l,t){var u=t._currentValue;if(t={context:t,memoizedValue:u,next:null},Ht===null){if(l===null)throw Error(m(308));Ht=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Ht=Ht.next=t;return u}var So=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(u,a){l.push(a)}};this.abort=function(){t.aborted=!0,l.forEach(function(u){return u()})}},bo=z.unstable_scheduleCallback,Eo=z.unstable_NormalPriority,_l={$$typeof:ul,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function _c(){return{controller:new So,data:new Map,refCount:0}}function Ya(l){l.refCount--,l.refCount===0&&bo(Eo,function(){l.controller.abort()})}var Ba=null,Mc=0,Pu=0,Iu=null;function To(l,t){if(Ba===null){var u=Ba=[];Mc=0,Pu=pf(),Iu={status:"pending",value:void 0,then:function(a){u.push(a)}}}return Mc++,t.then(d0,d0),t}function d0(){if(--Mc===0&&Ba!==null){Iu!==null&&(Iu.status="fulfilled");var l=Ba;Ba=null,Pu=0,Iu=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function Ao(l,t){var u=[],a={status:"pending",value:null,reason:null,then:function(e){u.push(e)}};return l.then(function(){a.status="fulfilled",a.value=t;for(var e=0;e<u.length;e++)(0,u[e])(t)},function(e){for(a.status="rejected",a.reason=e,e=0;e<u.length;e++)(0,u[e])(void 0)}),a}var r0=S.S;S.S=function(l,t){typeof t=="object"&&t!==null&&typeof t.then=="function"&&To(l,t),r0!==null&&r0(l,t)};var Du=A(null);function Oc(){var l=Du.current;return l!==null?l:vl.pooledCache}function Qe(l,t){t===null?_(Du,Du.current):_(Du,t.pool)}function v0(){var l=Oc();return l===null?null:{parent:_l._currentValue,pool:l}}var Ga=Error(m(460)),h0=Error(m(474)),Ve=Error(m(542)),Dc={then:function(){}};function y0(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Le(){}function m0(l,t,u){switch(u=l[u],u===void 0?l.push(t):u!==t&&(t.then(Le,Le),t=u),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,S0(l),l;default:if(typeof t.status=="string")t.then(Le,Le);else{if(l=vl,l!==null&&100<l.shellSuspendCounter)throw Error(m(482));l=t,l.status="pending",l.then(function(a){if(t.status==="pending"){var e=t;e.status="fulfilled",e.value=a}},function(a){if(t.status==="pending"){var e=t;e.status="rejected",e.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,S0(l),l}throw Xa=t,Ga}}var Xa=null;function g0(){if(Xa===null)throw Error(m(459));var l=Xa;return Xa=null,l}function S0(l){if(l===Ga||l===Ve)throw Error(m(483))}var wt=!1;function pc(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Uc(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function Wt(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function $t(l,t,u){var a=l.updateQueue;if(a===null)return null;if(a=a.shared,(al&2)!==0){var e=a.pending;return e===null?t.next=t:(t.next=e.next,e.next=t),a.pending=t,t=qe(l),e0(l,null,u),t}return je(l,a,t,u),qe(l)}function Za(l,t,u){if(t=t.updateQueue,t!==null&&(t=t.shared,(u&4194048)!==0)){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,di(l,u)}}function Rc(l,t){var u=l.updateQueue,a=l.alternate;if(a!==null&&(a=a.updateQueue,u===a)){var e=null,n=null;if(u=u.firstBaseUpdate,u!==null){do{var c={lane:u.lane,tag:u.tag,payload:u.payload,callback:null,next:null};n===null?e=n=c:n=n.next=c,u=u.next}while(u!==null);n===null?e=n=t:n=n.next=t}else e=n=t;u={baseState:a.baseState,firstBaseUpdate:e,lastBaseUpdate:n,shared:a.shared,callbacks:a.callbacks},l.updateQueue=u;return}l=u.lastBaseUpdate,l===null?u.firstBaseUpdate=t:l.next=t,u.lastBaseUpdate=t}var Nc=!1;function Qa(){if(Nc){var l=Iu;if(l!==null)throw l}}function Va(l,t,u,a){Nc=!1;var e=l.updateQueue;wt=!1;var n=e.firstBaseUpdate,c=e.lastBaseUpdate,f=e.shared.pending;if(f!==null){e.shared.pending=null;var i=f,v=i.next;i.next=null,c===null?n=v:c.next=v,c=i;var g=l.alternate;g!==null&&(g=g.updateQueue,f=g.lastBaseUpdate,f!==c&&(f===null?g.firstBaseUpdate=v:f.next=v,g.lastBaseUpdate=i))}if(n!==null){var T=e.baseState;c=0,g=v=i=null,f=n;do{var h=f.lane&-536870913,y=h!==f.lane;if(y?(k&h)===h:(a&h)===h){h!==0&&h===Pu&&(Nc=!0),g!==null&&(g=g.next={lane:0,tag:f.tag,payload:f.payload,callback:null,next:null});l:{var Y=l,x=f;h=t;var fl=u;switch(x.tag){case 1:if(Y=x.payload,typeof Y=="function"){T=Y.call(fl,T,h);break l}T=Y;break l;case 3:Y.flags=Y.flags&-65537|128;case 0:if(Y=x.payload,h=typeof Y=="function"?Y.call(fl,T,h):Y,h==null)break l;T=R({},T,h);break l;case 2:wt=!0}}h=f.callback,h!==null&&(l.flags|=64,y&&(l.flags|=8192),y=e.callbacks,y===null?e.callbacks=[h]:y.push(h))}else y={lane:h,tag:f.tag,payload:f.payload,callback:f.callback,next:null},g===null?(v=g=y,i=T):g=g.next=y,c|=h;if(f=f.next,f===null){if(f=e.shared.pending,f===null)break;y=f,f=y.next,y.next=null,e.lastBaseUpdate=y,e.shared.pending=null}}while(!0);g===null&&(i=T),e.baseState=i,e.firstBaseUpdate=v,e.lastBaseUpdate=g,n===null&&(e.shared.lanes=0),au|=c,l.lanes=c,l.memoizedState=T}}function b0(l,t){if(typeof l!="function")throw Error(m(191,l));l.call(t)}function E0(l,t){var u=l.callbacks;if(u!==null)for(l.callbacks=null,l=0;l<u.length;l++)b0(u[l],t)}var la=A(null),Ke=A(0);function T0(l,t){l=Xt,_(Ke,l),_(la,t),Xt=l|t.baseLanes}function Hc(){_(Ke,Xt),_(la,la.current)}function Cc(){Xt=Ke.current,D(la),D(Ke)}var kt=0,L=null,nl=null,Tl=null,Je=!1,ta=!1,pu=!1,we=0,La=0,ua=null,zo=0;function bl(){throw Error(m(321))}function xc(l,t){if(t===null)return!1;for(var u=0;u<t.length&&u<l.length;u++)if(!Pl(l[u],t[u]))return!1;return!0}function jc(l,t,u,a,e,n){return kt=n,L=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,S.H=l===null||l.memoizedState===null?e2:n2,pu=!1,n=u(a,e),pu=!1,ta&&(n=z0(t,u,a,e)),A0(l),n}function A0(l){S.H=Ie;var t=nl!==null&&nl.next!==null;if(kt=0,Tl=nl=L=null,Je=!1,La=0,ua=null,t)throw Error(m(300));l===null||pl||(l=l.dependencies,l!==null&&Xe(l)&&(pl=!0))}function z0(l,t,u,a){L=l;var e=0;do{if(ta&&(ua=null),La=0,ta=!1,25<=e)throw Error(m(301));if(e+=1,Tl=nl=null,l.updateQueue!=null){var n=l.updateQueue;n.lastEffect=null,n.events=null,n.stores=null,n.memoCache!=null&&(n.memoCache.index=0)}S.H=Ro,n=t(u,a)}while(ta);return n}function _o(){var l=S.H,t=l.useState()[0];return t=typeof t.then=="function"?Ka(t):t,l=l.useState()[0],(nl!==null?nl.memoizedState:null)!==l&&(L.flags|=1024),t}function qc(){var l=we!==0;return we=0,l}function Yc(l,t,u){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~u}function Bc(l){if(Je){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}Je=!1}kt=0,Tl=nl=L=null,ta=!1,La=we=0,ua=null}function Kl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Tl===null?L.memoizedState=Tl=l:Tl=Tl.next=l,Tl}function Al(){if(nl===null){var l=L.alternate;l=l!==null?l.memoizedState:null}else l=nl.next;var t=Tl===null?L.memoizedState:Tl.next;if(t!==null)Tl=t,nl=l;else{if(l===null)throw L.alternate===null?Error(m(467)):Error(m(310));nl=l,l={memoizedState:nl.memoizedState,baseState:nl.baseState,baseQueue:nl.baseQueue,queue:nl.queue,next:null},Tl===null?L.memoizedState=Tl=l:Tl=Tl.next=l}return Tl}function Gc(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Ka(l){var t=La;return La+=1,ua===null&&(ua=[]),l=m0(ua,l,t),t=L,(Tl===null?t.memoizedState:Tl.next)===null&&(t=t.alternate,S.H=t===null||t.memoizedState===null?e2:n2),l}function We(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return Ka(l);if(l.$$typeof===ul)return Xl(l)}throw Error(m(438,String(l)))}function Xc(l){var t=null,u=L.updateQueue;if(u!==null&&(t=u.memoCache),t==null){var a=L.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(e){return e.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),u===null&&(u=Gc(),L.updateQueue=u),u.memoCache=t,u=t.data[t.index],u===void 0)for(u=t.data[t.index]=Array(l),a=0;a<l;a++)u[a]=Cu;return t.index++,u}function xt(l,t){return typeof t=="function"?t(l):t}function $e(l){var t=Al();return Zc(t,nl,l)}function Zc(l,t,u){var a=l.queue;if(a===null)throw Error(m(311));a.lastRenderedReducer=u;var e=l.baseQueue,n=a.pending;if(n!==null){if(e!==null){var c=e.next;e.next=n.next,n.next=c}t.baseQueue=e=n,a.pending=null}if(n=l.baseState,e===null)l.memoizedState=n;else{t=e.next;var f=c=null,i=null,v=t,g=!1;do{var T=v.lane&-536870913;if(T!==v.lane?(k&T)===T:(kt&T)===T){var h=v.revertLane;if(h===0)i!==null&&(i=i.next={lane:0,revertLane:0,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null}),T===Pu&&(g=!0);else if((kt&h)===h){v=v.next,h===Pu&&(g=!0);continue}else T={lane:0,revertLane:v.revertLane,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},i===null?(f=i=T,c=n):i=i.next=T,L.lanes|=h,au|=h;T=v.action,pu&&u(n,T),n=v.hasEagerState?v.eagerState:u(n,T)}else h={lane:T,revertLane:v.revertLane,action:v.action,hasEagerState:v.hasEagerState,eagerState:v.eagerState,next:null},i===null?(f=i=h,c=n):i=i.next=h,L.lanes|=T,au|=T;v=v.next}while(v!==null&&v!==t);if(i===null?c=n:i.next=f,!Pl(n,l.memoizedState)&&(pl=!0,g&&(u=Iu,u!==null)))throw u;l.memoizedState=n,l.baseState=c,l.baseQueue=i,a.lastRenderedState=n}return e===null&&(a.lanes=0),[l.memoizedState,a.dispatch]}function Qc(l){var t=Al(),u=t.queue;if(u===null)throw Error(m(311));u.lastRenderedReducer=l;var a=u.dispatch,e=u.pending,n=t.memoizedState;if(e!==null){u.pending=null;var c=e=e.next;do n=l(n,c.action),c=c.next;while(c!==e);Pl(n,t.memoizedState)||(pl=!0),t.memoizedState=n,t.baseQueue===null&&(t.baseState=n),u.lastRenderedState=n}return[n,a]}function _0(l,t,u){var a=L,e=Al(),n=tl;if(n){if(u===void 0)throw Error(m(407));u=u()}else u=t();var c=!Pl((nl||e).memoizedState,u);c&&(e.memoizedState=u,pl=!0),e=e.queue;var f=D0.bind(null,a,e,l);if(Ja(2048,8,f,[l]),e.getSnapshot!==t||c||Tl!==null&&Tl.memoizedState.tag&1){if(a.flags|=2048,aa(9,ke(),O0.bind(null,a,e,u,t),null),vl===null)throw Error(m(349));n||(kt&124)!==0||M0(a,t,u)}return u}function M0(l,t,u){l.flags|=16384,l={getSnapshot:t,value:u},t=L.updateQueue,t===null?(t=Gc(),L.updateQueue=t,t.stores=[l]):(u=t.stores,u===null?t.stores=[l]:u.push(l))}function O0(l,t,u,a){t.value=u,t.getSnapshot=a,p0(t)&&U0(l)}function D0(l,t,u){return u(function(){p0(t)&&U0(l)})}function p0(l){var t=l.getSnapshot;l=l.value;try{var u=t();return!Pl(l,u)}catch{return!0}}function U0(l){var t=Wu(l,2);t!==null&&et(t,l,2)}function Vc(l){var t=Kl();if(typeof l=="function"){var u=l;if(l=u(),pu){Vt(!0);try{u()}finally{Vt(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:xt,lastRenderedState:l},t}function R0(l,t,u,a){return l.baseState=u,Zc(l,nl,typeof a=="function"?a:xt)}function Mo(l,t,u,a,e){if(Pe(l))throw Error(m(485));if(l=t.action,l!==null){var n={payload:e,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(c){n.listeners.push(c)}};S.T!==null?u(!0):n.isTransition=!1,a(n),u=t.pending,u===null?(n.next=t.pending=n,N0(t,n)):(n.next=u.next,t.pending=u.next=n)}}function N0(l,t){var u=t.action,a=t.payload,e=l.state;if(t.isTransition){var n=S.T,c={};S.T=c;try{var f=u(e,a),i=S.S;i!==null&&i(c,f),H0(l,t,f)}catch(v){Lc(l,t,v)}finally{S.T=n}}else try{n=u(e,a),H0(l,t,n)}catch(v){Lc(l,t,v)}}function H0(l,t,u){u!==null&&typeof u=="object"&&typeof u.then=="function"?u.then(function(a){C0(l,t,a)},function(a){return Lc(l,t,a)}):C0(l,t,u)}function C0(l,t,u){t.status="fulfilled",t.value=u,x0(t),l.state=u,t=l.pending,t!==null&&(u=t.next,u===t?l.pending=null:(u=u.next,t.next=u,N0(l,u)))}function Lc(l,t,u){var a=l.pending;if(l.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=u,x0(t),t=t.next;while(t!==a)}l.action=null}function x0(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function j0(l,t){return t}function q0(l,t){if(tl){var u=vl.formState;if(u!==null){l:{var a=L;if(tl){if(gl){t:{for(var e=gl,n=Et;e.nodeType!==8;){if(!n){e=null;break t}if(e=gt(e.nextSibling),e===null){e=null;break t}}n=e.data,e=n==="F!"||n==="F"?e:null}if(e){gl=gt(e.nextSibling),a=e.data==="F!";break l}}_u(a)}a=!1}a&&(t=u[0])}}return u=Kl(),u.memoizedState=u.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:j0,lastRenderedState:t},u.queue=a,u=t2.bind(null,L,a),a.dispatch=u,a=Vc(!1),n=$c.bind(null,L,!1,a.queue),a=Kl(),e={state:t,dispatch:null,action:l,pending:null},a.queue=e,u=Mo.bind(null,L,e,n,u),e.dispatch=u,a.memoizedState=l,[t,u,!1]}function Y0(l){var t=Al();return B0(t,nl,l)}function B0(l,t,u){if(t=Zc(l,t,j0)[0],l=$e(xt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var a=Ka(t)}catch(c){throw c===Ga?Ve:c}else a=t;t=Al();var e=t.queue,n=e.dispatch;return u!==t.memoizedState&&(L.flags|=2048,aa(9,ke(),Oo.bind(null,e,u),null)),[a,n,l]}function Oo(l,t){l.action=t}function G0(l){var t=Al(),u=nl;if(u!==null)return B0(t,u,l);Al(),t=t.memoizedState,u=Al();var a=u.queue.dispatch;return u.memoizedState=l,[t,a,!1]}function aa(l,t,u,a){return l={tag:l,create:u,deps:a,inst:t,next:null},t=L.updateQueue,t===null&&(t=Gc(),L.updateQueue=t),u=t.lastEffect,u===null?t.lastEffect=l.next=l:(a=u.next,u.next=l,l.next=a,t.lastEffect=l),l}function ke(){return{destroy:void 0,resource:void 0}}function X0(){return Al().memoizedState}function Fe(l,t,u,a){var e=Kl();a=a===void 0?null:a,L.flags|=l,e.memoizedState=aa(1|t,ke(),u,a)}function Ja(l,t,u,a){var e=Al();a=a===void 0?null:a;var n=e.memoizedState.inst;nl!==null&&a!==null&&xc(a,nl.memoizedState.deps)?e.memoizedState=aa(t,n,u,a):(L.flags|=l,e.memoizedState=aa(1|t,n,u,a))}function Z0(l,t){Fe(8390656,8,l,t)}function Q0(l,t){Ja(2048,8,l,t)}function V0(l,t){return Ja(4,2,l,t)}function L0(l,t){return Ja(4,4,l,t)}function K0(l,t){if(typeof t=="function"){l=l();var u=t(l);return function(){typeof u=="function"?u():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function J0(l,t,u){u=u!=null?u.concat([l]):null,Ja(4,4,K0.bind(null,t,l),u)}function Kc(){}function w0(l,t){var u=Al();t=t===void 0?null:t;var a=u.memoizedState;return t!==null&&xc(t,a[1])?a[0]:(u.memoizedState=[l,t],l)}function W0(l,t){var u=Al();t=t===void 0?null:t;var a=u.memoizedState;if(t!==null&&xc(t,a[1]))return a[0];if(a=l(),pu){Vt(!0);try{l()}finally{Vt(!1)}}return u.memoizedState=[a,t],a}function Jc(l,t,u){return u===void 0||(kt&1073741824)!==0?l.memoizedState=t:(l.memoizedState=u,l=F2(),L.lanes|=l,au|=l,u)}function $0(l,t,u,a){return Pl(u,t)?u:la.current!==null?(l=Jc(l,u,a),Pl(l,t)||(pl=!0),l):(kt&42)===0?(pl=!0,l.memoizedState=u):(l=F2(),L.lanes|=l,au|=l,t)}function k0(l,t,u,a,e){var n=O.p;O.p=n!==0&&8>n?n:8;var c=S.T,f={};S.T=f,$c(l,!1,t,u);try{var i=e(),v=S.S;if(v!==null&&v(f,i),i!==null&&typeof i=="object"&&typeof i.then=="function"){var g=Ao(i,a);wa(l,t,g,at(l))}else wa(l,t,a,at(l))}catch(T){wa(l,t,{then:function(){},status:"rejected",reason:T},at())}finally{O.p=n,S.T=c}}function Do(){}function wc(l,t,u,a){if(l.tag!==5)throw Error(m(476));var e=F0(l).queue;k0(l,e,t,q,u===null?Do:function(){return P0(l),u(a)})}function F0(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:q,baseState:q,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:xt,lastRenderedState:q},next:null};var u={};return t.next={memoizedState:u,baseState:u,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:xt,lastRenderedState:u},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function P0(l){var t=F0(l).next.queue;wa(l,t,{},at())}function Wc(){return Xl(de)}function I0(){return Al().memoizedState}function l2(){return Al().memoizedState}function po(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var u=at();l=Wt(u);var a=$t(t,l,u);a!==null&&(et(a,t,u),Za(a,t,u)),t={cache:_c()},l.payload=t;return}t=t.return}}function Uo(l,t,u){var a=at();u={lane:a,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null},Pe(l)?u2(t,u):(u=hc(l,t,u,a),u!==null&&(et(u,l,a),a2(u,t,a)))}function t2(l,t,u){var a=at();wa(l,t,u,a)}function wa(l,t,u,a){var e={lane:a,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null};if(Pe(l))u2(t,e);else{var n=l.alternate;if(l.lanes===0&&(n===null||n.lanes===0)&&(n=t.lastRenderedReducer,n!==null))try{var c=t.lastRenderedState,f=n(c,u);if(e.hasEagerState=!0,e.eagerState=f,Pl(f,c))return je(l,t,e,0),vl===null&&xe(),!1}catch{}finally{}if(u=hc(l,t,e,a),u!==null)return et(u,l,a),a2(u,t,a),!0}return!1}function $c(l,t,u,a){if(a={lane:2,revertLane:pf(),action:a,hasEagerState:!1,eagerState:null,next:null},Pe(l)){if(t)throw Error(m(479))}else t=hc(l,u,a,2),t!==null&&et(t,l,2)}function Pe(l){var t=l.alternate;return l===L||t!==null&&t===L}function u2(l,t){ta=Je=!0;var u=l.pending;u===null?t.next=t:(t.next=u.next,u.next=t),l.pending=t}function a2(l,t,u){if((u&4194048)!==0){var a=t.lanes;a&=l.pendingLanes,u|=a,t.lanes=u,di(l,u)}}var Ie={readContext:Xl,use:We,useCallback:bl,useContext:bl,useEffect:bl,useImperativeHandle:bl,useLayoutEffect:bl,useInsertionEffect:bl,useMemo:bl,useReducer:bl,useRef:bl,useState:bl,useDebugValue:bl,useDeferredValue:bl,useTransition:bl,useSyncExternalStore:bl,useId:bl,useHostTransitionStatus:bl,useFormState:bl,useActionState:bl,useOptimistic:bl,useMemoCache:bl,useCacheRefresh:bl},e2={readContext:Xl,use:We,useCallback:function(l,t){return Kl().memoizedState=[l,t===void 0?null:t],l},useContext:Xl,useEffect:Z0,useImperativeHandle:function(l,t,u){u=u!=null?u.concat([l]):null,Fe(4194308,4,K0.bind(null,t,l),u)},useLayoutEffect:function(l,t){return Fe(4194308,4,l,t)},useInsertionEffect:function(l,t){Fe(4,2,l,t)},useMemo:function(l,t){var u=Kl();t=t===void 0?null:t;var a=l();if(pu){Vt(!0);try{l()}finally{Vt(!1)}}return u.memoizedState=[a,t],a},useReducer:function(l,t,u){var a=Kl();if(u!==void 0){var e=u(t);if(pu){Vt(!0);try{u(t)}finally{Vt(!1)}}}else e=t;return a.memoizedState=a.baseState=e,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:e},a.queue=l,l=l.dispatch=Uo.bind(null,L,l),[a.memoizedState,l]},useRef:function(l){var t=Kl();return l={current:l},t.memoizedState=l},useState:function(l){l=Vc(l);var t=l.queue,u=t2.bind(null,L,t);return t.dispatch=u,[l.memoizedState,u]},useDebugValue:Kc,useDeferredValue:function(l,t){var u=Kl();return Jc(u,l,t)},useTransition:function(){var l=Vc(!1);return l=k0.bind(null,L,l.queue,!0,!1),Kl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,u){var a=L,e=Kl();if(tl){if(u===void 0)throw Error(m(407));u=u()}else{if(u=t(),vl===null)throw Error(m(349));(k&124)!==0||M0(a,t,u)}e.memoizedState=u;var n={value:u,getSnapshot:t};return e.queue=n,Z0(D0.bind(null,a,n,l),[l]),a.flags|=2048,aa(9,ke(),O0.bind(null,a,n,u,t),null),u},useId:function(){var l=Kl(),t=vl.identifierPrefix;if(tl){var u=Nt,a=Rt;u=(a&~(1<<32-Fl(a)-1)).toString(32)+u,t="«"+t+"R"+u,u=we++,0<u&&(t+="H"+u.toString(32)),t+="»"}else u=zo++,t="«"+t+"r"+u.toString(32)+"»";return l.memoizedState=t},useHostTransitionStatus:Wc,useFormState:q0,useActionState:q0,useOptimistic:function(l){var t=Kl();t.memoizedState=t.baseState=l;var u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=u,t=$c.bind(null,L,!0,u),u.dispatch=t,[l,t]},useMemoCache:Xc,useCacheRefresh:function(){return Kl().memoizedState=po.bind(null,L)}},n2={readContext:Xl,use:We,useCallback:w0,useContext:Xl,useEffect:Q0,useImperativeHandle:J0,useInsertionEffect:V0,useLayoutEffect:L0,useMemo:W0,useReducer:$e,useRef:X0,useState:function(){return $e(xt)},useDebugValue:Kc,useDeferredValue:function(l,t){var u=Al();return $0(u,nl.memoizedState,l,t)},useTransition:function(){var l=$e(xt)[0],t=Al().memoizedState;return[typeof l=="boolean"?l:Ka(l),t]},useSyncExternalStore:_0,useId:I0,useHostTransitionStatus:Wc,useFormState:Y0,useActionState:Y0,useOptimistic:function(l,t){var u=Al();return R0(u,nl,l,t)},useMemoCache:Xc,useCacheRefresh:l2},Ro={readContext:Xl,use:We,useCallback:w0,useContext:Xl,useEffect:Q0,useImperativeHandle:J0,useInsertionEffect:V0,useLayoutEffect:L0,useMemo:W0,useReducer:Qc,useRef:X0,useState:function(){return Qc(xt)},useDebugValue:Kc,useDeferredValue:function(l,t){var u=Al();return nl===null?Jc(u,l,t):$0(u,nl.memoizedState,l,t)},useTransition:function(){var l=Qc(xt)[0],t=Al().memoizedState;return[typeof l=="boolean"?l:Ka(l),t]},useSyncExternalStore:_0,useId:I0,useHostTransitionStatus:Wc,useFormState:G0,useActionState:G0,useOptimistic:function(l,t){var u=Al();return nl!==null?R0(u,nl,l,t):(u.baseState=l,[l,u.queue.dispatch])},useMemoCache:Xc,useCacheRefresh:l2},ea=null,Wa=0;function ln(l){var t=Wa;return Wa+=1,ea===null&&(ea=[]),m0(ea,l,t)}function $a(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function tn(l,t){throw t.$$typeof===K?Error(m(525)):(l=Object.prototype.toString.call(t),Error(m(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function c2(l){var t=l._init;return t(l._payload)}function f2(l){function t(d,o){if(l){var r=d.deletions;r===null?(d.deletions=[o],d.flags|=16):r.push(o)}}function u(d,o){if(!l)return null;for(;o!==null;)t(d,o),o=o.sibling;return null}function a(d){for(var o=new Map;d!==null;)d.key!==null?o.set(d.key,d):o.set(d.index,d),d=d.sibling;return o}function e(d,o){return d=Ut(d,o),d.index=0,d.sibling=null,d}function n(d,o,r){return d.index=r,l?(r=d.alternate,r!==null?(r=r.index,r<o?(d.flags|=67108866,o):r):(d.flags|=67108866,o)):(d.flags|=1048576,o)}function c(d){return l&&d.alternate===null&&(d.flags|=67108866),d}function f(d,o,r,b){return o===null||o.tag!==6?(o=mc(r,d.mode,b),o.return=d,o):(o=e(o,r),o.return=d,o)}function i(d,o,r,b){var U=r.type;return U===Ol?g(d,o,r.props.children,b,r.key):o!==null&&(o.elementType===U||typeof U=="object"&&U!==null&&U.$$typeof===Wl&&c2(U)===o.type)?(o=e(o,r.props),$a(o,r),o.return=d,o):(o=Ye(r.type,r.key,r.props,null,d.mode,b),$a(o,r),o.return=d,o)}function v(d,o,r,b){return o===null||o.tag!==4||o.stateNode.containerInfo!==r.containerInfo||o.stateNode.implementation!==r.implementation?(o=gc(r,d.mode,b),o.return=d,o):(o=e(o,r.children||[]),o.return=d,o)}function g(d,o,r,b,U){return o===null||o.tag!==7?(o=Eu(r,d.mode,b,U),o.return=d,o):(o=e(o,r),o.return=d,o)}function T(d,o,r){if(typeof o=="string"&&o!==""||typeof o=="number"||typeof o=="bigint")return o=mc(""+o,d.mode,r),o.return=d,o;if(typeof o=="object"&&o!==null){switch(o.$$typeof){case N:return r=Ye(o.type,o.key,o.props,null,d.mode,r),$a(r,o),r.return=d,r;case il:return o=gc(o,d.mode,r),o.return=d,o;case Wl:var b=o._init;return o=b(o._payload),T(d,o,r)}if(Bl(o)||Yl(o))return o=Eu(o,d.mode,r,null),o.return=d,o;if(typeof o.then=="function")return T(d,ln(o),r);if(o.$$typeof===ul)return T(d,Ze(d,o),r);tn(d,o)}return null}function h(d,o,r,b){var U=o!==null?o.key:null;if(typeof r=="string"&&r!==""||typeof r=="number"||typeof r=="bigint")return U!==null?null:f(d,o,""+r,b);if(typeof r=="object"&&r!==null){switch(r.$$typeof){case N:return r.key===U?i(d,o,r,b):null;case il:return r.key===U?v(d,o,r,b):null;case Wl:return U=r._init,r=U(r._payload),h(d,o,r,b)}if(Bl(r)||Yl(r))return U!==null?null:g(d,o,r,b,null);if(typeof r.then=="function")return h(d,o,ln(r),b);if(r.$$typeof===ul)return h(d,o,Ze(d,r),b);tn(d,r)}return null}function y(d,o,r,b,U){if(typeof b=="string"&&b!==""||typeof b=="number"||typeof b=="bigint")return d=d.get(r)||null,f(o,d,""+b,U);if(typeof b=="object"&&b!==null){switch(b.$$typeof){case N:return d=d.get(b.key===null?r:b.key)||null,i(o,d,b,U);case il:return d=d.get(b.key===null?r:b.key)||null,v(o,d,b,U);case Wl:var J=b._init;return b=J(b._payload),y(d,o,r,b,U)}if(Bl(b)||Yl(b))return d=d.get(r)||null,g(o,d,b,U,null);if(typeof b.then=="function")return y(d,o,r,ln(b),U);if(b.$$typeof===ul)return y(d,o,r,Ze(o,b),U);tn(o,b)}return null}function Y(d,o,r,b){for(var U=null,J=null,H=o,j=o=0,Rl=null;H!==null&&j<r.length;j++){H.index>j?(Rl=H,H=null):Rl=H.sibling;var ll=h(d,H,r[j],b);if(ll===null){H===null&&(H=Rl);break}l&&H&&ll.alternate===null&&t(d,H),o=n(ll,o,j),J===null?U=ll:J.sibling=ll,J=ll,H=Rl}if(j===r.length)return u(d,H),tl&&Au(d,j),U;if(H===null){for(;j<r.length;j++)H=T(d,r[j],b),H!==null&&(o=n(H,o,j),J===null?U=H:J.sibling=H,J=H);return tl&&Au(d,j),U}for(H=a(H);j<r.length;j++)Rl=y(H,d,j,r[j],b),Rl!==null&&(l&&Rl.alternate!==null&&H.delete(Rl.key===null?j:Rl.key),o=n(Rl,o,j),J===null?U=Rl:J.sibling=Rl,J=Rl);return l&&H.forEach(function(ru){return t(d,ru)}),tl&&Au(d,j),U}function x(d,o,r,b){if(r==null)throw Error(m(151));for(var U=null,J=null,H=o,j=o=0,Rl=null,ll=r.next();H!==null&&!ll.done;j++,ll=r.next()){H.index>j?(Rl=H,H=null):Rl=H.sibling;var ru=h(d,H,ll.value,b);if(ru===null){H===null&&(H=Rl);break}l&&H&&ru.alternate===null&&t(d,H),o=n(ru,o,j),J===null?U=ru:J.sibling=ru,J=ru,H=Rl}if(ll.done)return u(d,H),tl&&Au(d,j),U;if(H===null){for(;!ll.done;j++,ll=r.next())ll=T(d,ll.value,b),ll!==null&&(o=n(ll,o,j),J===null?U=ll:J.sibling=ll,J=ll);return tl&&Au(d,j),U}for(H=a(H);!ll.done;j++,ll=r.next())ll=y(H,d,j,ll.value,b),ll!==null&&(l&&ll.alternate!==null&&H.delete(ll.key===null?j:ll.key),o=n(ll,o,j),J===null?U=ll:J.sibling=ll,J=ll);return l&&H.forEach(function(N4){return t(d,N4)}),tl&&Au(d,j),U}function fl(d,o,r,b){if(typeof r=="object"&&r!==null&&r.type===Ol&&r.key===null&&(r=r.props.children),typeof r=="object"&&r!==null){switch(r.$$typeof){case N:l:{for(var U=r.key;o!==null;){if(o.key===U){if(U=r.type,U===Ol){if(o.tag===7){u(d,o.sibling),b=e(o,r.props.children),b.return=d,d=b;break l}}else if(o.elementType===U||typeof U=="object"&&U!==null&&U.$$typeof===Wl&&c2(U)===o.type){u(d,o.sibling),b=e(o,r.props),$a(b,r),b.return=d,d=b;break l}u(d,o);break}else t(d,o);o=o.sibling}r.type===Ol?(b=Eu(r.props.children,d.mode,b,r.key),b.return=d,d=b):(b=Ye(r.type,r.key,r.props,null,d.mode,b),$a(b,r),b.return=d,d=b)}return c(d);case il:l:{for(U=r.key;o!==null;){if(o.key===U)if(o.tag===4&&o.stateNode.containerInfo===r.containerInfo&&o.stateNode.implementation===r.implementation){u(d,o.sibling),b=e(o,r.children||[]),b.return=d,d=b;break l}else{u(d,o);break}else t(d,o);o=o.sibling}b=gc(r,d.mode,b),b.return=d,d=b}return c(d);case Wl:return U=r._init,r=U(r._payload),fl(d,o,r,b)}if(Bl(r))return Y(d,o,r,b);if(Yl(r)){if(U=Yl(r),typeof U!="function")throw Error(m(150));return r=U.call(r),x(d,o,r,b)}if(typeof r.then=="function")return fl(d,o,ln(r),b);if(r.$$typeof===ul)return fl(d,o,Ze(d,r),b);tn(d,r)}return typeof r=="string"&&r!==""||typeof r=="number"||typeof r=="bigint"?(r=""+r,o!==null&&o.tag===6?(u(d,o.sibling),b=e(o,r),b.return=d,d=b):(u(d,o),b=mc(r,d.mode,b),b.return=d,d=b),c(d)):u(d,o)}return function(d,o,r,b){try{Wa=0;var U=fl(d,o,r,b);return ea=null,U}catch(H){if(H===Ga||H===Ve)throw H;var J=Il(29,H,null,d.mode);return J.lanes=b,J.return=d,J}finally{}}}var na=f2(!0),i2=f2(!1),dt=A(null),Tt=null;function Ft(l){var t=l.alternate;_(Ml,Ml.current&1),_(dt,l),Tt===null&&(t===null||la.current!==null||t.memoizedState!==null)&&(Tt=l)}function s2(l){if(l.tag===22){if(_(Ml,Ml.current),_(dt,l),Tt===null){var t=l.alternate;t!==null&&t.memoizedState!==null&&(Tt=l)}}else Pt()}function Pt(){_(Ml,Ml.current),_(dt,dt.current)}function jt(l){D(dt),Tt===l&&(Tt=null),D(Ml)}var Ml=A(0);function un(l){for(var t=l;t!==null;){if(t.tag===13){var u=t.memoizedState;if(u!==null&&(u=u.dehydrated,u===null||u.data==="$?"||Xf(u)))return t}else if(t.tag===19&&t.memoizedProps.revealOrder!==void 0){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}function kc(l,t,u,a){t=l.memoizedState,u=u(a,t),u=u==null?t:R({},t,u),l.memoizedState=u,l.lanes===0&&(l.updateQueue.baseState=u)}var Fc={enqueueSetState:function(l,t,u){l=l._reactInternals;var a=at(),e=Wt(a);e.payload=t,u!=null&&(e.callback=u),t=$t(l,e,a),t!==null&&(et(t,l,a),Za(t,l,a))},enqueueReplaceState:function(l,t,u){l=l._reactInternals;var a=at(),e=Wt(a);e.tag=1,e.payload=t,u!=null&&(e.callback=u),t=$t(l,e,a),t!==null&&(et(t,l,a),Za(t,l,a))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var u=at(),a=Wt(u);a.tag=2,t!=null&&(a.callback=t),t=$t(l,a,u),t!==null&&(et(t,l,u),Za(t,l,u))}};function o2(l,t,u,a,e,n,c){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(a,n,c):t.prototype&&t.prototype.isPureReactComponent?!Na(u,a)||!Na(e,n):!0}function d2(l,t,u,a){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(u,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(u,a),t.state!==l&&Fc.enqueueReplaceState(t,t.state,null)}function Uu(l,t){var u=t;if("ref"in t){u={};for(var a in t)a!=="ref"&&(u[a]=t[a])}if(l=l.defaultProps){u===t&&(u=R({},u));for(var e in l)u[e]===void 0&&(u[e]=l[e])}return u}var an=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)};function r2(l){an(l)}function v2(l){console.error(l)}function h2(l){an(l)}function en(l,t){try{var u=l.onUncaughtError;u(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function y2(l,t,u){try{var a=l.onCaughtError;a(u.value,{componentStack:u.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(e){setTimeout(function(){throw e})}}function Pc(l,t,u){return u=Wt(u),u.tag=3,u.payload={element:null},u.callback=function(){en(l,t)},u}function m2(l){return l=Wt(l),l.tag=3,l}function g2(l,t,u,a){var e=u.type.getDerivedStateFromError;if(typeof e=="function"){var n=a.value;l.payload=function(){return e(n)},l.callback=function(){y2(t,u,a)}}var c=u.stateNode;c!==null&&typeof c.componentDidCatch=="function"&&(l.callback=function(){y2(t,u,a),typeof e!="function"&&(eu===null?eu=new Set([this]):eu.add(this));var f=a.stack;this.componentDidCatch(a.value,{componentStack:f!==null?f:""})})}function No(l,t,u,a,e){if(u.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=u.alternate,t!==null&&qa(t,u,e,!0),u=dt.current,u!==null){switch(u.tag){case 13:return Tt===null?zf():u.alternate===null&&Sl===0&&(Sl=3),u.flags&=-257,u.flags|=65536,u.lanes=e,a===Dc?u.flags|=16384:(t=u.updateQueue,t===null?u.updateQueue=new Set([a]):t.add(a),Mf(l,a,e)),!1;case 22:return u.flags|=65536,a===Dc?u.flags|=16384:(t=u.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},u.updateQueue=t):(u=t.retryQueue,u===null?t.retryQueue=new Set([a]):u.add(a)),Mf(l,a,e)),!1}throw Error(m(435,u.tag))}return Mf(l,a,e),zf(),!1}if(tl)return t=dt.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=e,a!==Ec&&(l=Error(m(422),{cause:a}),ja(ft(l,u)))):(a!==Ec&&(t=Error(m(423),{cause:a}),ja(ft(t,u))),l=l.current.alternate,l.flags|=65536,e&=-e,l.lanes|=e,a=ft(a,u),e=Pc(l.stateNode,a,e),Rc(l,e),Sl!==4&&(Sl=2)),!1;var n=Error(m(520),{cause:a});if(n=ft(n,u),ue===null?ue=[n]:ue.push(n),Sl!==4&&(Sl=2),t===null)return!0;a=ft(a,u),u=t;do{switch(u.tag){case 3:return u.flags|=65536,l=e&-e,u.lanes|=l,l=Pc(u.stateNode,a,l),Rc(u,l),!1;case 1:if(t=u.type,n=u.stateNode,(u.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||n!==null&&typeof n.componentDidCatch=="function"&&(eu===null||!eu.has(n))))return u.flags|=65536,e&=-e,u.lanes|=e,e=m2(e),g2(e,l,u,a),Rc(u,e),!1}u=u.return}while(u!==null);return!1}var S2=Error(m(461)),pl=!1;function Nl(l,t,u,a){t.child=l===null?i2(t,null,u,a):na(t,l.child,u,a)}function b2(l,t,u,a,e){u=u.render;var n=t.ref;if("ref"in a){var c={};for(var f in a)f!=="ref"&&(c[f]=a[f])}else c=a;return Ou(t),a=jc(l,t,u,c,n,e),f=qc(),l!==null&&!pl?(Yc(l,t,e),qt(l,t,e)):(tl&&f&&Sc(t),t.flags|=1,Nl(l,t,a,e),t.child)}function E2(l,t,u,a,e){if(l===null){var n=u.type;return typeof n=="function"&&!yc(n)&&n.defaultProps===void 0&&u.compare===null?(t.tag=15,t.type=n,T2(l,t,n,a,e)):(l=Ye(u.type,null,a,t,t.mode,e),l.ref=t.ref,l.return=t,t.child=l)}if(n=l.child,!cf(l,e)){var c=n.memoizedProps;if(u=u.compare,u=u!==null?u:Na,u(c,a)&&l.ref===t.ref)return qt(l,t,e)}return t.flags|=1,l=Ut(n,a),l.ref=t.ref,l.return=t,t.child=l}function T2(l,t,u,a,e){if(l!==null){var n=l.memoizedProps;if(Na(n,a)&&l.ref===t.ref)if(pl=!1,t.pendingProps=a=n,cf(l,e))(l.flags&131072)!==0&&(pl=!0);else return t.lanes=l.lanes,qt(l,t,e)}return Ic(l,t,u,a,e)}function A2(l,t,u){var a=t.pendingProps,e=a.children,n=l!==null?l.memoizedState:null;if(a.mode==="hidden"){if((t.flags&128)!==0){if(a=n!==null?n.baseLanes|u:u,l!==null){for(e=t.child=l.child,n=0;e!==null;)n=n|e.lanes|e.childLanes,e=e.sibling;t.childLanes=n&~a}else t.childLanes=0,t.child=null;return z2(l,t,a,u)}if((u&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&Qe(t,n!==null?n.cachePool:null),n!==null?T0(t,n):Hc(),s2(t);else return t.lanes=t.childLanes=536870912,z2(l,t,n!==null?n.baseLanes|u:u,u)}else n!==null?(Qe(t,n.cachePool),T0(t,n),Pt(),t.memoizedState=null):(l!==null&&Qe(t,null),Hc(),Pt());return Nl(l,t,e,u),t.child}function z2(l,t,u,a){var e=Oc();return e=e===null?null:{parent:_l._currentValue,pool:e},t.memoizedState={baseLanes:u,cachePool:e},l!==null&&Qe(t,null),Hc(),s2(t),l!==null&&qa(l,t,a,!0),null}function nn(l,t){var u=t.ref;if(u===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof u!="function"&&typeof u!="object")throw Error(m(284));(l===null||l.ref!==u)&&(t.flags|=4194816)}}function Ic(l,t,u,a,e){return Ou(t),u=jc(l,t,u,a,void 0,e),a=qc(),l!==null&&!pl?(Yc(l,t,e),qt(l,t,e)):(tl&&a&&Sc(t),t.flags|=1,Nl(l,t,u,e),t.child)}function _2(l,t,u,a,e,n){return Ou(t),t.updateQueue=null,u=z0(t,a,u,e),A0(l),a=qc(),l!==null&&!pl?(Yc(l,t,n),qt(l,t,n)):(tl&&a&&Sc(t),t.flags|=1,Nl(l,t,u,n),t.child)}function M2(l,t,u,a,e){if(Ou(t),t.stateNode===null){var n=$u,c=u.contextType;typeof c=="object"&&c!==null&&(n=Xl(c)),n=new u(a,n),t.memoizedState=n.state!==null&&n.state!==void 0?n.state:null,n.updater=Fc,t.stateNode=n,n._reactInternals=t,n=t.stateNode,n.props=a,n.state=t.memoizedState,n.refs={},pc(t),c=u.contextType,n.context=typeof c=="object"&&c!==null?Xl(c):$u,n.state=t.memoizedState,c=u.getDerivedStateFromProps,typeof c=="function"&&(kc(t,u,c,a),n.state=t.memoizedState),typeof u.getDerivedStateFromProps=="function"||typeof n.getSnapshotBeforeUpdate=="function"||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(c=n.state,typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount(),c!==n.state&&Fc.enqueueReplaceState(n,n.state,null),Va(t,a,n,e),Qa(),n.state=t.memoizedState),typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(l===null){n=t.stateNode;var f=t.memoizedProps,i=Uu(u,f);n.props=i;var v=n.context,g=u.contextType;c=$u,typeof g=="object"&&g!==null&&(c=Xl(g));var T=u.getDerivedStateFromProps;g=typeof T=="function"||typeof n.getSnapshotBeforeUpdate=="function",f=t.pendingProps!==f,g||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(f||v!==c)&&d2(t,n,a,c),wt=!1;var h=t.memoizedState;n.state=h,Va(t,a,n,e),Qa(),v=t.memoizedState,f||h!==v||wt?(typeof T=="function"&&(kc(t,u,T,a),v=t.memoizedState),(i=wt||o2(t,u,i,a,h,v,c))?(g||typeof n.UNSAFE_componentWillMount!="function"&&typeof n.componentWillMount!="function"||(typeof n.componentWillMount=="function"&&n.componentWillMount(),typeof n.UNSAFE_componentWillMount=="function"&&n.UNSAFE_componentWillMount()),typeof n.componentDidMount=="function"&&(t.flags|=4194308)):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=v),n.props=a,n.state=v,n.context=c,a=i):(typeof n.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{n=t.stateNode,Uc(l,t),c=t.memoizedProps,g=Uu(u,c),n.props=g,T=t.pendingProps,h=n.context,v=u.contextType,i=$u,typeof v=="object"&&v!==null&&(i=Xl(v)),f=u.getDerivedStateFromProps,(v=typeof f=="function"||typeof n.getSnapshotBeforeUpdate=="function")||typeof n.UNSAFE_componentWillReceiveProps!="function"&&typeof n.componentWillReceiveProps!="function"||(c!==T||h!==i)&&d2(t,n,a,i),wt=!1,h=t.memoizedState,n.state=h,Va(t,a,n,e),Qa();var y=t.memoizedState;c!==T||h!==y||wt||l!==null&&l.dependencies!==null&&Xe(l.dependencies)?(typeof f=="function"&&(kc(t,u,f,a),y=t.memoizedState),(g=wt||o2(t,u,g,a,h,y,i)||l!==null&&l.dependencies!==null&&Xe(l.dependencies))?(v||typeof n.UNSAFE_componentWillUpdate!="function"&&typeof n.componentWillUpdate!="function"||(typeof n.componentWillUpdate=="function"&&n.componentWillUpdate(a,y,i),typeof n.UNSAFE_componentWillUpdate=="function"&&n.UNSAFE_componentWillUpdate(a,y,i)),typeof n.componentDidUpdate=="function"&&(t.flags|=4),typeof n.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof n.componentDidUpdate!="function"||c===l.memoizedProps&&h===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||c===l.memoizedProps&&h===l.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=y),n.props=a,n.state=y,n.context=i,a=g):(typeof n.componentDidUpdate!="function"||c===l.memoizedProps&&h===l.memoizedState||(t.flags|=4),typeof n.getSnapshotBeforeUpdate!="function"||c===l.memoizedProps&&h===l.memoizedState||(t.flags|=1024),a=!1)}return n=a,nn(l,t),a=(t.flags&128)!==0,n||a?(n=t.stateNode,u=a&&typeof u.getDerivedStateFromError!="function"?null:n.render(),t.flags|=1,l!==null&&a?(t.child=na(t,l.child,null,e),t.child=na(t,null,u,e)):Nl(l,t,u,e),t.memoizedState=n.state,l=t.child):l=qt(l,t,e),l}function O2(l,t,u,a){return xa(),t.flags|=256,Nl(l,t,u,a),t.child}var lf={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function tf(l){return{baseLanes:l,cachePool:v0()}}function uf(l,t,u){return l=l!==null?l.childLanes&~u:0,t&&(l|=rt),l}function D2(l,t,u){var a=t.pendingProps,e=!1,n=(t.flags&128)!==0,c;if((c=n)||(c=l!==null&&l.memoizedState===null?!1:(Ml.current&2)!==0),c&&(e=!0,t.flags&=-129),c=(t.flags&32)!==0,t.flags&=-33,l===null){if(tl){if(e?Ft(t):Pt(),tl){var f=gl,i;if(i=f){l:{for(i=f,f=Et;i.nodeType!==8;){if(!f){f=null;break l}if(i=gt(i.nextSibling),i===null){f=null;break l}}f=i}f!==null?(t.memoizedState={dehydrated:f,treeContext:Tu!==null?{id:Rt,overflow:Nt}:null,retryLane:536870912,hydrationErrors:null},i=Il(18,null,null,0),i.stateNode=f,i.return=t,t.child=i,Ql=t,gl=null,i=!0):i=!1}i||_u(t)}if(f=t.memoizedState,f!==null&&(f=f.dehydrated,f!==null))return Xf(f)?t.lanes=32:t.lanes=536870912,null;jt(t)}return f=a.children,a=a.fallback,e?(Pt(),e=t.mode,f=cn({mode:"hidden",children:f},e),a=Eu(a,e,u,null),f.return=t,a.return=t,f.sibling=a,t.child=f,e=t.child,e.memoizedState=tf(u),e.childLanes=uf(l,c,u),t.memoizedState=lf,a):(Ft(t),af(t,f))}if(i=l.memoizedState,i!==null&&(f=i.dehydrated,f!==null)){if(n)t.flags&256?(Ft(t),t.flags&=-257,t=ef(l,t,u)):t.memoizedState!==null?(Pt(),t.child=l.child,t.flags|=128,t=null):(Pt(),e=a.fallback,f=t.mode,a=cn({mode:"visible",children:a.children},f),e=Eu(e,f,u,null),e.flags|=2,a.return=t,e.return=t,a.sibling=e,t.child=a,na(t,l.child,null,u),a=t.child,a.memoizedState=tf(u),a.childLanes=uf(l,c,u),t.memoizedState=lf,t=e);else if(Ft(t),Xf(f)){if(c=f.nextSibling&&f.nextSibling.dataset,c)var v=c.dgst;c=v,a=Error(m(419)),a.stack="",a.digest=c,ja({value:a,source:null,stack:null}),t=ef(l,t,u)}else if(pl||qa(l,t,u,!1),c=(u&l.childLanes)!==0,pl||c){if(c=vl,c!==null&&(a=u&-u,a=(a&42)!==0?1:Xn(a),a=(a&(c.suspendedLanes|u))!==0?0:a,a!==0&&a!==i.retryLane))throw i.retryLane=a,Wu(l,a),et(c,l,a),S2;f.data==="$?"||zf(),t=ef(l,t,u)}else f.data==="$?"?(t.flags|=192,t.child=l.child,t=null):(l=i.treeContext,gl=gt(f.nextSibling),Ql=t,tl=!0,zu=null,Et=!1,l!==null&&(st[ot++]=Rt,st[ot++]=Nt,st[ot++]=Tu,Rt=l.id,Nt=l.overflow,Tu=t),t=af(t,a.children),t.flags|=4096);return t}return e?(Pt(),e=a.fallback,f=t.mode,i=l.child,v=i.sibling,a=Ut(i,{mode:"hidden",children:a.children}),a.subtreeFlags=i.subtreeFlags&65011712,v!==null?e=Ut(v,e):(e=Eu(e,f,u,null),e.flags|=2),e.return=t,a.return=t,a.sibling=e,t.child=a,a=e,e=t.child,f=l.child.memoizedState,f===null?f=tf(u):(i=f.cachePool,i!==null?(v=_l._currentValue,i=i.parent!==v?{parent:v,pool:v}:i):i=v0(),f={baseLanes:f.baseLanes|u,cachePool:i}),e.memoizedState=f,e.childLanes=uf(l,c,u),t.memoizedState=lf,a):(Ft(t),u=l.child,l=u.sibling,u=Ut(u,{mode:"visible",children:a.children}),u.return=t,u.sibling=null,l!==null&&(c=t.deletions,c===null?(t.deletions=[l],t.flags|=16):c.push(l)),t.child=u,t.memoizedState=null,u)}function af(l,t){return t=cn({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function cn(l,t){return l=Il(22,l,null,t),l.lanes=0,l.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},l}function ef(l,t,u){return na(t,l.child,null,u),l=af(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function p2(l,t,u){l.lanes|=t;var a=l.alternate;a!==null&&(a.lanes|=t),Ac(l.return,t,u)}function nf(l,t,u,a,e){var n=l.memoizedState;n===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:u,tailMode:e}:(n.isBackwards=t,n.rendering=null,n.renderingStartTime=0,n.last=a,n.tail=u,n.tailMode=e)}function U2(l,t,u){var a=t.pendingProps,e=a.revealOrder,n=a.tail;if(Nl(l,t,a.children,u),a=Ml.current,(a&2)!==0)a=a&1|2,t.flags|=128;else{if(l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&p2(l,u,t);else if(l.tag===19)p2(l,u,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}a&=1}switch(_(Ml,a),e){case"forwards":for(u=t.child,e=null;u!==null;)l=u.alternate,l!==null&&un(l)===null&&(e=u),u=u.sibling;u=e,u===null?(e=t.child,t.child=null):(e=u.sibling,u.sibling=null),nf(t,!1,e,u,n);break;case"backwards":for(u=null,e=t.child,t.child=null;e!==null;){if(l=e.alternate,l!==null&&un(l)===null){t.child=e;break}l=e.sibling,e.sibling=u,u=e,e=l}nf(t,!0,u,null,n);break;case"together":nf(t,!1,null,null,void 0);break;default:t.memoizedState=null}return t.child}function qt(l,t,u){if(l!==null&&(t.dependencies=l.dependencies),au|=t.lanes,(u&t.childLanes)===0)if(l!==null){if(qa(l,t,u,!1),(u&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(m(153));if(t.child!==null){for(l=t.child,u=Ut(l,l.pendingProps),t.child=u,u.return=t;l.sibling!==null;)l=l.sibling,u=u.sibling=Ut(l,l.pendingProps),u.return=t;u.sibling=null}return t.child}function cf(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&Xe(l)))}function Ho(l,t,u){switch(t.tag){case 3:hl(t,t.stateNode.containerInfo),Jt(t,_l,l.memoizedState.cache),xa();break;case 27:case 5:jn(t);break;case 4:hl(t,t.stateNode.containerInfo);break;case 10:Jt(t,t.type,t.memoizedProps.value);break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(Ft(t),t.flags|=128,null):(u&t.child.childLanes)!==0?D2(l,t,u):(Ft(t),l=qt(l,t,u),l!==null?l.sibling:null);Ft(t);break;case 19:var e=(l.flags&128)!==0;if(a=(u&t.childLanes)!==0,a||(qa(l,t,u,!1),a=(u&t.childLanes)!==0),e){if(a)return U2(l,t,u);t.flags|=128}if(e=t.memoizedState,e!==null&&(e.rendering=null,e.tail=null,e.lastEffect=null),_(Ml,Ml.current),a)break;return null;case 22:case 23:return t.lanes=0,A2(l,t,u);case 24:Jt(t,_l,l.memoizedState.cache)}return qt(l,t,u)}function R2(l,t,u){if(l!==null)if(l.memoizedProps!==t.pendingProps)pl=!0;else{if(!cf(l,u)&&(t.flags&128)===0)return pl=!1,Ho(l,t,u);pl=(l.flags&131072)!==0}else pl=!1,tl&&(t.flags&1048576)!==0&&c0(t,Ge,t.index);switch(t.lanes=0,t.tag){case 16:l:{l=t.pendingProps;var a=t.elementType,e=a._init;if(a=e(a._payload),t.type=a,typeof a=="function")yc(a)?(l=Uu(a,l),t.tag=1,t=M2(null,t,a,l,u)):(t.tag=0,t=Ic(null,t,a,l,u));else{if(a!=null){if(e=a.$$typeof,e===sl){t.tag=11,t=b2(null,t,a,l,u);break l}else if(e===zl){t.tag=14,t=E2(null,t,a,l,u);break l}}throw t=hu(a)||a,Error(m(306,t,""))}}return t;case 0:return Ic(l,t,t.type,t.pendingProps,u);case 1:return a=t.type,e=Uu(a,t.pendingProps),M2(l,t,a,e,u);case 3:l:{if(hl(t,t.stateNode.containerInfo),l===null)throw Error(m(387));a=t.pendingProps;var n=t.memoizedState;e=n.element,Uc(l,t),Va(t,a,null,u);var c=t.memoizedState;if(a=c.cache,Jt(t,_l,a),a!==n.cache&&zc(t,[_l],u,!0),Qa(),a=c.element,n.isDehydrated)if(n={element:a,isDehydrated:!1,cache:c.cache},t.updateQueue.baseState=n,t.memoizedState=n,t.flags&256){t=O2(l,t,a,u);break l}else if(a!==e){e=ft(Error(m(424)),t),ja(e),t=O2(l,t,a,u);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(gl=gt(l.firstChild),Ql=t,tl=!0,zu=null,Et=!0,u=i2(t,null,a,u),t.child=u;u;)u.flags=u.flags&-3|4096,u=u.sibling}else{if(xa(),a===e){t=qt(l,t,u);break l}Nl(l,t,a,u)}t=t.child}return t;case 26:return nn(l,t),l===null?(u=x1(t.type,null,t.pendingProps,null))?t.memoizedState=u:tl||(u=t.type,l=t.pendingProps,a=Tn(X.current).createElement(u),a[Gl]=t,a[Vl]=l,Cl(a,u,l),Dl(a),t.stateNode=a):t.memoizedState=x1(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return jn(t),l===null&&tl&&(a=t.stateNode=N1(t.type,t.pendingProps,X.current),Ql=t,Et=!0,e=gl,fu(t.type)?(Zf=e,gl=gt(a.firstChild)):gl=e),Nl(l,t,t.pendingProps.children,u),nn(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&tl&&((e=a=gl)&&(a=c4(a,t.type,t.pendingProps,Et),a!==null?(t.stateNode=a,Ql=t,gl=gt(a.firstChild),Et=!1,e=!0):e=!1),e||_u(t)),jn(t),e=t.type,n=t.pendingProps,c=l!==null?l.memoizedProps:null,a=n.children,Yf(e,n)?a=null:c!==null&&Yf(e,c)&&(t.flags|=32),t.memoizedState!==null&&(e=jc(l,t,_o,null,null,u),de._currentValue=e),nn(l,t),Nl(l,t,a,u),t.child;case 6:return l===null&&tl&&((l=u=gl)&&(u=f4(u,t.pendingProps,Et),u!==null?(t.stateNode=u,Ql=t,gl=null,l=!0):l=!1),l||_u(t)),null;case 13:return D2(l,t,u);case 4:return hl(t,t.stateNode.containerInfo),a=t.pendingProps,l===null?t.child=na(t,null,a,u):Nl(l,t,a,u),t.child;case 11:return b2(l,t,t.type,t.pendingProps,u);case 7:return Nl(l,t,t.pendingProps,u),t.child;case 8:return Nl(l,t,t.pendingProps.children,u),t.child;case 12:return Nl(l,t,t.pendingProps.children,u),t.child;case 10:return a=t.pendingProps,Jt(t,t.type,a.value),Nl(l,t,a.children,u),t.child;case 9:return e=t.type._context,a=t.pendingProps.children,Ou(t),e=Xl(e),a=a(e),t.flags|=1,Nl(l,t,a,u),t.child;case 14:return E2(l,t,t.type,t.pendingProps,u);case 15:return T2(l,t,t.type,t.pendingProps,u);case 19:return U2(l,t,u);case 31:return a=t.pendingProps,u=t.mode,a={mode:a.mode,children:a.children},l===null?(u=cn(a,u),u.ref=t.ref,t.child=u,u.return=t,t=u):(u=Ut(l.child,a),u.ref=t.ref,t.child=u,u.return=t,t=u),t;case 22:return A2(l,t,u);case 24:return Ou(t),a=Xl(_l),l===null?(e=Oc(),e===null&&(e=vl,n=_c(),e.pooledCache=n,n.refCount++,n!==null&&(e.pooledCacheLanes|=u),e=n),t.memoizedState={parent:a,cache:e},pc(t),Jt(t,_l,e)):((l.lanes&u)!==0&&(Uc(l,t),Va(t,null,null,u),Qa()),e=l.memoizedState,n=t.memoizedState,e.parent!==a?(e={parent:a,cache:a},t.memoizedState=e,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=e),Jt(t,_l,a)):(a=n.cache,Jt(t,_l,a),a!==e.cache&&zc(t,[_l],u,!0))),Nl(l,t,t.pendingProps.children,u),t.child;case 29:throw t.pendingProps}throw Error(m(156,t.tag))}function Yt(l){l.flags|=4}function N2(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!G1(t)){if(t=dt.current,t!==null&&((k&4194048)===k?Tt!==null:(k&62914560)!==k&&(k&536870912)===0||t!==Tt))throw Xa=Dc,h0;l.flags|=8192}}function fn(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?si():536870912,l.lanes|=t,sa|=t)}function ka(l,t){if(!tl)switch(l.tailMode){case"hidden":t=l.tail;for(var u=null;t!==null;)t.alternate!==null&&(u=t),t=t.sibling;u===null?l.tail=null:u.sibling=null;break;case"collapsed":u=l.tail;for(var a=null;u!==null;)u.alternate!==null&&(a=u),u=u.sibling;a===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:a.sibling=null}}function ml(l){var t=l.alternate!==null&&l.alternate.child===l.child,u=0,a=0;if(t)for(var e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags&65011712,a|=e.flags&65011712,e.return=l,e=e.sibling;else for(e=l.child;e!==null;)u|=e.lanes|e.childLanes,a|=e.subtreeFlags,a|=e.flags,e.return=l,e=e.sibling;return l.subtreeFlags|=a,l.childLanes=u,t}function Co(l,t,u){var a=t.pendingProps;switch(bc(t),t.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return ml(t),null;case 1:return ml(t),null;case 3:return u=t.stateNode,a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Ct(_l),Qt(),u.pendingContext&&(u.context=u.pendingContext,u.pendingContext=null),(l===null||l.child===null)&&(Ca(t)?Yt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,s0())),ml(t),null;case 26:return u=t.memoizedState,l===null?(Yt(t),u!==null?(ml(t),N2(t,u)):(ml(t),t.flags&=-16777217)):u?u!==l.memoizedState?(Yt(t),ml(t),N2(t,u)):(ml(t),t.flags&=-16777217):(l.memoizedProps!==a&&Yt(t),ml(t),t.flags&=-16777217),null;case 27:Se(t),u=X.current;var e=t.type;if(l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(!a){if(t.stateNode===null)throw Error(m(166));return ml(t),null}l=C.current,Ca(t)?f0(t):(l=N1(e,a,u),t.stateNode=l,Yt(t))}return ml(t),null;case 5:if(Se(t),u=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(!a){if(t.stateNode===null)throw Error(m(166));return ml(t),null}if(l=C.current,Ca(t))f0(t);else{switch(e=Tn(X.current),l){case 1:l=e.createElementNS("http://www.w3.org/2000/svg",u);break;case 2:l=e.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;default:switch(u){case"svg":l=e.createElementNS("http://www.w3.org/2000/svg",u);break;case"math":l=e.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;case"script":l=e.createElement("div"),l.innerHTML="<script><\/script>",l=l.removeChild(l.firstChild);break;case"select":l=typeof a.is=="string"?e.createElement("select",{is:a.is}):e.createElement("select"),a.multiple?l.multiple=!0:a.size&&(l.size=a.size);break;default:l=typeof a.is=="string"?e.createElement(u,{is:a.is}):e.createElement(u)}}l[Gl]=t,l[Vl]=a;l:for(e=t.child;e!==null;){if(e.tag===5||e.tag===6)l.appendChild(e.stateNode);else if(e.tag!==4&&e.tag!==27&&e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break l;for(;e.sibling===null;){if(e.return===null||e.return===t)break l;e=e.return}e.sibling.return=e.return,e=e.sibling}t.stateNode=l;l:switch(Cl(l,u,a),u){case"button":case"input":case"select":case"textarea":l=!!a.autoFocus;break l;case"img":l=!0;break l;default:l=!1}l&&Yt(t)}}return ml(t),t.flags&=-16777217,null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(m(166));if(l=X.current,Ca(t)){if(l=t.stateNode,u=t.memoizedProps,a=null,e=Ql,e!==null)switch(e.tag){case 27:case 5:a=e.memoizedProps}l[Gl]=t,l=!!(l.nodeValue===u||a!==null&&a.suppressHydrationWarning===!0||_1(l.nodeValue,u)),l||_u(t)}else l=Tn(l).createTextNode(a),l[Gl]=t,t.stateNode=l}return ml(t),null;case 13:if(a=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(e=Ca(t),a!==null&&a.dehydrated!==null){if(l===null){if(!e)throw Error(m(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(m(317));e[Gl]=t}else xa(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;ml(t),e=!1}else e=s0(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),e=!0;if(!e)return t.flags&256?(jt(t),t):(jt(t),null)}if(jt(t),(t.flags&128)!==0)return t.lanes=u,t;if(u=a!==null,l=l!==null&&l.memoizedState!==null,u){a=t.child,e=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(e=a.alternate.memoizedState.cachePool.pool);var n=null;a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(n=a.memoizedState.cachePool.pool),n!==e&&(a.flags|=2048)}return u!==l&&u&&(t.child.flags|=8192),fn(t,t.updateQueue),ml(t),null;case 4:return Qt(),l===null&&Hf(t.stateNode.containerInfo),ml(t),null;case 10:return Ct(t.type),ml(t),null;case 19:if(D(Ml),e=t.memoizedState,e===null)return ml(t),null;if(a=(t.flags&128)!==0,n=e.rendering,n===null)if(a)ka(e,!1);else{if(Sl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(n=un(l),n!==null){for(t.flags|=128,ka(e,!1),l=n.updateQueue,t.updateQueue=l,fn(t,l),t.subtreeFlags=0,l=u,u=t.child;u!==null;)n0(u,l),u=u.sibling;return _(Ml,Ml.current&1|2),t.child}l=l.sibling}e.tail!==null&&bt()>dn&&(t.flags|=128,a=!0,ka(e,!1),t.lanes=4194304)}else{if(!a)if(l=un(n),l!==null){if(t.flags|=128,a=!0,l=l.updateQueue,t.updateQueue=l,fn(t,l),ka(e,!0),e.tail===null&&e.tailMode==="hidden"&&!n.alternate&&!tl)return ml(t),null}else 2*bt()-e.renderingStartTime>dn&&u!==536870912&&(t.flags|=128,a=!0,ka(e,!1),t.lanes=4194304);e.isBackwards?(n.sibling=t.child,t.child=n):(l=e.last,l!==null?l.sibling=n:t.child=n,e.last=n)}return e.tail!==null?(t=e.tail,e.rendering=t,e.tail=t.sibling,e.renderingStartTime=bt(),t.sibling=null,l=Ml.current,_(Ml,a?l&1|2:l&1),t):(ml(t),null);case 22:case 23:return jt(t),Cc(),a=t.memoizedState!==null,l!==null?l.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?(u&536870912)!==0&&(t.flags&128)===0&&(ml(t),t.subtreeFlags&6&&(t.flags|=8192)):ml(t),u=t.updateQueue,u!==null&&fn(t,u.retryQueue),u=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==u&&(t.flags|=2048),l!==null&&D(Du),null;case 24:return u=null,l!==null&&(u=l.memoizedState.cache),t.memoizedState.cache!==u&&(t.flags|=2048),Ct(_l),ml(t),null;case 25:return null;case 30:return null}throw Error(m(156,t.tag))}function xo(l,t){switch(bc(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Ct(_l),Qt(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return Se(t),null;case 13:if(jt(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(m(340));xa()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return D(Ml),null;case 4:return Qt(),null;case 10:return Ct(t.type),null;case 22:case 23:return jt(t),Cc(),l!==null&&D(Du),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Ct(_l),null;case 25:return null;default:return null}}function H2(l,t){switch(bc(t),t.tag){case 3:Ct(_l),Qt();break;case 26:case 27:case 5:Se(t);break;case 4:Qt();break;case 13:jt(t);break;case 19:D(Ml);break;case 10:Ct(t.type);break;case 22:case 23:jt(t),Cc(),l!==null&&D(Du);break;case 24:Ct(_l)}}function Fa(l,t){try{var u=t.updateQueue,a=u!==null?u.lastEffect:null;if(a!==null){var e=a.next;u=e;do{if((u.tag&l)===l){a=void 0;var n=u.create,c=u.inst;a=n(),c.destroy=a}u=u.next}while(u!==e)}}catch(f){dl(t,t.return,f)}}function It(l,t,u){try{var a=t.updateQueue,e=a!==null?a.lastEffect:null;if(e!==null){var n=e.next;a=n;do{if((a.tag&l)===l){var c=a.inst,f=c.destroy;if(f!==void 0){c.destroy=void 0,e=t;var i=u,v=f;try{v()}catch(g){dl(e,i,g)}}}a=a.next}while(a!==n)}}catch(g){dl(t,t.return,g)}}function C2(l){var t=l.updateQueue;if(t!==null){var u=l.stateNode;try{E0(t,u)}catch(a){dl(l,l.return,a)}}}function x2(l,t,u){u.props=Uu(l.type,l.memoizedProps),u.state=l.memoizedState;try{u.componentWillUnmount()}catch(a){dl(l,t,a)}}function Pa(l,t){try{var u=l.ref;if(u!==null){switch(l.tag){case 26:case 27:case 5:var a=l.stateNode;break;case 30:a=l.stateNode;break;default:a=l.stateNode}typeof u=="function"?l.refCleanup=u(a):u.current=a}}catch(e){dl(l,t,e)}}function At(l,t){var u=l.ref,a=l.refCleanup;if(u!==null)if(typeof a=="function")try{a()}catch(e){dl(l,t,e)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof u=="function")try{u(null)}catch(e){dl(l,t,e)}else u.current=null}function j2(l){var t=l.type,u=l.memoizedProps,a=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":u.autoFocus&&a.focus();break l;case"img":u.src?a.src=u.src:u.srcSet&&(a.srcset=u.srcSet)}}catch(e){dl(l,l.return,e)}}function ff(l,t,u){try{var a=l.stateNode;t4(a,l.type,u,t),a[Vl]=t}catch(e){dl(l,l.return,e)}}function q2(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&fu(l.type)||l.tag===4}function sf(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||q2(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&fu(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function of(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?(u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u).insertBefore(l,t):(t=u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u,t.appendChild(l),u=u._reactRootContainer,u!=null||t.onclick!==null||(t.onclick=En));else if(a!==4&&(a===27&&fu(l.type)&&(u=l.stateNode,t=null),l=l.child,l!==null))for(of(l,t,u),l=l.sibling;l!==null;)of(l,t,u),l=l.sibling}function sn(l,t,u){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?u.insertBefore(l,t):u.appendChild(l);else if(a!==4&&(a===27&&fu(l.type)&&(u=l.stateNode),l=l.child,l!==null))for(sn(l,t,u),l=l.sibling;l!==null;)sn(l,t,u),l=l.sibling}function Y2(l){var t=l.stateNode,u=l.memoizedProps;try{for(var a=l.type,e=t.attributes;e.length;)t.removeAttributeNode(e[0]);Cl(t,a,u),t[Gl]=l,t[Vl]=u}catch(n){dl(l,l.return,n)}}var Bt=!1,El=!1,df=!1,B2=typeof WeakSet=="function"?WeakSet:Set,Ul=null;function jo(l,t){if(l=l.containerInfo,jf=Dn,l=$i(l),ic(l)){if("selectionStart"in l)var u={start:l.selectionStart,end:l.selectionEnd};else l:{u=(u=l.ownerDocument)&&u.defaultView||window;var a=u.getSelection&&u.getSelection();if(a&&a.rangeCount!==0){u=a.anchorNode;var e=a.anchorOffset,n=a.focusNode;a=a.focusOffset;try{u.nodeType,n.nodeType}catch{u=null;break l}var c=0,f=-1,i=-1,v=0,g=0,T=l,h=null;t:for(;;){for(var y;T!==u||e!==0&&T.nodeType!==3||(f=c+e),T!==n||a!==0&&T.nodeType!==3||(i=c+a),T.nodeType===3&&(c+=T.nodeValue.length),(y=T.firstChild)!==null;)h=T,T=y;for(;;){if(T===l)break t;if(h===u&&++v===e&&(f=c),h===n&&++g===a&&(i=c),(y=T.nextSibling)!==null)break;T=h,h=T.parentNode}T=y}u=f===-1||i===-1?null:{start:f,end:i}}else u=null}u=u||{start:0,end:0}}else u=null;for(qf={focusedElem:l,selectionRange:u},Dn=!1,Ul=t;Ul!==null;)if(t=Ul,l=t.child,(t.subtreeFlags&1024)!==0&&l!==null)l.return=t,Ul=l;else for(;Ul!==null;){switch(t=Ul,n=t.alternate,l=t.flags,t.tag){case 0:break;case 11:case 15:break;case 1:if((l&1024)!==0&&n!==null){l=void 0,u=t,e=n.memoizedProps,n=n.memoizedState,a=u.stateNode;try{var Y=Uu(u.type,e,u.elementType===u.type);l=a.getSnapshotBeforeUpdate(Y,n),a.__reactInternalSnapshotBeforeUpdate=l}catch(x){dl(u,u.return,x)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,u=l.nodeType,u===9)Gf(l);else if(u===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":Gf(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(m(163))}if(l=t.sibling,l!==null){l.return=t.return,Ul=l;break}Ul=t.return}}function G2(l,t,u){var a=u.flags;switch(u.tag){case 0:case 11:case 15:lu(l,u),a&4&&Fa(5,u);break;case 1:if(lu(l,u),a&4)if(l=u.stateNode,t===null)try{l.componentDidMount()}catch(c){dl(u,u.return,c)}else{var e=Uu(u.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(e,t,l.__reactInternalSnapshotBeforeUpdate)}catch(c){dl(u,u.return,c)}}a&64&&C2(u),a&512&&Pa(u,u.return);break;case 3:if(lu(l,u),a&64&&(l=u.updateQueue,l!==null)){if(t=null,u.child!==null)switch(u.child.tag){case 27:case 5:t=u.child.stateNode;break;case 1:t=u.child.stateNode}try{E0(l,t)}catch(c){dl(u,u.return,c)}}break;case 27:t===null&&a&4&&Y2(u);case 26:case 5:lu(l,u),t===null&&a&4&&j2(u),a&512&&Pa(u,u.return);break;case 12:lu(l,u);break;case 13:lu(l,u),a&4&&Q2(l,u),a&64&&(l=u.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(u=Lo.bind(null,u),i4(l,u))));break;case 22:if(a=u.memoizedState!==null||Bt,!a){t=t!==null&&t.memoizedState!==null||El,e=Bt;var n=El;Bt=a,(El=t)&&!n?tu(l,u,(u.subtreeFlags&8772)!==0):lu(l,u),Bt=e,El=n}break;case 30:break;default:lu(l,u)}}function X2(l){var t=l.alternate;t!==null&&(l.alternate=null,X2(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&Vn(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var yl=null,Jl=!1;function Gt(l,t,u){for(u=u.child;u!==null;)Z2(l,t,u),u=u.sibling}function Z2(l,t,u){if(kl&&typeof kl.onCommitFiberUnmount=="function")try{kl.onCommitFiberUnmount(ba,u)}catch{}switch(u.tag){case 26:El||At(u,t),Gt(l,t,u),u.memoizedState?u.memoizedState.count--:u.stateNode&&(u=u.stateNode,u.parentNode.removeChild(u));break;case 27:El||At(u,t);var a=yl,e=Jl;fu(u.type)&&(yl=u.stateNode,Jl=!1),Gt(l,t,u),fe(u.stateNode),yl=a,Jl=e;break;case 5:El||At(u,t);case 6:if(a=yl,e=Jl,yl=null,Gt(l,t,u),yl=a,Jl=e,yl!==null)if(Jl)try{(yl.nodeType===9?yl.body:yl.nodeName==="HTML"?yl.ownerDocument.body:yl).removeChild(u.stateNode)}catch(n){dl(u,t,n)}else try{yl.removeChild(u.stateNode)}catch(n){dl(u,t,n)}break;case 18:yl!==null&&(Jl?(l=yl,U1(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,u.stateNode),ye(l)):U1(yl,u.stateNode));break;case 4:a=yl,e=Jl,yl=u.stateNode.containerInfo,Jl=!0,Gt(l,t,u),yl=a,Jl=e;break;case 0:case 11:case 14:case 15:El||It(2,u,t),El||It(4,u,t),Gt(l,t,u);break;case 1:El||(At(u,t),a=u.stateNode,typeof a.componentWillUnmount=="function"&&x2(u,t,a)),Gt(l,t,u);break;case 21:Gt(l,t,u);break;case 22:El=(a=El)||u.memoizedState!==null,Gt(l,t,u),El=a;break;default:Gt(l,t,u)}}function Q2(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{ye(l)}catch(u){dl(t,t.return,u)}}function qo(l){switch(l.tag){case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new B2),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new B2),t;default:throw Error(m(435,l.tag))}}function rf(l,t){var u=qo(l);t.forEach(function(a){var e=Ko.bind(null,l,a);u.has(a)||(u.add(a),a.then(e,e))})}function lt(l,t){var u=t.deletions;if(u!==null)for(var a=0;a<u.length;a++){var e=u[a],n=l,c=t,f=c;l:for(;f!==null;){switch(f.tag){case 27:if(fu(f.type)){yl=f.stateNode,Jl=!1;break l}break;case 5:yl=f.stateNode,Jl=!1;break l;case 3:case 4:yl=f.stateNode.containerInfo,Jl=!0;break l}f=f.return}if(yl===null)throw Error(m(160));Z2(n,c,e),yl=null,Jl=!1,n=e.alternate,n!==null&&(n.return=null),e.return=null}if(t.subtreeFlags&13878)for(t=t.child;t!==null;)V2(t,l),t=t.sibling}var mt=null;function V2(l,t){var u=l.alternate,a=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:lt(t,l),tt(l),a&4&&(It(3,l,l.return),Fa(3,l),It(5,l,l.return));break;case 1:lt(t,l),tt(l),a&512&&(El||u===null||At(u,u.return)),a&64&&Bt&&(l=l.updateQueue,l!==null&&(a=l.callbacks,a!==null&&(u=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=u===null?a:u.concat(a))));break;case 26:var e=mt;if(lt(t,l),tt(l),a&512&&(El||u===null||At(u,u.return)),a&4){var n=u!==null?u.memoizedState:null;if(a=l.memoizedState,u===null)if(a===null)if(l.stateNode===null){l:{a=l.type,u=l.memoizedProps,e=e.ownerDocument||e;t:switch(a){case"title":n=e.getElementsByTagName("title")[0],(!n||n[Aa]||n[Gl]||n.namespaceURI==="http://www.w3.org/2000/svg"||n.hasAttribute("itemprop"))&&(n=e.createElement(a),e.head.insertBefore(n,e.querySelector("head > title"))),Cl(n,a,u),n[Gl]=l,Dl(n),a=n;break l;case"link":var c=Y1("link","href",e).get(a+(u.href||""));if(c){for(var f=0;f<c.length;f++)if(n=c[f],n.getAttribute("href")===(u.href==null||u.href===""?null:u.href)&&n.getAttribute("rel")===(u.rel==null?null:u.rel)&&n.getAttribute("title")===(u.title==null?null:u.title)&&n.getAttribute("crossorigin")===(u.crossOrigin==null?null:u.crossOrigin)){c.splice(f,1);break t}}n=e.createElement(a),Cl(n,a,u),e.head.appendChild(n);break;case"meta":if(c=Y1("meta","content",e).get(a+(u.content||""))){for(f=0;f<c.length;f++)if(n=c[f],n.getAttribute("content")===(u.content==null?null:""+u.content)&&n.getAttribute("name")===(u.name==null?null:u.name)&&n.getAttribute("property")===(u.property==null?null:u.property)&&n.getAttribute("http-equiv")===(u.httpEquiv==null?null:u.httpEquiv)&&n.getAttribute("charset")===(u.charSet==null?null:u.charSet)){c.splice(f,1);break t}}n=e.createElement(a),Cl(n,a,u),e.head.appendChild(n);break;default:throw Error(m(468,a))}n[Gl]=l,Dl(n),a=n}l.stateNode=a}else B1(e,l.type,l.stateNode);else l.stateNode=q1(e,a,l.memoizedProps);else n!==a?(n===null?u.stateNode!==null&&(u=u.stateNode,u.parentNode.removeChild(u)):n.count--,a===null?B1(e,l.type,l.stateNode):q1(e,a,l.memoizedProps)):a===null&&l.stateNode!==null&&ff(l,l.memoizedProps,u.memoizedProps)}break;case 27:lt(t,l),tt(l),a&512&&(El||u===null||At(u,u.return)),u!==null&&a&4&&ff(l,l.memoizedProps,u.memoizedProps);break;case 5:if(lt(t,l),tt(l),a&512&&(El||u===null||At(u,u.return)),l.flags&32){e=l.stateNode;try{Zu(e,"")}catch(y){dl(l,l.return,y)}}a&4&&l.stateNode!=null&&(e=l.memoizedProps,ff(l,e,u!==null?u.memoizedProps:e)),a&1024&&(df=!0);break;case 6:if(lt(t,l),tt(l),a&4){if(l.stateNode===null)throw Error(m(162));a=l.memoizedProps,u=l.stateNode;try{u.nodeValue=a}catch(y){dl(l,l.return,y)}}break;case 3:if(_n=null,e=mt,mt=An(t.containerInfo),lt(t,l),mt=e,tt(l),a&4&&u!==null&&u.memoizedState.isDehydrated)try{ye(t.containerInfo)}catch(y){dl(l,l.return,y)}df&&(df=!1,L2(l));break;case 4:a=mt,mt=An(l.stateNode.containerInfo),lt(t,l),tt(l),mt=a;break;case 12:lt(t,l),tt(l);break;case 13:lt(t,l),tt(l),l.child.flags&8192&&l.memoizedState!==null!=(u!==null&&u.memoizedState!==null)&&(Sf=bt()),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,rf(l,a)));break;case 22:e=l.memoizedState!==null;var i=u!==null&&u.memoizedState!==null,v=Bt,g=El;if(Bt=v||e,El=g||i,lt(t,l),El=g,Bt=v,tt(l),a&8192)l:for(t=l.stateNode,t._visibility=e?t._visibility&-2:t._visibility|1,e&&(u===null||i||Bt||El||Ru(l)),u=null,t=l;;){if(t.tag===5||t.tag===26){if(u===null){i=u=t;try{if(n=i.stateNode,e)c=n.style,typeof c.setProperty=="function"?c.setProperty("display","none","important"):c.display="none";else{f=i.stateNode;var T=i.memoizedProps.style,h=T!=null&&T.hasOwnProperty("display")?T.display:null;f.style.display=h==null||typeof h=="boolean"?"":(""+h).trim()}}catch(y){dl(i,i.return,y)}}}else if(t.tag===6){if(u===null){i=t;try{i.stateNode.nodeValue=e?"":i.memoizedProps}catch(y){dl(i,i.return,y)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;u===t&&(u=null),t=t.return}u===t&&(u=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=l.updateQueue,a!==null&&(u=a.retryQueue,u!==null&&(a.retryQueue=null,rf(l,u))));break;case 19:lt(t,l),tt(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,rf(l,a)));break;case 30:break;case 21:break;default:lt(t,l),tt(l)}}function tt(l){var t=l.flags;if(t&2){try{for(var u,a=l.return;a!==null;){if(q2(a)){u=a;break}a=a.return}if(u==null)throw Error(m(160));switch(u.tag){case 27:var e=u.stateNode,n=sf(l);sn(l,n,e);break;case 5:var c=u.stateNode;u.flags&32&&(Zu(c,""),u.flags&=-33);var f=sf(l);sn(l,f,c);break;case 3:case 4:var i=u.stateNode.containerInfo,v=sf(l);of(l,v,i);break;default:throw Error(m(161))}}catch(g){dl(l,l.return,g)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function L2(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;L2(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function lu(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)G2(l,t.alternate,t),t=t.sibling}function Ru(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:It(4,t,t.return),Ru(t);break;case 1:At(t,t.return);var u=t.stateNode;typeof u.componentWillUnmount=="function"&&x2(t,t.return,u),Ru(t);break;case 27:fe(t.stateNode);case 26:case 5:At(t,t.return),Ru(t);break;case 22:t.memoizedState===null&&Ru(t);break;case 30:Ru(t);break;default:Ru(t)}l=l.sibling}}function tu(l,t,u){for(u=u&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,e=l,n=t,c=n.flags;switch(n.tag){case 0:case 11:case 15:tu(e,n,u),Fa(4,n);break;case 1:if(tu(e,n,u),a=n,e=a.stateNode,typeof e.componentDidMount=="function")try{e.componentDidMount()}catch(v){dl(a,a.return,v)}if(a=n,e=a.updateQueue,e!==null){var f=a.stateNode;try{var i=e.shared.hiddenCallbacks;if(i!==null)for(e.shared.hiddenCallbacks=null,e=0;e<i.length;e++)b0(i[e],f)}catch(v){dl(a,a.return,v)}}u&&c&64&&C2(n),Pa(n,n.return);break;case 27:Y2(n);case 26:case 5:tu(e,n,u),u&&a===null&&c&4&&j2(n),Pa(n,n.return);break;case 12:tu(e,n,u);break;case 13:tu(e,n,u),u&&c&4&&Q2(e,n);break;case 22:n.memoizedState===null&&tu(e,n,u),Pa(n,n.return);break;case 30:break;default:tu(e,n,u)}t=t.sibling}}function vf(l,t){var u=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(u=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==u&&(l!=null&&l.refCount++,u!=null&&Ya(u))}function hf(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ya(l))}function zt(l,t,u,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)K2(l,t,u,a),t=t.sibling}function K2(l,t,u,a){var e=t.flags;switch(t.tag){case 0:case 11:case 15:zt(l,t,u,a),e&2048&&Fa(9,t);break;case 1:zt(l,t,u,a);break;case 3:zt(l,t,u,a),e&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&Ya(l)));break;case 12:if(e&2048){zt(l,t,u,a),l=t.stateNode;try{var n=t.memoizedProps,c=n.id,f=n.onPostCommit;typeof f=="function"&&f(c,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(i){dl(t,t.return,i)}}else zt(l,t,u,a);break;case 13:zt(l,t,u,a);break;case 23:break;case 22:n=t.stateNode,c=t.alternate,t.memoizedState!==null?n._visibility&2?zt(l,t,u,a):Ia(l,t):n._visibility&2?zt(l,t,u,a):(n._visibility|=2,ca(l,t,u,a,(t.subtreeFlags&10256)!==0)),e&2048&&vf(c,t);break;case 24:zt(l,t,u,a),e&2048&&hf(t.alternate,t);break;default:zt(l,t,u,a)}}function ca(l,t,u,a,e){for(e=e&&(t.subtreeFlags&10256)!==0,t=t.child;t!==null;){var n=l,c=t,f=u,i=a,v=c.flags;switch(c.tag){case 0:case 11:case 15:ca(n,c,f,i,e),Fa(8,c);break;case 23:break;case 22:var g=c.stateNode;c.memoizedState!==null?g._visibility&2?ca(n,c,f,i,e):Ia(n,c):(g._visibility|=2,ca(n,c,f,i,e)),e&&v&2048&&vf(c.alternate,c);break;case 24:ca(n,c,f,i,e),e&&v&2048&&hf(c.alternate,c);break;default:ca(n,c,f,i,e)}t=t.sibling}}function Ia(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var u=l,a=t,e=a.flags;switch(a.tag){case 22:Ia(u,a),e&2048&&vf(a.alternate,a);break;case 24:Ia(u,a),e&2048&&hf(a.alternate,a);break;default:Ia(u,a)}t=t.sibling}}var le=8192;function fa(l){if(l.subtreeFlags&le)for(l=l.child;l!==null;)J2(l),l=l.sibling}function J2(l){switch(l.tag){case 26:fa(l),l.flags&le&&l.memoizedState!==null&&T4(mt,l.memoizedState,l.memoizedProps);break;case 5:fa(l);break;case 3:case 4:var t=mt;mt=An(l.stateNode.containerInfo),fa(l),mt=t;break;case 22:l.memoizedState===null&&(t=l.alternate,t!==null&&t.memoizedState!==null?(t=le,le=16777216,fa(l),le=t):fa(l));break;default:fa(l)}}function w2(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function te(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Ul=a,$2(a,l)}w2(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)W2(l),l=l.sibling}function W2(l){switch(l.tag){case 0:case 11:case 15:te(l),l.flags&2048&&It(9,l,l.return);break;case 3:te(l);break;case 12:te(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,on(l)):te(l);break;default:te(l)}}function on(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var u=0;u<t.length;u++){var a=t[u];Ul=a,$2(a,l)}w2(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:It(8,t,t.return),on(t);break;case 22:u=t.stateNode,u._visibility&2&&(u._visibility&=-3,on(t));break;default:on(t)}l=l.sibling}}function $2(l,t){for(;Ul!==null;){var u=Ul;switch(u.tag){case 0:case 11:case 15:It(8,u,t);break;case 23:case 22:if(u.memoizedState!==null&&u.memoizedState.cachePool!==null){var a=u.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:Ya(u.memoizedState.cache)}if(a=u.child,a!==null)a.return=u,Ul=a;else l:for(u=l;Ul!==null;){a=Ul;var e=a.sibling,n=a.return;if(X2(a),a===u){Ul=null;break l}if(e!==null){e.return=n,Ul=e;break l}Ul=n}}}var Yo={getCacheForType:function(l){var t=Xl(_l),u=t.data.get(l);return u===void 0&&(u=l(),t.data.set(l,u)),u}},Bo=typeof WeakMap=="function"?WeakMap:Map,al=0,vl=null,w=null,k=0,el=0,ut=null,uu=!1,ia=!1,yf=!1,Xt=0,Sl=0,au=0,Nu=0,mf=0,rt=0,sa=0,ue=null,wl=null,gf=!1,Sf=0,dn=1/0,rn=null,eu=null,Hl=0,nu=null,oa=null,da=0,bf=0,Ef=null,k2=null,ae=0,Tf=null;function at(){if((al&2)!==0&&k!==0)return k&-k;if(S.T!==null){var l=Pu;return l!==0?l:pf()}return ri()}function F2(){rt===0&&(rt=(k&536870912)===0||tl?ii():536870912);var l=dt.current;return l!==null&&(l.flags|=32),rt}function et(l,t,u){(l===vl&&(el===2||el===9)||l.cancelPendingCommit!==null)&&(ra(l,0),cu(l,k,rt,!1)),Ta(l,u),((al&2)===0||l!==vl)&&(l===vl&&((al&2)===0&&(Nu|=u),Sl===4&&cu(l,k,rt,!1)),_t(l))}function P2(l,t,u){if((al&6)!==0)throw Error(m(327));var a=!u&&(t&124)===0&&(t&l.expiredLanes)===0||Ea(l,t),e=a?Zo(l,t):_f(l,t,!0),n=a;do{if(e===0){ia&&!a&&cu(l,t,0,!1);break}else{if(u=l.current.alternate,n&&!Go(u)){e=_f(l,t,!1),n=!1;continue}if(e===2){if(n=t,l.errorRecoveryDisabledLanes&n)var c=0;else c=l.pendingLanes&-536870913,c=c!==0?c:c&536870912?536870912:0;if(c!==0){t=c;l:{var f=l;e=ue;var i=f.current.memoizedState.isDehydrated;if(i&&(ra(f,c).flags|=256),c=_f(f,c,!1),c!==2){if(yf&&!i){f.errorRecoveryDisabledLanes|=n,Nu|=n,e=4;break l}n=wl,wl=e,n!==null&&(wl===null?wl=n:wl.push.apply(wl,n))}e=c}if(n=!1,e!==2)continue}}if(e===1){ra(l,0),cu(l,t,0,!0);break}l:{switch(a=l,n=e,n){case 0:case 1:throw Error(m(345));case 4:if((t&4194048)!==t)break;case 6:cu(a,t,rt,!uu);break l;case 2:wl=null;break;case 3:case 5:break;default:throw Error(m(329))}if((t&62914560)===t&&(e=Sf+300-bt(),10<e)){if(cu(a,t,rt,!uu),Ae(a,0,!0)!==0)break l;a.timeoutHandle=D1(I2.bind(null,a,u,wl,rn,gf,t,rt,Nu,sa,uu,n,2,-0,0),e);break l}I2(a,u,wl,rn,gf,t,rt,Nu,sa,uu,n,0,-0,0)}}break}while(!0);_t(l)}function I2(l,t,u,a,e,n,c,f,i,v,g,T,h,y){if(l.timeoutHandle=-1,T=t.subtreeFlags,(T&8192||(T&16785408)===16785408)&&(oe={stylesheets:null,count:0,unsuspend:E4},J2(t),T=A4(),T!==null)){l.cancelPendingCommit=T(c1.bind(null,l,t,n,u,a,e,c,f,i,g,1,h,y)),cu(l,n,c,!v);return}c1(l,t,n,u,a,e,c,f,i)}function Go(l){for(var t=l;;){var u=t.tag;if((u===0||u===11||u===15)&&t.flags&16384&&(u=t.updateQueue,u!==null&&(u=u.stores,u!==null)))for(var a=0;a<u.length;a++){var e=u[a],n=e.getSnapshot;e=e.value;try{if(!Pl(n(),e))return!1}catch{return!1}}if(u=t.child,t.subtreeFlags&16384&&u!==null)u.return=t,t=u;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function cu(l,t,u,a){t&=~mf,t&=~Nu,l.suspendedLanes|=t,l.pingedLanes&=~t,a&&(l.warmLanes|=t),a=l.expirationTimes;for(var e=t;0<e;){var n=31-Fl(e),c=1<<n;a[n]=-1,e&=~c}u!==0&&oi(l,u,t)}function vn(){return(al&6)===0?(ee(0),!1):!0}function Af(){if(w!==null){if(el===0)var l=w.return;else l=w,Ht=Mu=null,Bc(l),ea=null,Wa=0,l=w;for(;l!==null;)H2(l.alternate,l),l=l.return;w=null}}function ra(l,t){var u=l.timeoutHandle;u!==-1&&(l.timeoutHandle=-1,a4(u)),u=l.cancelPendingCommit,u!==null&&(l.cancelPendingCommit=null,u()),Af(),vl=l,w=u=Ut(l.current,null),k=t,el=0,ut=null,uu=!1,ia=Ea(l,t),yf=!1,sa=rt=mf=Nu=au=Sl=0,wl=ue=null,gf=!1,(t&8)!==0&&(t|=t&32);var a=l.entangledLanes;if(a!==0)for(l=l.entanglements,a&=t;0<a;){var e=31-Fl(a),n=1<<e;t|=l[e],a&=~n}return Xt=t,xe(),u}function l1(l,t){L=null,S.H=Ie,t===Ga||t===Ve?(t=g0(),el=3):t===h0?(t=g0(),el=4):el=t===S2?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,ut=t,w===null&&(Sl=1,en(l,ft(t,l.current)))}function t1(){var l=S.H;return S.H=Ie,l===null?Ie:l}function u1(){var l=S.A;return S.A=Yo,l}function zf(){Sl=4,uu||(k&4194048)!==k&&dt.current!==null||(ia=!0),(au&134217727)===0&&(Nu&134217727)===0||vl===null||cu(vl,k,rt,!1)}function _f(l,t,u){var a=al;al|=2;var e=t1(),n=u1();(vl!==l||k!==t)&&(rn=null,ra(l,t)),t=!1;var c=Sl;l:do try{if(el!==0&&w!==null){var f=w,i=ut;switch(el){case 8:Af(),c=6;break l;case 3:case 2:case 9:case 6:dt.current===null&&(t=!0);var v=el;if(el=0,ut=null,va(l,f,i,v),u&&ia){c=0;break l}break;default:v=el,el=0,ut=null,va(l,f,i,v)}}Xo(),c=Sl;break}catch(g){l1(l,g)}while(!0);return t&&l.shellSuspendCounter++,Ht=Mu=null,al=a,S.H=e,S.A=n,w===null&&(vl=null,k=0,xe()),c}function Xo(){for(;w!==null;)a1(w)}function Zo(l,t){var u=al;al|=2;var a=t1(),e=u1();vl!==l||k!==t?(rn=null,dn=bt()+500,ra(l,t)):ia=Ea(l,t);l:do try{if(el!==0&&w!==null){t=w;var n=ut;t:switch(el){case 1:el=0,ut=null,va(l,t,n,1);break;case 2:case 9:if(y0(n)){el=0,ut=null,e1(t);break}t=function(){el!==2&&el!==9||vl!==l||(el=7),_t(l)},n.then(t,t);break l;case 3:el=7;break l;case 4:el=5;break l;case 7:y0(n)?(el=0,ut=null,e1(t)):(el=0,ut=null,va(l,t,n,7));break;case 5:var c=null;switch(w.tag){case 26:c=w.memoizedState;case 5:case 27:var f=w;if(!c||G1(c)){el=0,ut=null;var i=f.sibling;if(i!==null)w=i;else{var v=f.return;v!==null?(w=v,hn(v)):w=null}break t}}el=0,ut=null,va(l,t,n,5);break;case 6:el=0,ut=null,va(l,t,n,6);break;case 8:Af(),Sl=6;break l;default:throw Error(m(462))}}Qo();break}catch(g){l1(l,g)}while(!0);return Ht=Mu=null,S.H=a,S.A=e,al=u,w!==null?0:(vl=null,k=0,xe(),Sl)}function Qo(){for(;w!==null&&!ss();)a1(w)}function a1(l){var t=R2(l.alternate,l,Xt);l.memoizedProps=l.pendingProps,t===null?hn(l):w=t}function e1(l){var t=l,u=t.alternate;switch(t.tag){case 15:case 0:t=_2(u,t,t.pendingProps,t.type,void 0,k);break;case 11:t=_2(u,t,t.pendingProps,t.type.render,t.ref,k);break;case 5:Bc(t);default:H2(u,t),t=w=n0(t,Xt),t=R2(u,t,Xt)}l.memoizedProps=l.pendingProps,t===null?hn(l):w=t}function va(l,t,u,a){Ht=Mu=null,Bc(t),ea=null,Wa=0;var e=t.return;try{if(No(l,e,t,u,k)){Sl=1,en(l,ft(u,l.current)),w=null;return}}catch(n){if(e!==null)throw w=e,n;Sl=1,en(l,ft(u,l.current)),w=null;return}t.flags&32768?(tl||a===1?l=!0:ia||(k&536870912)!==0?l=!1:(uu=l=!0,(a===2||a===9||a===3||a===6)&&(a=dt.current,a!==null&&a.tag===13&&(a.flags|=16384))),n1(t,l)):hn(t)}function hn(l){var t=l;do{if((t.flags&32768)!==0){n1(t,uu);return}l=t.return;var u=Co(t.alternate,t,Xt);if(u!==null){w=u;return}if(t=t.sibling,t!==null){w=t;return}w=t=l}while(t!==null);Sl===0&&(Sl=5)}function n1(l,t){do{var u=xo(l.alternate,l);if(u!==null){u.flags&=32767,w=u;return}if(u=l.return,u!==null&&(u.flags|=32768,u.subtreeFlags=0,u.deletions=null),!t&&(l=l.sibling,l!==null)){w=l;return}w=l=u}while(l!==null);Sl=6,w=null}function c1(l,t,u,a,e,n,c,f,i){l.cancelPendingCommit=null;do yn();while(Hl!==0);if((al&6)!==0)throw Error(m(327));if(t!==null){if(t===l.current)throw Error(m(177));if(n=t.lanes|t.childLanes,n|=vc,bs(l,u,n,c,f,i),l===vl&&(w=vl=null,k=0),oa=t,nu=l,da=u,bf=n,Ef=e,k2=a,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,Jo(be,function(){return d1(),null})):(l.callbackNode=null,l.callbackPriority=0),a=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||a){a=S.T,S.T=null,e=O.p,O.p=2,c=al,al|=4;try{jo(l,t,u)}finally{al=c,O.p=e,S.T=a}}Hl=1,f1(),i1(),s1()}}function f1(){if(Hl===1){Hl=0;var l=nu,t=oa,u=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||u){u=S.T,S.T=null;var a=O.p;O.p=2;var e=al;al|=4;try{V2(t,l);var n=qf,c=$i(l.containerInfo),f=n.focusedElem,i=n.selectionRange;if(c!==f&&f&&f.ownerDocument&&Wi(f.ownerDocument.documentElement,f)){if(i!==null&&ic(f)){var v=i.start,g=i.end;if(g===void 0&&(g=v),"selectionStart"in f)f.selectionStart=v,f.selectionEnd=Math.min(g,f.value.length);else{var T=f.ownerDocument||document,h=T&&T.defaultView||window;if(h.getSelection){var y=h.getSelection(),Y=f.textContent.length,x=Math.min(i.start,Y),fl=i.end===void 0?x:Math.min(i.end,Y);!y.extend&&x>fl&&(c=fl,fl=x,x=c);var d=wi(f,x),o=wi(f,fl);if(d&&o&&(y.rangeCount!==1||y.anchorNode!==d.node||y.anchorOffset!==d.offset||y.focusNode!==o.node||y.focusOffset!==o.offset)){var r=T.createRange();r.setStart(d.node,d.offset),y.removeAllRanges(),x>fl?(y.addRange(r),y.extend(o.node,o.offset)):(r.setEnd(o.node,o.offset),y.addRange(r))}}}}for(T=[],y=f;y=y.parentNode;)y.nodeType===1&&T.push({element:y,left:y.scrollLeft,top:y.scrollTop});for(typeof f.focus=="function"&&f.focus(),f=0;f<T.length;f++){var b=T[f];b.element.scrollLeft=b.left,b.element.scrollTop=b.top}}Dn=!!jf,qf=jf=null}finally{al=e,O.p=a,S.T=u}}l.current=t,Hl=2}}function i1(){if(Hl===2){Hl=0;var l=nu,t=oa,u=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||u){u=S.T,S.T=null;var a=O.p;O.p=2;var e=al;al|=4;try{G2(l,t.alternate,t)}finally{al=e,O.p=a,S.T=u}}Hl=3}}function s1(){if(Hl===4||Hl===3){Hl=0,os();var l=nu,t=oa,u=da,a=k2;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Hl=5:(Hl=0,oa=nu=null,o1(l,l.pendingLanes));var e=l.pendingLanes;if(e===0&&(eu=null),Zn(u),t=t.stateNode,kl&&typeof kl.onCommitFiberRoot=="function")try{kl.onCommitFiberRoot(ba,t,void 0,(t.current.flags&128)===128)}catch{}if(a!==null){t=S.T,e=O.p,O.p=2,S.T=null;try{for(var n=l.onRecoverableError,c=0;c<a.length;c++){var f=a[c];n(f.value,{componentStack:f.stack})}}finally{S.T=t,O.p=e}}(da&3)!==0&&yn(),_t(l),e=l.pendingLanes,(u&4194090)!==0&&(e&42)!==0?l===Tf?ae++:(ae=0,Tf=l):ae=0,ee(0)}}function o1(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,Ya(t)))}function yn(l){return f1(),i1(),s1(),d1()}function d1(){if(Hl!==5)return!1;var l=nu,t=bf;bf=0;var u=Zn(da),a=S.T,e=O.p;try{O.p=32>u?32:u,S.T=null,u=Ef,Ef=null;var n=nu,c=da;if(Hl=0,oa=nu=null,da=0,(al&6)!==0)throw Error(m(331));var f=al;if(al|=4,W2(n.current),K2(n,n.current,c,u),al=f,ee(0,!1),kl&&typeof kl.onPostCommitFiberRoot=="function")try{kl.onPostCommitFiberRoot(ba,n)}catch{}return!0}finally{O.p=e,S.T=a,o1(l,t)}}function r1(l,t,u){t=ft(u,t),t=Pc(l.stateNode,t,2),l=$t(l,t,2),l!==null&&(Ta(l,2),_t(l))}function dl(l,t,u){if(l.tag===3)r1(l,l,u);else for(;t!==null;){if(t.tag===3){r1(t,l,u);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(eu===null||!eu.has(a))){l=ft(u,l),u=m2(2),a=$t(t,u,2),a!==null&&(g2(u,a,t,l),Ta(a,2),_t(a));break}}t=t.return}}function Mf(l,t,u){var a=l.pingCache;if(a===null){a=l.pingCache=new Bo;var e=new Set;a.set(t,e)}else e=a.get(t),e===void 0&&(e=new Set,a.set(t,e));e.has(u)||(yf=!0,e.add(u),l=Vo.bind(null,l,t,u),t.then(l,l))}function Vo(l,t,u){var a=l.pingCache;a!==null&&a.delete(t),l.pingedLanes|=l.suspendedLanes&u,l.warmLanes&=~u,vl===l&&(k&u)===u&&(Sl===4||Sl===3&&(k&62914560)===k&&300>bt()-Sf?(al&2)===0&&ra(l,0):mf|=u,sa===k&&(sa=0)),_t(l)}function v1(l,t){t===0&&(t=si()),l=Wu(l,t),l!==null&&(Ta(l,t),_t(l))}function Lo(l){var t=l.memoizedState,u=0;t!==null&&(u=t.retryLane),v1(l,u)}function Ko(l,t){var u=0;switch(l.tag){case 13:var a=l.stateNode,e=l.memoizedState;e!==null&&(u=e.retryLane);break;case 19:a=l.stateNode;break;case 22:a=l.stateNode._retryCache;break;default:throw Error(m(314))}a!==null&&a.delete(t),v1(l,u)}function Jo(l,t){return Yn(l,t)}var mn=null,ha=null,Of=!1,gn=!1,Df=!1,Hu=0;function _t(l){l!==ha&&l.next===null&&(ha===null?mn=ha=l:ha=ha.next=l),gn=!0,Of||(Of=!0,Wo())}function ee(l,t){if(!Df&&gn){Df=!0;do for(var u=!1,a=mn;a!==null;){if(l!==0){var e=a.pendingLanes;if(e===0)var n=0;else{var c=a.suspendedLanes,f=a.pingedLanes;n=(1<<31-Fl(42|l)+1)-1,n&=e&~(c&~f),n=n&201326741?n&201326741|1:n?n|2:0}n!==0&&(u=!0,g1(a,n))}else n=k,n=Ae(a,a===vl?n:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(n&3)===0||Ea(a,n)||(u=!0,g1(a,n));a=a.next}while(u);Df=!1}}function wo(){h1()}function h1(){gn=Of=!1;var l=0;Hu!==0&&(u4()&&(l=Hu),Hu=0);for(var t=bt(),u=null,a=mn;a!==null;){var e=a.next,n=y1(a,t);n===0?(a.next=null,u===null?mn=e:u.next=e,e===null&&(ha=u)):(u=a,(l!==0||(n&3)!==0)&&(gn=!0)),a=e}ee(l)}function y1(l,t){for(var u=l.suspendedLanes,a=l.pingedLanes,e=l.expirationTimes,n=l.pendingLanes&-62914561;0<n;){var c=31-Fl(n),f=1<<c,i=e[c];i===-1?((f&u)===0||(f&a)!==0)&&(e[c]=Ss(f,t)):i<=t&&(l.expiredLanes|=f),n&=~f}if(t=vl,u=k,u=Ae(l,l===t?u:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a=l.callbackNode,u===0||l===t&&(el===2||el===9)||l.cancelPendingCommit!==null)return a!==null&&a!==null&&Bn(a),l.callbackNode=null,l.callbackPriority=0;if((u&3)===0||Ea(l,u)){if(t=u&-u,t===l.callbackPriority)return t;switch(a!==null&&Bn(a),Zn(u)){case 2:case 8:u=ci;break;case 32:u=be;break;case 268435456:u=fi;break;default:u=be}return a=m1.bind(null,l),u=Yn(u,a),l.callbackPriority=t,l.callbackNode=u,t}return a!==null&&a!==null&&Bn(a),l.callbackPriority=2,l.callbackNode=null,2}function m1(l,t){if(Hl!==0&&Hl!==5)return l.callbackNode=null,l.callbackPriority=0,null;var u=l.callbackNode;if(yn()&&l.callbackNode!==u)return null;var a=k;return a=Ae(l,l===vl?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a===0?null:(P2(l,a,t),y1(l,bt()),l.callbackNode!=null&&l.callbackNode===u?m1.bind(null,l):null)}function g1(l,t){if(yn())return null;P2(l,t,!0)}function Wo(){e4(function(){(al&6)!==0?Yn(ni,wo):h1()})}function pf(){return Hu===0&&(Hu=ii()),Hu}function S1(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:De(""+l)}function b1(l,t){var u=t.ownerDocument.createElement("input");return u.name=t.name,u.value=t.value,l.id&&u.setAttribute("form",l.id),t.parentNode.insertBefore(u,t),l=new FormData(l),u.parentNode.removeChild(u),l}function $o(l,t,u,a,e){if(t==="submit"&&u&&u.stateNode===e){var n=S1((e[Vl]||null).action),c=a.submitter;c&&(t=(t=c[Vl]||null)?S1(t.formAction):c.getAttribute("formAction"),t!==null&&(n=t,c=null));var f=new Ne("action","action",null,a,e);l.push({event:f,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(Hu!==0){var i=c?b1(e,c):new FormData(e);wc(u,{pending:!0,data:i,method:e.method,action:n},null,i)}}else typeof n=="function"&&(f.preventDefault(),i=c?b1(e,c):new FormData(e),wc(u,{pending:!0,data:i,method:e.method,action:n},n,i))},currentTarget:e}]})}}for(var Uf=0;Uf<rc.length;Uf++){var Rf=rc[Uf],ko=Rf.toLowerCase(),Fo=Rf[0].toUpperCase()+Rf.slice(1);yt(ko,"on"+Fo)}yt(Pi,"onAnimationEnd"),yt(Ii,"onAnimationIteration"),yt(l0,"onAnimationStart"),yt("dblclick","onDoubleClick"),yt("focusin","onFocus"),yt("focusout","onBlur"),yt(ho,"onTransitionRun"),yt(yo,"onTransitionStart"),yt(mo,"onTransitionCancel"),yt(t0,"onTransitionEnd"),Bu("onMouseEnter",["mouseout","mouseover"]),Bu("onMouseLeave",["mouseout","mouseover"]),Bu("onPointerEnter",["pointerout","pointerover"]),Bu("onPointerLeave",["pointerout","pointerover"]),mu("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),mu("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),mu("onBeforeInput",["compositionend","keypress","textInput","paste"]),mu("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),mu("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),mu("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var ne="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Po=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(ne));function E1(l,t){t=(t&4)!==0;for(var u=0;u<l.length;u++){var a=l[u],e=a.event;a=a.listeners;l:{var n=void 0;if(t)for(var c=a.length-1;0<=c;c--){var f=a[c],i=f.instance,v=f.currentTarget;if(f=f.listener,i!==n&&e.isPropagationStopped())break l;n=f,e.currentTarget=v;try{n(e)}catch(g){an(g)}e.currentTarget=null,n=i}else for(c=0;c<a.length;c++){if(f=a[c],i=f.instance,v=f.currentTarget,f=f.listener,i!==n&&e.isPropagationStopped())break l;n=f,e.currentTarget=v;try{n(e)}catch(g){an(g)}e.currentTarget=null,n=i}}}}function W(l,t){var u=t[Qn];u===void 0&&(u=t[Qn]=new Set);var a=l+"__bubble";u.has(a)||(T1(t,l,2,!1),u.add(a))}function Nf(l,t,u){var a=0;t&&(a|=4),T1(u,l,a,t)}var Sn="_reactListening"+Math.random().toString(36).slice(2);function Hf(l){if(!l[Sn]){l[Sn]=!0,hi.forEach(function(u){u!=="selectionchange"&&(Po.has(u)||Nf(u,!1,l),Nf(u,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[Sn]||(t[Sn]=!0,Nf("selectionchange",!1,t))}}function T1(l,t,u,a){switch(K1(t)){case 2:var e=M4;break;case 8:e=O4;break;default:e=Jf}u=e.bind(null,t,u,l),e=void 0,!In||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(e=!0),a?e!==void 0?l.addEventListener(t,u,{capture:!0,passive:e}):l.addEventListener(t,u,!0):e!==void 0?l.addEventListener(t,u,{passive:e}):l.addEventListener(t,u,!1)}function Cf(l,t,u,a,e){var n=a;if((t&1)===0&&(t&2)===0&&a!==null)l:for(;;){if(a===null)return;var c=a.tag;if(c===3||c===4){var f=a.stateNode.containerInfo;if(f===e)break;if(c===4)for(c=a.return;c!==null;){var i=c.tag;if((i===3||i===4)&&c.stateNode.containerInfo===e)return;c=c.return}for(;f!==null;){if(c=ju(f),c===null)return;if(i=c.tag,i===5||i===6||i===26||i===27){a=n=c;continue l}f=f.parentNode}}a=a.return}pi(function(){var v=n,g=Fn(u),T=[];l:{var h=u0.get(l);if(h!==void 0){var y=Ne,Y=l;switch(l){case"keypress":if(Ue(u)===0)break l;case"keydown":case"keyup":y=Ks;break;case"focusin":Y="focus",y=ac;break;case"focusout":Y="blur",y=ac;break;case"beforeblur":case"afterblur":y=ac;break;case"click":if(u.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":y=Ni;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":y=Cs;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":y=Ws;break;case Pi:case Ii:case l0:y=qs;break;case t0:y=ks;break;case"scroll":case"scrollend":y=Ns;break;case"wheel":y=Ps;break;case"copy":case"cut":case"paste":y=Bs;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":y=Ci;break;case"toggle":case"beforetoggle":y=lo}var x=(t&4)!==0,fl=!x&&(l==="scroll"||l==="scrollend"),d=x?h!==null?h+"Capture":null:h;x=[];for(var o=v,r;o!==null;){var b=o;if(r=b.stateNode,b=b.tag,b!==5&&b!==26&&b!==27||r===null||d===null||(b=_a(o,d),b!=null&&x.push(ce(o,b,r))),fl)break;o=o.return}0<x.length&&(h=new y(h,Y,null,u,g),T.push({event:h,listeners:x}))}}if((t&7)===0){l:{if(h=l==="mouseover"||l==="pointerover",y=l==="mouseout"||l==="pointerout",h&&u!==kn&&(Y=u.relatedTarget||u.fromElement)&&(ju(Y)||Y[xu]))break l;if((y||h)&&(h=g.window===g?g:(h=g.ownerDocument)?h.defaultView||h.parentWindow:window,y?(Y=u.relatedTarget||u.toElement,y=v,Y=Y?ju(Y):null,Y!==null&&(fl=B(Y),x=Y.tag,Y!==fl||x!==5&&x!==27&&x!==6)&&(Y=null)):(y=null,Y=v),y!==Y)){if(x=Ni,b="onMouseLeave",d="onMouseEnter",o="mouse",(l==="pointerout"||l==="pointerover")&&(x=Ci,b="onPointerLeave",d="onPointerEnter",o="pointer"),fl=y==null?h:za(y),r=Y==null?h:za(Y),h=new x(b,o+"leave",y,u,g),h.target=fl,h.relatedTarget=r,b=null,ju(g)===v&&(x=new x(d,o+"enter",Y,u,g),x.target=r,x.relatedTarget=fl,b=x),fl=b,y&&Y)t:{for(x=y,d=Y,o=0,r=x;r;r=ya(r))o++;for(r=0,b=d;b;b=ya(b))r++;for(;0<o-r;)x=ya(x),o--;for(;0<r-o;)d=ya(d),r--;for(;o--;){if(x===d||d!==null&&x===d.alternate)break t;x=ya(x),d=ya(d)}x=null}else x=null;y!==null&&A1(T,h,y,x,!1),Y!==null&&fl!==null&&A1(T,fl,Y,x,!0)}}l:{if(h=v?za(v):window,y=h.nodeName&&h.nodeName.toLowerCase(),y==="select"||y==="input"&&h.type==="file")var U=Zi;else if(Gi(h))if(Qi)U=oo;else{U=io;var J=fo}else y=h.nodeName,!y||y.toLowerCase()!=="input"||h.type!=="checkbox"&&h.type!=="radio"?v&&$n(v.elementType)&&(U=Zi):U=so;if(U&&(U=U(l,v))){Xi(T,U,u,g);break l}J&&J(l,h,v),l==="focusout"&&v&&h.type==="number"&&v.memoizedProps.value!=null&&Wn(h,"number",h.value)}switch(J=v?za(v):window,l){case"focusin":(Gi(J)||J.contentEditable==="true")&&(Ku=J,sc=v,Ha=null);break;case"focusout":Ha=sc=Ku=null;break;case"mousedown":oc=!0;break;case"contextmenu":case"mouseup":case"dragend":oc=!1,ki(T,u,g);break;case"selectionchange":if(vo)break;case"keydown":case"keyup":ki(T,u,g)}var H;if(nc)l:{switch(l){case"compositionstart":var j="onCompositionStart";break l;case"compositionend":j="onCompositionEnd";break l;case"compositionupdate":j="onCompositionUpdate";break l}j=void 0}else Lu?Yi(l,u)&&(j="onCompositionEnd"):l==="keydown"&&u.keyCode===229&&(j="onCompositionStart");j&&(xi&&u.locale!=="ko"&&(Lu||j!=="onCompositionStart"?j==="onCompositionEnd"&&Lu&&(H=Ui()):(Kt=g,lc="value"in Kt?Kt.value:Kt.textContent,Lu=!0)),J=bn(v,j),0<J.length&&(j=new Hi(j,l,null,u,g),T.push({event:j,listeners:J}),H?j.data=H:(H=Bi(u),H!==null&&(j.data=H)))),(H=uo?ao(l,u):eo(l,u))&&(j=bn(v,"onBeforeInput"),0<j.length&&(J=new Hi("onBeforeInput","beforeinput",null,u,g),T.push({event:J,listeners:j}),J.data=H)),$o(T,l,v,u,g)}E1(T,t)})}function ce(l,t,u){return{instance:l,listener:t,currentTarget:u}}function bn(l,t){for(var u=t+"Capture",a=[];l!==null;){var e=l,n=e.stateNode;if(e=e.tag,e!==5&&e!==26&&e!==27||n===null||(e=_a(l,u),e!=null&&a.unshift(ce(l,e,n)),e=_a(l,t),e!=null&&a.push(ce(l,e,n))),l.tag===3)return a;l=l.return}return[]}function ya(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function A1(l,t,u,a,e){for(var n=t._reactName,c=[];u!==null&&u!==a;){var f=u,i=f.alternate,v=f.stateNode;if(f=f.tag,i!==null&&i===a)break;f!==5&&f!==26&&f!==27||v===null||(i=v,e?(v=_a(u,n),v!=null&&c.unshift(ce(u,v,i))):e||(v=_a(u,n),v!=null&&c.push(ce(u,v,i)))),u=u.return}c.length!==0&&l.push({event:t,listeners:c})}var Io=/\r\n?/g,l4=/\u0000|\uFFFD/g;function z1(l){return(typeof l=="string"?l:""+l).replace(Io,`
`).replace(l4,"")}function _1(l,t){return t=z1(t),z1(l)===t}function En(){}function cl(l,t,u,a,e,n){switch(u){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||Zu(l,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&Zu(l,""+a);break;case"className":_e(l,"class",a);break;case"tabIndex":_e(l,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":_e(l,u,a);break;case"style":Oi(l,a,n);break;case"data":if(t!=="object"){_e(l,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||u!=="href")){l.removeAttribute(u);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=De(""+a),l.setAttribute(u,a);break;case"action":case"formAction":if(typeof a=="function"){l.setAttribute(u,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof n=="function"&&(u==="formAction"?(t!=="input"&&cl(l,t,"name",e.name,e,null),cl(l,t,"formEncType",e.formEncType,e,null),cl(l,t,"formMethod",e.formMethod,e,null),cl(l,t,"formTarget",e.formTarget,e,null)):(cl(l,t,"encType",e.encType,e,null),cl(l,t,"method",e.method,e,null),cl(l,t,"target",e.target,e,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(u);break}a=De(""+a),l.setAttribute(u,a);break;case"onClick":a!=null&&(l.onclick=En);break;case"onScroll":a!=null&&W("scroll",l);break;case"onScrollEnd":a!=null&&W("scrollend",l);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(m(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(m(60));l.innerHTML=u}}break;case"multiple":l.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":l.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){l.removeAttribute("xlink:href");break}u=De(""+a),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",u);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""+a):l.removeAttribute(u);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,""):l.removeAttribute(u);break;case"capture":case"download":a===!0?l.setAttribute(u,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(u,a):l.removeAttribute(u);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?l.setAttribute(u,a):l.removeAttribute(u);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?l.removeAttribute(u):l.setAttribute(u,a);break;case"popover":W("beforetoggle",l),W("toggle",l),ze(l,"popover",a);break;case"xlinkActuate":Dt(l,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Dt(l,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Dt(l,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Dt(l,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Dt(l,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Dt(l,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Dt(l,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Dt(l,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Dt(l,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":ze(l,"is",a);break;case"innerText":case"textContent":break;default:(!(2<u.length)||u[0]!=="o"&&u[0]!=="O"||u[1]!=="n"&&u[1]!=="N")&&(u=Us.get(u)||u,ze(l,u,a))}}function xf(l,t,u,a,e,n){switch(u){case"style":Oi(l,a,n);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(m(61));if(u=a.__html,u!=null){if(e.children!=null)throw Error(m(60));l.innerHTML=u}}break;case"children":typeof a=="string"?Zu(l,a):(typeof a=="number"||typeof a=="bigint")&&Zu(l,""+a);break;case"onScroll":a!=null&&W("scroll",l);break;case"onScrollEnd":a!=null&&W("scrollend",l);break;case"onClick":a!=null&&(l.onclick=En);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!yi.hasOwnProperty(u))l:{if(u[0]==="o"&&u[1]==="n"&&(e=u.endsWith("Capture"),t=u.slice(2,e?u.length-7:void 0),n=l[Vl]||null,n=n!=null?n[u]:null,typeof n=="function"&&l.removeEventListener(t,n,e),typeof a=="function")){typeof n!="function"&&n!==null&&(u in l?l[u]=null:l.hasAttribute(u)&&l.removeAttribute(u)),l.addEventListener(t,a,e);break l}u in l?l[u]=a:a===!0?l.setAttribute(u,""):ze(l,u,a)}}}function Cl(l,t,u){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":W("error",l),W("load",l);var a=!1,e=!1,n;for(n in u)if(u.hasOwnProperty(n)){var c=u[n];if(c!=null)switch(n){case"src":a=!0;break;case"srcSet":e=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(m(137,t));default:cl(l,t,n,c,u,null)}}e&&cl(l,t,"srcSet",u.srcSet,u,null),a&&cl(l,t,"src",u.src,u,null);return;case"input":W("invalid",l);var f=n=c=e=null,i=null,v=null;for(a in u)if(u.hasOwnProperty(a)){var g=u[a];if(g!=null)switch(a){case"name":e=g;break;case"type":c=g;break;case"checked":i=g;break;case"defaultChecked":v=g;break;case"value":n=g;break;case"defaultValue":f=g;break;case"children":case"dangerouslySetInnerHTML":if(g!=null)throw Error(m(137,t));break;default:cl(l,t,a,g,u,null)}}Ai(l,n,f,i,v,c,e,!1),Me(l);return;case"select":W("invalid",l),a=c=n=null;for(e in u)if(u.hasOwnProperty(e)&&(f=u[e],f!=null))switch(e){case"value":n=f;break;case"defaultValue":c=f;break;case"multiple":a=f;default:cl(l,t,e,f,u,null)}t=n,u=c,l.multiple=!!a,t!=null?Xu(l,!!a,t,!1):u!=null&&Xu(l,!!a,u,!0);return;case"textarea":W("invalid",l),n=e=a=null;for(c in u)if(u.hasOwnProperty(c)&&(f=u[c],f!=null))switch(c){case"value":a=f;break;case"defaultValue":e=f;break;case"children":n=f;break;case"dangerouslySetInnerHTML":if(f!=null)throw Error(m(91));break;default:cl(l,t,c,f,u,null)}_i(l,a,e,n),Me(l);return;case"option":for(i in u)if(u.hasOwnProperty(i)&&(a=u[i],a!=null))switch(i){case"selected":l.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:cl(l,t,i,a,u,null)}return;case"dialog":W("beforetoggle",l),W("toggle",l),W("cancel",l),W("close",l);break;case"iframe":case"object":W("load",l);break;case"video":case"audio":for(a=0;a<ne.length;a++)W(ne[a],l);break;case"image":W("error",l),W("load",l);break;case"details":W("toggle",l);break;case"embed":case"source":case"link":W("error",l),W("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(v in u)if(u.hasOwnProperty(v)&&(a=u[v],a!=null))switch(v){case"children":case"dangerouslySetInnerHTML":throw Error(m(137,t));default:cl(l,t,v,a,u,null)}return;default:if($n(t)){for(g in u)u.hasOwnProperty(g)&&(a=u[g],a!==void 0&&xf(l,t,g,a,u,void 0));return}}for(f in u)u.hasOwnProperty(f)&&(a=u[f],a!=null&&cl(l,t,f,a,u,null))}function t4(l,t,u,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var e=null,n=null,c=null,f=null,i=null,v=null,g=null;for(y in u){var T=u[y];if(u.hasOwnProperty(y)&&T!=null)switch(y){case"checked":break;case"value":break;case"defaultValue":i=T;default:a.hasOwnProperty(y)||cl(l,t,y,null,a,T)}}for(var h in a){var y=a[h];if(T=u[h],a.hasOwnProperty(h)&&(y!=null||T!=null))switch(h){case"type":n=y;break;case"name":e=y;break;case"checked":v=y;break;case"defaultChecked":g=y;break;case"value":c=y;break;case"defaultValue":f=y;break;case"children":case"dangerouslySetInnerHTML":if(y!=null)throw Error(m(137,t));break;default:y!==T&&cl(l,t,h,y,a,T)}}wn(l,c,f,i,v,g,n,e);return;case"select":y=c=f=h=null;for(n in u)if(i=u[n],u.hasOwnProperty(n)&&i!=null)switch(n){case"value":break;case"multiple":y=i;default:a.hasOwnProperty(n)||cl(l,t,n,null,a,i)}for(e in a)if(n=a[e],i=u[e],a.hasOwnProperty(e)&&(n!=null||i!=null))switch(e){case"value":h=n;break;case"defaultValue":f=n;break;case"multiple":c=n;default:n!==i&&cl(l,t,e,n,a,i)}t=f,u=c,a=y,h!=null?Xu(l,!!u,h,!1):!!a!=!!u&&(t!=null?Xu(l,!!u,t,!0):Xu(l,!!u,u?[]:"",!1));return;case"textarea":y=h=null;for(f in u)if(e=u[f],u.hasOwnProperty(f)&&e!=null&&!a.hasOwnProperty(f))switch(f){case"value":break;case"children":break;default:cl(l,t,f,null,a,e)}for(c in a)if(e=a[c],n=u[c],a.hasOwnProperty(c)&&(e!=null||n!=null))switch(c){case"value":h=e;break;case"defaultValue":y=e;break;case"children":break;case"dangerouslySetInnerHTML":if(e!=null)throw Error(m(91));break;default:e!==n&&cl(l,t,c,e,a,n)}zi(l,h,y);return;case"option":for(var Y in u)if(h=u[Y],u.hasOwnProperty(Y)&&h!=null&&!a.hasOwnProperty(Y))switch(Y){case"selected":l.selected=!1;break;default:cl(l,t,Y,null,a,h)}for(i in a)if(h=a[i],y=u[i],a.hasOwnProperty(i)&&h!==y&&(h!=null||y!=null))switch(i){case"selected":l.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:cl(l,t,i,h,a,y)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var x in u)h=u[x],u.hasOwnProperty(x)&&h!=null&&!a.hasOwnProperty(x)&&cl(l,t,x,null,a,h);for(v in a)if(h=a[v],y=u[v],a.hasOwnProperty(v)&&h!==y&&(h!=null||y!=null))switch(v){case"children":case"dangerouslySetInnerHTML":if(h!=null)throw Error(m(137,t));break;default:cl(l,t,v,h,a,y)}return;default:if($n(t)){for(var fl in u)h=u[fl],u.hasOwnProperty(fl)&&h!==void 0&&!a.hasOwnProperty(fl)&&xf(l,t,fl,void 0,a,h);for(g in a)h=a[g],y=u[g],!a.hasOwnProperty(g)||h===y||h===void 0&&y===void 0||xf(l,t,g,h,a,y);return}}for(var d in u)h=u[d],u.hasOwnProperty(d)&&h!=null&&!a.hasOwnProperty(d)&&cl(l,t,d,null,a,h);for(T in a)h=a[T],y=u[T],!a.hasOwnProperty(T)||h===y||h==null&&y==null||cl(l,t,T,h,a,y)}var jf=null,qf=null;function Tn(l){return l.nodeType===9?l:l.ownerDocument}function M1(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function O1(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function Yf(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Bf=null;function u4(){var l=window.event;return l&&l.type==="popstate"?l===Bf?!1:(Bf=l,!0):(Bf=null,!1)}var D1=typeof setTimeout=="function"?setTimeout:void 0,a4=typeof clearTimeout=="function"?clearTimeout:void 0,p1=typeof Promise=="function"?Promise:void 0,e4=typeof queueMicrotask=="function"?queueMicrotask:typeof p1<"u"?function(l){return p1.resolve(null).then(l).catch(n4)}:D1;function n4(l){setTimeout(function(){throw l})}function fu(l){return l==="head"}function U1(l,t){var u=t,a=0,e=0;do{var n=u.nextSibling;if(l.removeChild(u),n&&n.nodeType===8)if(u=n.data,u==="/$"){if(0<a&&8>a){u=a;var c=l.ownerDocument;if(u&1&&fe(c.documentElement),u&2&&fe(c.body),u&4)for(u=c.head,fe(u),c=u.firstChild;c;){var f=c.nextSibling,i=c.nodeName;c[Aa]||i==="SCRIPT"||i==="STYLE"||i==="LINK"&&c.rel.toLowerCase()==="stylesheet"||u.removeChild(c),c=f}}if(e===0){l.removeChild(n),ye(t);return}e--}else u==="$"||u==="$?"||u==="$!"?e++:a=u.charCodeAt(0)-48;else a=0;u=n}while(u);ye(t)}function Gf(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var u=t;switch(t=t.nextSibling,u.nodeName){case"HTML":case"HEAD":case"BODY":Gf(u),Vn(u);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(u.rel.toLowerCase()==="stylesheet")continue}l.removeChild(u)}}function c4(l,t,u,a){for(;l.nodeType===1;){var e=u;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(a){if(!l[Aa])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(n=l.getAttribute("rel"),n==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(n!==e.rel||l.getAttribute("href")!==(e.href==null||e.href===""?null:e.href)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin)||l.getAttribute("title")!==(e.title==null?null:e.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(n=l.getAttribute("src"),(n!==(e.src==null?null:e.src)||l.getAttribute("type")!==(e.type==null?null:e.type)||l.getAttribute("crossorigin")!==(e.crossOrigin==null?null:e.crossOrigin))&&n&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var n=e.name==null?null:""+e.name;if(e.type==="hidden"&&l.getAttribute("name")===n)return l}else return l;if(l=gt(l.nextSibling),l===null)break}return null}function f4(l,t,u){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!u||(l=gt(l.nextSibling),l===null))return null;return l}function Xf(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState==="complete"}function i4(l,t){var u=l.ownerDocument;if(l.data!=="$?"||u.readyState==="complete")t();else{var a=function(){t(),u.removeEventListener("DOMContentLoaded",a)};u.addEventListener("DOMContentLoaded",a),l._reactRetry=a}}function gt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="F!"||t==="F")break;if(t==="/$")return null}}return l}var Zf=null;function R1(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var u=l.data;if(u==="$"||u==="$!"||u==="$?"){if(t===0)return l;t--}else u==="/$"&&t++}l=l.previousSibling}return null}function N1(l,t,u){switch(t=Tn(u),l){case"html":if(l=t.documentElement,!l)throw Error(m(452));return l;case"head":if(l=t.head,!l)throw Error(m(453));return l;case"body":if(l=t.body,!l)throw Error(m(454));return l;default:throw Error(m(451))}}function fe(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);Vn(l)}var vt=new Map,H1=new Set;function An(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Zt=O.d;O.d={f:s4,r:o4,D:d4,C:r4,L:v4,m:h4,X:m4,S:y4,M:g4};function s4(){var l=Zt.f(),t=vn();return l||t}function o4(l){var t=qu(l);t!==null&&t.tag===5&&t.type==="form"?P0(t):Zt.r(l)}var ma=typeof document>"u"?null:document;function C1(l,t,u){var a=ma;if(a&&typeof t=="string"&&t){var e=ct(t);e='link[rel="'+l+'"][href="'+e+'"]',typeof u=="string"&&(e+='[crossorigin="'+u+'"]'),H1.has(e)||(H1.add(e),l={rel:l,crossOrigin:u,href:t},a.querySelector(e)===null&&(t=a.createElement("link"),Cl(t,"link",l),Dl(t),a.head.appendChild(t)))}}function d4(l){Zt.D(l),C1("dns-prefetch",l,null)}function r4(l,t){Zt.C(l,t),C1("preconnect",l,t)}function v4(l,t,u){Zt.L(l,t,u);var a=ma;if(a&&l&&t){var e='link[rel="preload"][as="'+ct(t)+'"]';t==="image"&&u&&u.imageSrcSet?(e+='[imagesrcset="'+ct(u.imageSrcSet)+'"]',typeof u.imageSizes=="string"&&(e+='[imagesizes="'+ct(u.imageSizes)+'"]')):e+='[href="'+ct(l)+'"]';var n=e;switch(t){case"style":n=ga(l);break;case"script":n=Sa(l)}vt.has(n)||(l=R({rel:"preload",href:t==="image"&&u&&u.imageSrcSet?void 0:l,as:t},u),vt.set(n,l),a.querySelector(e)!==null||t==="style"&&a.querySelector(ie(n))||t==="script"&&a.querySelector(se(n))||(t=a.createElement("link"),Cl(t,"link",l),Dl(t),a.head.appendChild(t)))}}function h4(l,t){Zt.m(l,t);var u=ma;if(u&&l){var a=t&&typeof t.as=="string"?t.as:"script",e='link[rel="modulepreload"][as="'+ct(a)+'"][href="'+ct(l)+'"]',n=e;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":n=Sa(l)}if(!vt.has(n)&&(l=R({rel:"modulepreload",href:l},t),vt.set(n,l),u.querySelector(e)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(u.querySelector(se(n)))return}a=u.createElement("link"),Cl(a,"link",l),Dl(a),u.head.appendChild(a)}}}function y4(l,t,u){Zt.S(l,t,u);var a=ma;if(a&&l){var e=Yu(a).hoistableStyles,n=ga(l);t=t||"default";var c=e.get(n);if(!c){var f={loading:0,preload:null};if(c=a.querySelector(ie(n)))f.loading=5;else{l=R({rel:"stylesheet",href:l,"data-precedence":t},u),(u=vt.get(n))&&Qf(l,u);var i=c=a.createElement("link");Dl(i),Cl(i,"link",l),i._p=new Promise(function(v,g){i.onload=v,i.onerror=g}),i.addEventListener("load",function(){f.loading|=1}),i.addEventListener("error",function(){f.loading|=2}),f.loading|=4,zn(c,t,a)}c={type:"stylesheet",instance:c,count:1,state:f},e.set(n,c)}}}function m4(l,t){Zt.X(l,t);var u=ma;if(u&&l){var a=Yu(u).hoistableScripts,e=Sa(l),n=a.get(e);n||(n=u.querySelector(se(e)),n||(l=R({src:l,async:!0},t),(t=vt.get(e))&&Vf(l,t),n=u.createElement("script"),Dl(n),Cl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function g4(l,t){Zt.M(l,t);var u=ma;if(u&&l){var a=Yu(u).hoistableScripts,e=Sa(l),n=a.get(e);n||(n=u.querySelector(se(e)),n||(l=R({src:l,async:!0,type:"module"},t),(t=vt.get(e))&&Vf(l,t),n=u.createElement("script"),Dl(n),Cl(n,"link",l),u.head.appendChild(n)),n={type:"script",instance:n,count:1,state:null},a.set(e,n))}}function x1(l,t,u,a){var e=(e=X.current)?An(e):null;if(!e)throw Error(m(446));switch(l){case"meta":case"title":return null;case"style":return typeof u.precedence=="string"&&typeof u.href=="string"?(t=ga(u.href),u=Yu(e).hoistableStyles,a=u.get(t),a||(a={type:"style",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(u.rel==="stylesheet"&&typeof u.href=="string"&&typeof u.precedence=="string"){l=ga(u.href);var n=Yu(e).hoistableStyles,c=n.get(l);if(c||(e=e.ownerDocument||e,c={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},n.set(l,c),(n=e.querySelector(ie(l)))&&!n._p&&(c.instance=n,c.state.loading=5),vt.has(l)||(u={rel:"preload",as:"style",href:u.href,crossOrigin:u.crossOrigin,integrity:u.integrity,media:u.media,hrefLang:u.hrefLang,referrerPolicy:u.referrerPolicy},vt.set(l,u),n||S4(e,l,u,c.state))),t&&a===null)throw Error(m(528,""));return c}if(t&&a!==null)throw Error(m(529,""));return null;case"script":return t=u.async,u=u.src,typeof u=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Sa(u),u=Yu(e).hoistableScripts,a=u.get(t),a||(a={type:"script",instance:null,count:0,state:null},u.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(m(444,l))}}function ga(l){return'href="'+ct(l)+'"'}function ie(l){return'link[rel="stylesheet"]['+l+"]"}function j1(l){return R({},l,{"data-precedence":l.precedence,precedence:null})}function S4(l,t,u,a){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=l.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),Cl(t,"link",u),Dl(t),l.head.appendChild(t))}function Sa(l){return'[src="'+ct(l)+'"]'}function se(l){return"script[async]"+l}function q1(l,t,u){if(t.count++,t.instance===null)switch(t.type){case"style":var a=l.querySelector('style[data-href~="'+ct(u.href)+'"]');if(a)return t.instance=a,Dl(a),a;var e=R({},u,{"data-href":u.href,"data-precedence":u.precedence,href:null,precedence:null});return a=(l.ownerDocument||l).createElement("style"),Dl(a),Cl(a,"style",e),zn(a,u.precedence,l),t.instance=a;case"stylesheet":e=ga(u.href);var n=l.querySelector(ie(e));if(n)return t.state.loading|=4,t.instance=n,Dl(n),n;a=j1(u),(e=vt.get(e))&&Qf(a,e),n=(l.ownerDocument||l).createElement("link"),Dl(n);var c=n;return c._p=new Promise(function(f,i){c.onload=f,c.onerror=i}),Cl(n,"link",a),t.state.loading|=4,zn(n,u.precedence,l),t.instance=n;case"script":return n=Sa(u.src),(e=l.querySelector(se(n)))?(t.instance=e,Dl(e),e):(a=u,(e=vt.get(n))&&(a=R({},u),Vf(a,e)),l=l.ownerDocument||l,e=l.createElement("script"),Dl(e),Cl(e,"link",a),l.head.appendChild(e),t.instance=e);case"void":return null;default:throw Error(m(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(a=t.instance,t.state.loading|=4,zn(a,u.precedence,l));return t.instance}function zn(l,t,u){for(var a=u.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),e=a.length?a[a.length-1]:null,n=e,c=0;c<a.length;c++){var f=a[c];if(f.dataset.precedence===t)n=f;else if(n!==e)break}n?n.parentNode.insertBefore(l,n.nextSibling):(t=u.nodeType===9?u.head:u,t.insertBefore(l,t.firstChild))}function Qf(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function Vf(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var _n=null;function Y1(l,t,u){if(_n===null){var a=new Map,e=_n=new Map;e.set(u,a)}else e=_n,a=e.get(u),a||(a=new Map,e.set(u,a));if(a.has(l))return a;for(a.set(l,null),u=u.getElementsByTagName(l),e=0;e<u.length;e++){var n=u[e];if(!(n[Aa]||n[Gl]||l==="link"&&n.getAttribute("rel")==="stylesheet")&&n.namespaceURI!=="http://www.w3.org/2000/svg"){var c=n.getAttribute(t)||"";c=l+c;var f=a.get(c);f?f.push(n):a.set(c,[n])}}return a}function B1(l,t,u){l=l.ownerDocument||l,l.head.insertBefore(u,t==="title"?l.querySelector("head > title"):null)}function b4(l,t,u){if(u===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function G1(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}var oe=null;function E4(){}function T4(l,t,u){if(oe===null)throw Error(m(475));var a=oe;if(t.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&(t.state.loading&4)===0){if(t.instance===null){var e=ga(u.href),n=l.querySelector(ie(e));if(n){l=n._p,l!==null&&typeof l=="object"&&typeof l.then=="function"&&(a.count++,a=Mn.bind(a),l.then(a,a)),t.state.loading|=4,t.instance=n,Dl(n);return}n=l.ownerDocument||l,u=j1(u),(e=vt.get(e))&&Qf(u,e),n=n.createElement("link"),Dl(n);var c=n;c._p=new Promise(function(f,i){c.onload=f,c.onerror=i}),Cl(n,"link",u),t.instance=n}a.stylesheets===null&&(a.stylesheets=new Map),a.stylesheets.set(t,l),(l=t.state.preload)&&(t.state.loading&3)===0&&(a.count++,t=Mn.bind(a),l.addEventListener("load",t),l.addEventListener("error",t))}}function A4(){if(oe===null)throw Error(m(475));var l=oe;return l.stylesheets&&l.count===0&&Lf(l,l.stylesheets),0<l.count?function(t){var u=setTimeout(function(){if(l.stylesheets&&Lf(l,l.stylesheets),l.unsuspend){var a=l.unsuspend;l.unsuspend=null,a()}},6e4);return l.unsuspend=t,function(){l.unsuspend=null,clearTimeout(u)}}:null}function Mn(){if(this.count--,this.count===0){if(this.stylesheets)Lf(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var On=null;function Lf(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,On=new Map,t.forEach(z4,l),On=null,Mn.call(l))}function z4(l,t){if(!(t.state.loading&4)){var u=On.get(l);if(u)var a=u.get(null);else{u=new Map,On.set(l,u);for(var e=l.querySelectorAll("link[data-precedence],style[data-precedence]"),n=0;n<e.length;n++){var c=e[n];(c.nodeName==="LINK"||c.getAttribute("media")!=="not all")&&(u.set(c.dataset.precedence,c),a=c)}a&&u.set(null,a)}e=t.instance,c=e.getAttribute("data-precedence"),n=u.get(c)||a,n===a&&u.set(null,e),u.set(c,e),this.count++,a=Mn.bind(this),e.addEventListener("load",a),e.addEventListener("error",a),n?n.parentNode.insertBefore(e,n.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(e,l.firstChild)),t.state.loading|=4}}var de={$$typeof:ul,Provider:null,Consumer:null,_currentValue:q,_currentValue2:q,_threadCount:0};function _4(l,t,u,a,e,n,c,f){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Gn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Gn(0),this.hiddenUpdates=Gn(null),this.identifierPrefix=a,this.onUncaughtError=e,this.onCaughtError=n,this.onRecoverableError=c,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=f,this.incompleteTransitions=new Map}function X1(l,t,u,a,e,n,c,f,i,v,g,T){return l=new _4(l,t,u,c,f,i,v,T),t=1,n===!0&&(t|=24),n=Il(3,null,null,t),l.current=n,n.stateNode=l,t=_c(),t.refCount++,l.pooledCache=t,t.refCount++,n.memoizedState={element:a,isDehydrated:u,cache:t},pc(n),l}function Z1(l){return l?(l=$u,l):$u}function Q1(l,t,u,a,e,n){e=Z1(e),a.context===null?a.context=e:a.pendingContext=e,a=Wt(t),a.payload={element:u},n=n===void 0?null:n,n!==null&&(a.callback=n),u=$t(l,a,t),u!==null&&(et(u,l,t),Za(u,l,t))}function V1(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var u=l.retryLane;l.retryLane=u!==0&&u<t?u:t}}function Kf(l,t){V1(l,t),(l=l.alternate)&&V1(l,t)}function L1(l){if(l.tag===13){var t=Wu(l,67108864);t!==null&&et(t,l,67108864),Kf(l,67108864)}}var Dn=!0;function M4(l,t,u,a){var e=S.T;S.T=null;var n=O.p;try{O.p=2,Jf(l,t,u,a)}finally{O.p=n,S.T=e}}function O4(l,t,u,a){var e=S.T;S.T=null;var n=O.p;try{O.p=8,Jf(l,t,u,a)}finally{O.p=n,S.T=e}}function Jf(l,t,u,a){if(Dn){var e=wf(a);if(e===null)Cf(l,t,a,pn,u),J1(l,a);else if(p4(e,l,t,u,a))a.stopPropagation();else if(J1(l,a),t&4&&-1<D4.indexOf(l)){for(;e!==null;){var n=qu(e);if(n!==null)switch(n.tag){case 3:if(n=n.stateNode,n.current.memoizedState.isDehydrated){var c=yu(n.pendingLanes);if(c!==0){var f=n;for(f.pendingLanes|=2,f.entangledLanes|=2;c;){var i=1<<31-Fl(c);f.entanglements[1]|=i,c&=~i}_t(n),(al&6)===0&&(dn=bt()+500,ee(0))}}break;case 13:f=Wu(n,2),f!==null&&et(f,n,2),vn(),Kf(n,2)}if(n=wf(a),n===null&&Cf(l,t,a,pn,u),n===e)break;e=n}e!==null&&a.stopPropagation()}else Cf(l,t,a,null,u)}}function wf(l){return l=Fn(l),Wf(l)}var pn=null;function Wf(l){if(pn=null,l=ju(l),l!==null){var t=B(l);if(t===null)l=null;else{var u=t.tag;if(u===13){if(l=F(t),l!==null)return l;l=null}else if(u===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return pn=l,null}function K1(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(ds()){case ni:return 2;case ci:return 8;case be:case rs:return 32;case fi:return 268435456;default:return 32}default:return 32}}var $f=!1,iu=null,su=null,ou=null,re=new Map,ve=new Map,du=[],D4="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function J1(l,t){switch(l){case"focusin":case"focusout":iu=null;break;case"dragenter":case"dragleave":su=null;break;case"mouseover":case"mouseout":ou=null;break;case"pointerover":case"pointerout":re.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":ve.delete(t.pointerId)}}function he(l,t,u,a,e,n){return l===null||l.nativeEvent!==n?(l={blockedOn:t,domEventName:u,eventSystemFlags:a,nativeEvent:n,targetContainers:[e]},t!==null&&(t=qu(t),t!==null&&L1(t)),l):(l.eventSystemFlags|=a,t=l.targetContainers,e!==null&&t.indexOf(e)===-1&&t.push(e),l)}function p4(l,t,u,a,e){switch(t){case"focusin":return iu=he(iu,l,t,u,a,e),!0;case"dragenter":return su=he(su,l,t,u,a,e),!0;case"mouseover":return ou=he(ou,l,t,u,a,e),!0;case"pointerover":var n=e.pointerId;return re.set(n,he(re.get(n)||null,l,t,u,a,e)),!0;case"gotpointercapture":return n=e.pointerId,ve.set(n,he(ve.get(n)||null,l,t,u,a,e)),!0}return!1}function w1(l){var t=ju(l.target);if(t!==null){var u=B(t);if(u!==null){if(t=u.tag,t===13){if(t=F(u),t!==null){l.blockedOn=t,Es(l.priority,function(){if(u.tag===13){var a=at();a=Xn(a);var e=Wu(u,a);e!==null&&et(e,u,a),Kf(u,a)}});return}}else if(t===3&&u.stateNode.current.memoizedState.isDehydrated){l.blockedOn=u.tag===3?u.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Un(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var u=wf(l.nativeEvent);if(u===null){u=l.nativeEvent;var a=new u.constructor(u.type,u);kn=a,u.target.dispatchEvent(a),kn=null}else return t=qu(u),t!==null&&L1(t),l.blockedOn=u,!1;t.shift()}return!0}function W1(l,t,u){Un(l)&&u.delete(t)}function U4(){$f=!1,iu!==null&&Un(iu)&&(iu=null),su!==null&&Un(su)&&(su=null),ou!==null&&Un(ou)&&(ou=null),re.forEach(W1),ve.forEach(W1)}function Rn(l,t){l.blockedOn===t&&(l.blockedOn=null,$f||($f=!0,z.unstable_scheduleCallback(z.unstable_NormalPriority,U4)))}var Nn=null;function $1(l){Nn!==l&&(Nn=l,z.unstable_scheduleCallback(z.unstable_NormalPriority,function(){Nn===l&&(Nn=null);for(var t=0;t<l.length;t+=3){var u=l[t],a=l[t+1],e=l[t+2];if(typeof a!="function"){if(Wf(a||u)===null)continue;break}var n=qu(u);n!==null&&(l.splice(t,3),t-=3,wc(n,{pending:!0,data:e,method:u.method,action:a},a,e))}}))}function ye(l){function t(i){return Rn(i,l)}iu!==null&&Rn(iu,l),su!==null&&Rn(su,l),ou!==null&&Rn(ou,l),re.forEach(t),ve.forEach(t);for(var u=0;u<du.length;u++){var a=du[u];a.blockedOn===l&&(a.blockedOn=null)}for(;0<du.length&&(u=du[0],u.blockedOn===null);)w1(u),u.blockedOn===null&&du.shift();if(u=(l.ownerDocument||l).$$reactFormReplay,u!=null)for(a=0;a<u.length;a+=3){var e=u[a],n=u[a+1],c=e[Vl]||null;if(typeof n=="function")c||$1(u);else if(c){var f=null;if(n&&n.hasAttribute("formAction")){if(e=n,c=n[Vl]||null)f=c.formAction;else if(Wf(e)!==null)continue}else f=c.action;typeof f=="function"?u[a+1]=f:(u.splice(a,3),a-=3),$1(u)}}}function kf(l){this._internalRoot=l}Hn.prototype.render=kf.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(m(409));var u=t.current,a=at();Q1(u,a,l,t,null,null)},Hn.prototype.unmount=kf.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;Q1(l.current,2,null,l,null,null),vn(),t[xu]=null}};function Hn(l){this._internalRoot=l}Hn.prototype.unstable_scheduleHydration=function(l){if(l){var t=ri();l={blockedOn:null,target:l,priority:t};for(var u=0;u<du.length&&t!==0&&t<du[u].priority;u++);du.splice(u,0,l),u===0&&w1(l)}};var k1=$.version;if(k1!=="19.1.1")throw Error(m(527,k1,"19.1.1"));O.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(m(188)):(l=Object.keys(l).join(","),Error(m(268,l)));return l=p(t),l=l!==null?E(l):null,l=l===null?null:l.stateNode,l};var R4={bundleType:0,version:"19.1.1",rendererPackageName:"react-dom",currentDispatcherRef:S,reconcilerVersion:"19.1.1"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Cn=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Cn.isDisabled&&Cn.supportsFiber)try{ba=Cn.inject(R4),kl=Cn}catch{}}return ge.createRoot=function(l,t){if(!G(l))throw Error(m(299));var u=!1,a="",e=r2,n=v2,c=h2,f=null;return t!=null&&(t.unstable_strictMode===!0&&(u=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(e=t.onUncaughtError),t.onCaughtError!==void 0&&(n=t.onCaughtError),t.onRecoverableError!==void 0&&(c=t.onRecoverableError),t.unstable_transitionCallbacks!==void 0&&(f=t.unstable_transitionCallbacks)),t=X1(l,1,!1,null,null,u,a,e,n,c,f,null),l[xu]=t.current,Hf(l),new kf(t)},ge.hydrateRoot=function(l,t,u){if(!G(l))throw Error(m(299));var a=!1,e="",n=r2,c=v2,f=h2,i=null,v=null;return u!=null&&(u.unstable_strictMode===!0&&(a=!0),u.identifierPrefix!==void 0&&(e=u.identifierPrefix),u.onUncaughtError!==void 0&&(n=u.onUncaughtError),u.onCaughtError!==void 0&&(c=u.onCaughtError),u.onRecoverableError!==void 0&&(f=u.onRecoverableError),u.unstable_transitionCallbacks!==void 0&&(i=u.unstable_transitionCallbacks),u.formState!==void 0&&(v=u.formState)),t=X1(l,1,!0,t,u??null,a,e,n,c,f,i,v),t.context=Z1(null),u=t.current,a=at(),a=Xn(a),e=Wt(a),e.callback=null,$t(u,e,a),u=a,t.current.lanes=u,Ta(t,u),_t(t),l[xu]=t.current,Hf(l),new Hn(t)},ge.version="19.1.1",ge}var cs;function X4(){if(cs)return If.exports;cs=1;function z(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(z)}catch($){console.error($)}}return z(),If.exports=G4(),If.exports}var Z4=X4();const Q4="data:image/svg+xml,%3csvg%20width='490'%20height='190'%20viewBox='0%200%20490%20190'%20fill='none'%20xmlns='http://www.w3.org/2000/svg'%3e%3cg%20clip-path='url(%23clip0_33_23)'%3e%3cpath%20d='M455.26%20148.48C444.41%20148.48%20436.47%20139.69%20436.47%20128.84V82.57H423.04V61.9H437.55L437.33%2040.92L459.04%2033.41V61.91H477.82V82.58H459.04V127.43H475.67V148.49H455.25L455.26%20148.48Z'%20fill='black'/%3e%3cpath%20d='M381.33%20149.48C369.96%20149.48%20361.35%20145.8%20355.14%20135.81L353.94%20135.98C354.11%20140.29%20354.28%20144.03%20354.28%20148.51H331.37V33.53L354.63%2025.67V53.97C354.63%2062.24%20354.63%2066.72%20353.77%2074.47L355.15%2074.81C361.53%2064.47%20371%2059.82%20382.03%2059.82C405.46%2059.82%20420.1%2079.8%20420.1%20105.3C420.1%20130.8%20404.94%20149.46%20381.34%20149.46L381.33%20149.48ZM375.82%20128.63C388.74%20128.63%20397.01%20118.92%20397.01%20104.97C397.01%2091.02%20388.74%2080.68%20375.82%2080.68C362.9%2080.68%20354.12%2090.84%20354.12%20105.14C354.12%20119.44%20362.56%20128.63%20375.82%20128.63Z'%20fill='black'/%3e%3cpath%20d='M262.51%20149.48C239.6%20149.48%20224.44%20130.13%20224.44%20104.97C224.44%2079.81%20239.43%2059.83%20263.37%2059.83C274.22%2059.83%20283.36%2064.14%20289.56%2074.3L290.76%2073.96C290.07%2066.72%20290.07%2061.73%20290.07%2053.98V33.54L313.33%2025.68V148.52H290.42C290.42%20144.21%20290.42%20140.29%20290.76%20135.98L289.56%20135.64C283.18%20145.8%20273.88%20149.48%20262.51%20149.48ZM268.88%20128.63C282.15%20128.63%20290.59%20119.27%20290.59%20104.97C290.59%2090.67%20282.15%2080.68%20268.88%2080.68C255.79%2080.85%20247.69%2091.19%20247.69%20105.14C247.69%20119.09%20255.79%20128.63%20268.88%20128.63Z'%20fill='black'/%3e%3cpath%20d='M485.216%20148.816C482.608%20148.816%20480.8%20146.976%20480.8%20144.368C480.8%20141.776%20482.624%20139.92%20485.216%20139.92C487.808%20139.92%20489.632%20141.776%20489.632%20144.368C489.632%20146.976%20487.824%20148.816%20485.216%20148.816ZM485.216%20148.032C487.328%20148.032%20488.752%20146.48%20488.752%20144.368C488.752%20142.256%20487.328%20140.72%20485.216%20140.72C483.104%20140.72%20481.68%20142.256%20481.68%20144.368C481.68%20146.48%20483.104%20148.032%20485.216%20148.032ZM483.744%20146.56V142.112H485.52C486.448%20142.112%20486.928%20142.64%20486.928%20143.424C486.928%20144.144%20486.448%20144.656%20485.696%20144.656H485.664L487.2%20146.544V146.56H486.144L484.592%20144.608H484.576V146.56H483.744ZM484.576%20144.064H485.408C485.84%20144.064%20486.08%20143.808%20486.08%20143.44C486.08%20143.088%20485.824%20142.848%20485.408%20142.848H484.576V144.064Z'%20fill='black'/%3e%3cpath%20d='M158.184%202.16438C166.564%20-2.6797%20175.59%201.19557%20182.359%207.97729C189.45%2015.082%20192.351%2022.8325%20187.839%2031.5518C186.227%2034.7812%20167.209%2067.721%20161.407%2077.0863C158.184%2082.2533%20156.572%2088.7121%20156.572%2094.8479C156.572%20100.984%20158.184%20107.443%20161.407%20112.933C167.209%20121.975%20186.227%20155.238%20187.839%20158.467C192.351%20167.509%20189.128%20174.291%20182.681%20181.396C175.267%20188.823%20167.854%20192.698%20158.828%20187.854C155.605%20185.917%2065.3511%20133.924%2065.3511%20133.924C66.9627%20144.581%2072.7648%20154.269%2080.1785%20160.082C79.2115%20160.405%2034.5761%20186.232%2031.5058%20187.854C23.0444%20192.326%2015.3286%20189.336%208.62001%20183.01C1.04465%20175.867%20-2.66173%20167.509%202.1733%20158.79C3.78498%20155.56%2022.8028%20122.298%2028.2825%20113.255C31.5058%20107.765%2033.4398%20101.63%2033.4398%2095.1709C33.4398%2088.7121%2031.5058%2082.5762%2028.2825%2077.4092C22.8028%2067.721%203.78498%2034.1354%202.1733%2031.2289C-2.66173%2022.5096%201.22016%2013.1436%207.97534%207.00847C15.6327%200.0538926%2022.8028%20-2.03382%2031.5058%202.16438C34.0845%203.1332%20124.016%2056.4182%20124.016%2056.4182C123.049%2046.0841%20117.892%2036.7189%20109.511%2030.2601C110.156%2029.9372%20154.96%203.45614%20158.184%202.16438ZM98.2293%20110.995L111.123%2098.0773C112.734%2096.4626%20112.734%2093.8791%20111.123%2091.9415L98.2293%2079.0239C96.2953%2077.0863%2093.7166%2077.0863%2091.7826%2079.0239L78.8892%2091.9415C77.2775%2093.5562%2077.2775%2096.4626%2078.8892%2098.0773L91.7826%20110.995C93.3942%20112.61%2096.2953%20112.61%2098.2293%20110.995Z'%20fill='%23FE6703'/%3e%3c/g%3e%3cdefs%3e%3cclipPath%20id='clip0_33_23'%3e%3crect%20width='490'%20height='190'%20fill='white'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e",V4="data:image/svg+xml,%3csvg%20width='490'%20height='190'%20viewBox='0%200%20490%20190'%20fill='none'%20xmlns='http://www.w3.org/2000/svg'%3e%3cg%20clip-path='url(%23clip0_33_49)'%3e%3cpath%20d='M455.26%20148.48C444.41%20148.48%20436.47%20139.69%20436.47%20128.84V82.57H423.04V61.9H437.55L437.33%2040.92L459.04%2033.41V61.91H477.82V82.58H459.04V127.43H475.67V148.49H455.25L455.26%20148.48Z'%20fill='white'/%3e%3cpath%20d='M381.33%20149.48C369.96%20149.48%20361.35%20145.8%20355.14%20135.81L353.94%20135.98C354.11%20140.29%20354.28%20144.03%20354.28%20148.51H331.37V33.53L354.63%2025.67V53.97C354.63%2062.24%20354.63%2066.72%20353.77%2074.47L355.15%2074.81C361.53%2064.47%20371%2059.82%20382.03%2059.82C405.46%2059.82%20420.1%2079.8%20420.1%20105.3C420.1%20130.8%20404.94%20149.46%20381.34%20149.46L381.33%20149.48ZM375.82%20128.63C388.74%20128.63%20397.01%20118.92%20397.01%20104.97C397.01%2091.02%20388.74%2080.68%20375.82%2080.68C362.9%2080.68%20354.12%2090.84%20354.12%20105.14C354.12%20119.44%20362.56%20128.63%20375.82%20128.63Z'%20fill='white'/%3e%3cpath%20d='M262.51%20149.48C239.6%20149.48%20224.44%20130.13%20224.44%20104.97C224.44%2079.81%20239.43%2059.83%20263.37%2059.83C274.22%2059.83%20283.36%2064.14%20289.56%2074.3L290.76%2073.96C290.07%2066.72%20290.07%2061.73%20290.07%2053.98V33.54L313.33%2025.68V148.52H290.42C290.42%20144.21%20290.42%20140.29%20290.76%20135.98L289.56%20135.64C283.18%20145.8%20273.88%20149.48%20262.51%20149.48ZM268.88%20128.63C282.15%20128.63%20290.59%20119.27%20290.59%20104.97C290.59%2090.67%20282.15%2080.68%20268.88%2080.68C255.79%2080.85%20247.69%2091.19%20247.69%20105.14C247.69%20119.09%20255.79%20128.63%20268.88%20128.63Z'%20fill='white'/%3e%3cpath%20d='M485.216%20148.816C482.608%20148.816%20480.8%20146.976%20480.8%20144.368C480.8%20141.776%20482.624%20139.92%20485.216%20139.92C487.808%20139.92%20489.632%20141.776%20489.632%20144.368C489.632%20146.976%20487.824%20148.816%20485.216%20148.816ZM485.216%20148.032C487.328%20148.032%20488.752%20146.48%20488.752%20144.368C488.752%20142.256%20487.328%20140.72%20485.216%20140.72C483.104%20140.72%20481.68%20142.256%20481.68%20144.368C481.68%20146.48%20483.104%20148.032%20485.216%20148.032ZM483.744%20146.56V142.112H485.52C486.448%20142.112%20486.928%20142.64%20486.928%20143.424C486.928%20144.144%20486.448%20144.656%20485.696%20144.656H485.664L487.2%20146.544V146.56H486.144L484.592%20144.608H484.576V146.56H483.744ZM484.576%20144.064H485.408C485.84%20144.064%20486.08%20143.808%20486.08%20143.44C486.08%20143.088%20485.824%20142.848%20485.408%20142.848H484.576V144.064Z'%20fill='white'/%3e%3cpath%20d='M158.184%202.16438C166.564%20-2.6797%20175.59%201.19557%20182.359%207.97729C189.45%2015.082%20192.351%2022.8325%20187.839%2031.5518C186.227%2034.7812%20167.209%2067.721%20161.407%2077.0863C158.184%2082.2533%20156.572%2088.7121%20156.572%2094.8479C156.572%20100.984%20158.184%20107.443%20161.407%20112.933C167.209%20121.975%20186.227%20155.238%20187.839%20158.467C192.351%20167.509%20189.128%20174.291%20182.681%20181.396C175.267%20188.823%20167.854%20192.698%20158.828%20187.854C155.605%20185.917%2065.3511%20133.924%2065.3511%20133.924C66.9627%20144.581%2072.7648%20154.269%2080.1785%20160.082C79.2115%20160.405%2034.5761%20186.232%2031.5058%20187.854C23.0444%20192.326%2015.3286%20189.336%208.62001%20183.01C1.04465%20175.867%20-2.66173%20167.509%202.1733%20158.79C3.78498%20155.56%2022.8028%20122.298%2028.2825%20113.255C31.5058%20107.765%2033.4398%20101.63%2033.4398%2095.1709C33.4398%2088.7121%2031.5058%2082.5762%2028.2825%2077.4092C22.8028%2067.721%203.78498%2034.1354%202.1733%2031.2289C-2.66173%2022.5096%201.22016%2013.1436%207.97534%207.00847C15.6327%200.0538926%2022.8028%20-2.03382%2031.5058%202.16438C34.0845%203.1332%20124.016%2056.4182%20124.016%2056.4182C123.049%2046.0841%20117.892%2036.7189%20109.511%2030.2601C110.156%2029.9372%20154.96%203.45614%20158.184%202.16438ZM98.2293%20110.995L111.123%2098.0773C112.734%2096.4626%20112.734%2093.8791%20111.123%2091.9415L98.2293%2079.0239C96.2953%2077.0863%2093.7166%2077.0863%2091.7826%2079.0239L78.8892%2091.9415C77.2775%2093.5562%2077.2775%2096.4626%2078.8892%2098.0773L91.7826%20110.995C93.3942%20112.61%2096.2953%20112.61%2098.2293%20110.995Z'%20fill='%23FE6703'/%3e%3c/g%3e%3cdefs%3e%3cclipPath%20id='clip0_33_49'%3e%3crect%20width='490'%20height='190'%20fill='white'/%3e%3c/clipPath%3e%3c/defs%3e%3c/svg%3e";function ai(z){return(z instanceof DOMException||z instanceof Error)&&z.name==="AbortError"}function L4(z){return z instanceof TypeError?!0:z instanceof Error&&z.name==="TypeError"}function K4(z){return new Promise($=>{setTimeout($,z)})}async function xn(z,$,V){const{attempts:m=3,delayMs:G=500,backoffFactor:B=2,timeoutMs:F=1e4,retryOnResponse:rl}=V??{};let p=G;for(let E=0;E<m;E++){E>0&&p>0&&(await K4(p),p*=B);const R=new AbortController,K=setTimeout(()=>R.abort(),F);$?.signal&&$.signal.addEventListener("abort",()=>R.abort(),{once:!0});try{const N=await fetch(z,{...$,signal:R.signal});if(clearTimeout(K),rl&&rl(N)&&E<m-1){try{await N.arrayBuffer()}catch{}continue}return N}catch(N){if(clearTimeout(K),ai(N)||!L4(N)||E===m-1)throw N}}throw new Error("Failed to fetch after retries")}function J4(){const z=window.location.hash.startsWith("#")?window.location.hash.slice(1):window.location.hash,$=z.startsWith("?")?z.slice(1):z;return new URLSearchParams($)}function w4(){const z=xl.useMemo(()=>J4(),[]);return{status:z.get("status"),error:z.get("error"),errorDescription:z.get("error_description")}}function W4({value:z,onChange:$,options:V,placeholder:m,id:G}){const[B,F]=xl.useState(!1),rl=xl.useRef(null),p=xl.useRef(null);xl.useEffect(()=>{function N(il){rl.current&&!rl.current.contains(il.target)&&F(!1)}if(B)return document.addEventListener("mousedown",N),()=>{document.removeEventListener("mousedown",N)}},[B]),xl.useEffect(()=>{function N(il){if(!B){(il.key==="Enter"||il.key===" "||il.key==="ArrowDown")&&(il.preventDefault(),F(!0));return}il.key==="Escape"&&(F(!1),p.current?.focus())}if(p.current?.contains(document.activeElement))return document.addEventListener("keydown",N),()=>{document.removeEventListener("keydown",N)}},[B]);const E=V.find(N=>N.id===z),R=()=>{F(!B)},K=N=>{$(N.id.toString()),F(!1),p.current?.focus()};return M.jsxs("div",{className:"custom-dropdown",ref:rl,children:[M.jsx("button",{ref:p,id:G,type:"button",className:`dropdown-trigger ${B?"open":""} ${E?"":"placeholder"}`,onClick:R,"aria-haspopup":"listbox","aria-expanded":B,"aria-labelledby":`${G}-label`,children:E?M.jsxs(M.Fragment,{children:[M.jsx("div",{className:"option-primary",children:E.name}),M.jsx("div",{className:"option-secondary",children:E.account_name})]}):m}),B&&M.jsx("div",{ref:rl,className:"dropdown-options",role:"listbox","aria-labelledby":`${G}-label`,children:V.map(N=>M.jsxs("button",{type:"button",className:`dropdown-option ${N.id===z?"selected":""}`,onClick:()=>K(N),role:"option","aria-selected":N.id===z,children:[M.jsx("div",{className:"option-primary",children:N.name}),M.jsx("div",{className:"option-secondary",children:N.account_name})]},`${N.account_id}-${N.id}`))})]})}function $4(){const z=w4(),[$,V]=xl.useState(null),[m,G]=xl.useState([]),[B,F]=xl.useState(null),[rl,p]=xl.useState(!1),[E,R]=xl.useState(null),[K,N]=xl.useState(null),[il,Ol]=xl.useState(!1),[jl,ql]=xl.useState(!1);xl.useEffect(()=>{if(z.status!=="success")return;const ul=new AbortController;let sl=!1;return(async()=>{p(!0),F(null);try{const P=await xn("/projects",{signal:ul.signal},{attempts:3,delayMs:400});if(!P.ok)throw new Error(`Failed to load projects (${P.status})`);const zl=await P.json();sl||G(zl)}catch(P){if(sl||ai(P))return;const zl=P instanceof Error?P.message:String(P);F(zl)}finally{sl||p(!1)}})(),()=>{sl=!0,ul.abort()}},[z.status]),xl.useEffect(()=>{if(z.status!=="success")return;const ul=new AbortController;let sl=!1;return(async()=>{try{const Z=await xn("/dbt_platform_context",{signal:ul.signal},{attempts:2,delayMs:400});if(!Z.ok||sl)return;const P=await Z.json();sl||N(P)}catch(Z){if(ai(Z)||sl)return}})(),()=>{sl=!0,ul.abort()}},[z.status]);const Mt=async()=>{if(!il){Ol(!0),V(null);try{const ul=await xn("/shutdown",{method:"POST"},{attempts:3,delayMs:400}),sl=await ul.text();ul.ok?(ql(!0),window.close()):V(sl)}catch(ul){V(String(ul))}finally{Ol(!1)}}},ht=async ul=>{N(null);const sl=Number(ul);R(Number.isNaN(sl)?null:sl);const Z=m.find(P=>P.id===sl);if(Z)try{const P=await xn("/selected_project",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({account_id:Z.account_id,project_id:Z.id})},{attempts:3,delayMs:400});if(P.ok){const zl=await P.json();N(zl)}else V(await P.text()),N(null)}catch(P){V(String(P)),N(null)}};return M.jsxs("div",{className:"app-container",children:[M.jsxs("div",{className:"logo-container",children:[M.jsx("img",{src:Q4,alt:"dbt",className:"logo logo-light"}),M.jsx("img",{src:V4,alt:"dbt",className:"logo logo-dark"})]}),M.jsxs("div",{className:"app-content",children:[M.jsxs("header",{className:"app-header",children:[M.jsx("h1",{children:"dbt Platform Setup"}),M.jsx("p",{children:"Configure your dbt Platform connection"})]}),z.status==="error"&&M.jsxs("section",{className:"error-section",children:[M.jsxs("div",{className:"section-header",children:[M.jsx("h2",{children:"Authentication Error"}),M.jsx("p",{children:"There was a problem during authentication"})]}),M.jsxs("div",{className:"error-details",children:[z.error&&M.jsxs("div",{className:"error-item",children:[M.jsx("strong",{children:"Error Code:"}),M.jsx("code",{className:"error-code",children:z.error})]}),z.errorDescription&&M.jsxs("div",{className:"error-item",children:[M.jsx("strong",{children:"Description:"}),M.jsx("p",{className:"error-description",children:decodeURIComponent(z.errorDescription)})]}),M.jsx("div",{className:"error-actions",children:M.jsx("p",{children:"Please close this window and try again. If the problem persists, contact support."})})]})]}),z.status==="success"&&!jl&&M.jsxs("section",{className:"project-selection-section",children:[M.jsxs("div",{className:"section-header",children:[M.jsx("h2",{children:"Select a Project"}),M.jsx("p",{children:"Choose the dbt project you want to work with"})]}),M.jsxs("div",{className:"form-content",children:[rl&&M.jsxs("div",{className:"loading-state",children:[M.jsx("div",{className:"spinner"}),M.jsx("span",{children:"Loading projects…"})]}),B&&M.jsxs("div",{className:"error-state",children:[M.jsx("strong",{children:"Error loading projects"}),M.jsx("p",{children:B})]}),!rl&&!B&&M.jsxs("div",{className:"form-group",children:[M.jsx("label",{htmlFor:"project-select",className:"form-label",id:"project-select-label",children:"Available Projects"}),M.jsx(W4,{id:"project-select",value:E,onChange:ht,options:m,placeholder:"Choose a project"})]})]})]}),K&&!jl&&M.jsxs("section",{className:"context-section",children:[M.jsxs("div",{className:"section-header",children:[M.jsx("h2",{children:"Current Configuration"}),M.jsx("p",{children:"Your dbt Platform context is ready"})]}),M.jsxs("div",{className:"context-details",children:[M.jsxs("div",{className:"context-item",children:[M.jsx("strong",{children:"User ID:"})," ",K.decoded_access_token?.decoded_claims.sub]}),K.dev_environment&&M.jsxs("div",{className:"context-item",children:[M.jsx("strong",{children:"Development Environment:"}),M.jsx("div",{className:"environment-details",children:M.jsx("span",{className:"env-name",children:K.dev_environment.name})})]}),K.prod_environment&&M.jsxs("div",{className:"context-item",children:[M.jsx("strong",{children:"Production Environment:"}),M.jsx("div",{className:"environment-details",children:M.jsx("span",{className:"env-name",children:K.prod_environment.name})})]})]})]}),K&&!jl&&M.jsx("div",{className:"button-container",children:M.jsx("button",{onClick:Mt,className:"primary-button",disabled:E===null||il,children:il?"Closing…":"Continue"})}),jl&&M.jsx("section",{className:"completion-section",children:M.jsxs("div",{className:"completion-card",children:[M.jsx("h2",{children:"All Set!"}),M.jsx("p",{children:"Your dbt Platform setup has finished. This window can now be closed."})]})}),$&&M.jsxs("section",{className:"response-section",children:[M.jsx("div",{className:"section-header",children:M.jsx("h3",{children:"Response"})}),M.jsx("pre",{className:"response-text",children:$})]})]})]})}Z4.createRoot(document.getElementById("root")).render(M.jsx(xl.StrictMode,{children:M.jsx($4,{})}));let fs=!1;const is=()=>{if(fs)return;fs=!0;const z="/shutdown";try{if("sendBeacon"in navigator){const $=new Blob([""],{type:"text/plain"});navigator.sendBeacon(z,$)}else fetch(z,{method:"POST",keepalive:!0}).catch(()=>{})}catch{}};window.addEventListener("pagehide",is);window.addEventListener("beforeunload",is);
